package com.snplog.backend.adapter;

import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.snplog.backend.dto.CabinAreaDTO;
import com.snplog.backend.entity.CabinArea;
import com.snplog.backend.repository.CabinAreaRepository;

/**
 * Adapter to transform {@link.com.snplog.backend.entitiy.CabinArea} to and from
 * {@link.com.snplog.backend.dto.CabinAreaDTO}.
 * This class is only referenced by the {@link.com.snplog.backend.services.misc.JpaDtoMapper},
 * and other adapter classes to link other objects.
 * 
 * @author Theodor Urtegård
 *
 */
@Service
public class CabinAreaAdapter {
	
	/**
	 *  {@link.com.snplog.backend.repository.CabinAreaRepository} for the {@link.com.snplog.backend.entity.CabinArea} class.
	 */
	@Autowired
	private CabinAreaRepository cabinAreaRepository;
	
	/**
	 * Creates a Data Transfer Object ready to send to an end user
	 * 
	 * @param cabinArea, to be transformed into DTO Object
	 * @return CabinAreaDTO {@link.com.snplog.backend.dto.CabinAreaDTO}
	 */
	public CabinAreaDTO toDTOFinal(CabinArea cabinArea) {
		return new CabinAreaDTO(
				cabinArea.getId(),
				cabinArea.getName(),
				cabinArea.getCreated(),
				cabinArea.getLongitude(),
				cabinArea.getLatitude(),
				cabinArea.getRadius()
				);
	}
	
	/**
	 * Function to transform a Data Transfer Object to an Entity.
	 * Enabling the application to use jparepository calls (i.e. save, update, delete, etc..)
	 * 
	 * @param cabinAreaDTO, to be transformed into entity
	 * @return CabinArea {@link.com.snplog.backend.entity.CabinArea}
	 */
	public CabinArea fromDTO(CabinAreaDTO cabinAreaDTO) {
		Optional<CabinArea> result = cabinAreaRepository.findById(cabinAreaDTO.getId());
		
		CabinArea cabinArea = null;
		
		if(result.isPresent()) {
			cabinArea = result.get();
			cabinArea.setName(cabinAreaDTO.getName());
			cabinArea.setLongitude(cabinAreaDTO.getLongitude());
			cabinArea.setLatitude(cabinAreaDTO.getLatitude());
			cabinArea.setRadius(cabinAreaDTO.getRadius());
		} else {
			throw new RuntimeException("Did not find the cabin area id - " + cabinAreaDTO.getId());
		}
		
		return cabinArea;
	}
	
}
