package com.snplog.backend.adapter;

import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.snplog.backend.dto.PlowerCabinAreaDTO;
import com.snplog.backend.entity.PlowerCabinArea;
import com.snplog.backend.repository.PlowerCabinAreaRepository;

/**
 * Adapter to transform {@link.com.snplog.backend.entitiy.PlowerCabinArea} to and from
 * {@link.com.snplog.backend.dto.PlowerCabinAreaDTO}.
 * This class is only referenced by the {@link.com.snplog.backend.services.misc.JpaDtoMapper},
 * and other adapter classes to link other objects.
 * 
 * @author Theodor Urtegård
 *
 */
@Service
public class PlowerCabinAreaAdapter {
	
	/**
	 *  {@link.com.snplog.backend.repository.PlowerCabinAreaRepository} for the {@link.com.snplog.backend.entity.PlowerCabinArea} class.
	 */
	@Autowired
	private PlowerCabinAreaRepository plowerCabinAreaRepository;
	
	/**
	 *  {@link.com.snplog.backend.adapter.MyUserAdapter} for the {@link.com.snplog.backend.entity.MyUser} class.
	 */
	@Autowired
	private MyUserAdapter myUserAdapter;
	
	/**
	 *  {@link.com.snplog.backend.adapter.CabinAreaAdapter} for the {@link.com.snplog.backend.entity.CabinArea} class.
	 */
	@Autowired
	private CabinAreaAdapter cabinAreaAdapter;

	/**
	 * Creates a Data Transfer Object ready to send to an end user
	 * 
	 * @param plowerCabinArea, to be transformed into DTO Object
	 * @return PlowerCabinAreaDTO {@link.com.snplog.backend.dto.PlowerCabinAreaDTO}
	 */
	public PlowerCabinAreaDTO toDTO(PlowerCabinArea plowerCabinArea) {
		return new PlowerCabinAreaDTO(
				plowerCabinArea.getId(),
				myUserAdapter.toDTOFinal(plowerCabinArea.getPlower()),
				cabinAreaAdapter.toDTOFinal(plowerCabinArea.getCabinArea()),
				plowerCabinArea.getValid(),
				plowerCabinArea.getDateCreated(),
				plowerCabinArea.getDateEnded()
				);
		
	}
	
	/**
	 * This function is needed to stop the infinite recursion in the JSON message sent to the end user
	 * 
	 * @param plowerCabinArea, to be transformed into DTO Object
	 * @return PlowerCabinAreaDTO {@link.com.snplog.backend.dto.PlowerCabinAreaDTO}
	 */
	public PlowerCabinAreaDTO toDTOFinal(PlowerCabinArea plowerCabinArea) {
		return new PlowerCabinAreaDTO(
				plowerCabinArea.getId(),
				null,
				null,
				plowerCabinArea.getValid(),
				plowerCabinArea.getDateCreated(),
				plowerCabinArea.getDateEnded()
				);
		
	}
	
	/**
	 * Function to transform a Data Transfer Object to an Entity.
	 * Enabling the application to use jparepository calls (i.e. save, update, delete, etc..)
	 * 
	 * @param plowerCabinAreaDTO, to be transformed into entity
	 * @return PlowerCabinArea {@link.com.snplog.backend.entity.PlowerCabinArea}
	 */
	public PlowerCabinArea fromDTO(PlowerCabinAreaDTO plowerCabinAreaDTO) {
		Optional<PlowerCabinArea> result = plowerCabinAreaRepository.findById(plowerCabinAreaDTO.getId());
		
		PlowerCabinArea plowerCabinArea = null;
		
		if(result.isPresent()) {
			plowerCabinArea = result.get();
			plowerCabinArea.setValid(plowerCabinArea.getValid());
			plowerCabinArea.setDateEnded(plowerCabinAreaDTO.getDateEnded());
		} else {
			throw new RuntimeException("Did not find the messageThread id - " + plowerCabinAreaDTO.getId());
		}
		
		return plowerCabinArea;
	}
	
}
