package com.snplog.backend.dto;

import java.sql.Timestamp;
import java.util.List;

import com.snplog.backend.entity.Change;

/**
 * 
 * CabinAreaDTO class is a Data Transfer Object class.
 * This class models the data that is to be transfered to end users
 * Based upon the {@link.com.snplog.backend.entity.CabinArea} entity class.
 * 
 * @author Theodor Urtegård
 *
 */
public class CabinAreaDTO {

	private int id;
	
	private String name;
	
	private Timestamp created;
	
	private double longitude;
	
	private double latitude;
	
	private int radius;
	
	/**
	 * A list to hold {@link.com.snplog.backend.entity.Change} objects. 
	 * This helps with auditing when the object is returned with changes to its fields.
	 */
	private List<Change> changes;
	
	/**
	 * Boolean value to hold information if the entity should be updated
	 * (May be redundant)
	 */
	private boolean edited;
	
	public CabinAreaDTO() {}
	
	/**
	 * 
	 * @param id
	 * @param name
	 * @param created
	 * @param longitude
	 * @param latitude
	 * @param radius
	 */
	public CabinAreaDTO(int id, String name, Timestamp created, double longitude, double latitude, int radius) {
		super();
		this.id = id;
		this.name = name;
		this.created = created;
		this.longitude = longitude;
		this.latitude = latitude;
		this.radius = radius;
		this.edited = false;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Timestamp getCreated() {
		return created;
	}

	public void setCreated(Timestamp created) {
		this.created = created;
	}

	public double getLongitude() {
		return longitude;
	}

	public void setLongitude(double longitude) {
		this.longitude = longitude;
	}

	public double getLatitude() {
		return latitude;
	}

	public void setLatitude(double latitude) {
		this.latitude = latitude;
	}

	public int getRadius() {
		return radius;
	}

	public void setRadius(int radius) {
		this.radius = radius;
	}
	

	public List<Change> getChanges() {
		return changes;
	}

	public void setChanges(List<Change> changes) {
		this.changes = changes;
	}
	
	
	public boolean isEdited() {
		return edited;
	}

	public void setEdited(boolean edited) {
		this.edited = edited;
	}

	@Override
	public String toString() {
		return "CabinAreaDTO [id=" + id + ", name=" + name + ", created=" + created + ", longitude=" + longitude
				+ ", latitude=" + latitude + ", radius=" + radius + "]";
	}
	
	
	
	
}
