package com.snplog.backend.dto;

import java.sql.Timestamp;
import java.util.List;

import com.snplog.backend.entity.Change;

/**
 * 
 * CabinDTO class is a Data Transfer Object class.
 * This class models the data that is to be transfered to end users
 * Based upon the {@link.com.snplog.backend.entity.Cabin} entity class.
 * 
 * @author Theodor Urtegård
 *
 */
public class CabinDTO {
	
	private int id;
	
	private MyUserDTO myUserDTO;
	
	private CabinAreaDTO cabinArea;
	
	private String cabinName;
	
	private double longitude;
	
	private double latitude;
	
	private String country;
	
	private String region;
	
	private String municipality;
	
	private String streetAdress;
	
	private int kid;
	
	private int gid;
	
	private int bid;
	
	private String cabinStatus;
	
	private Timestamp lastPlowed;
	
	private Timestamp created;
	
	/**
	 * Boolean value to hold information if the entity should be updated
	 * (May be redundant)
	 */
	private boolean edited;
	
	/**
	 * A list to hold {@link.com.snplog.backend.entity.Change} objects. 
	 * This helps with auditing when the object is returned with changes to its fields.
	 */
	private List<Change> changes;
	
	public CabinDTO() {}

	/**
	 * 
	 * @param id
	 * @param myUserDTO
	 * @param cabinArea
	 * @param cabinName
	 * @param longitude
	 * @param latitude
	 * @param country
	 * @param region
	 * @param municipality
	 * @param streetAdress
	 * @param kid
	 * @param gid
	 * @param bid
	 * @param cabinStatus
	 * @param lastPlowed
	 * @param created
	 */
	public CabinDTO(int id, MyUserDTO myUserDTO, CabinAreaDTO cabinArea, String cabinName, double longitude,
			double latitude, String country, String region, String municipality, String streetAdress, int kid, int gid,
			int bid, String cabinStatus, Timestamp lastPlowed, Timestamp created) {
		super();
		this.id = id;
		this.myUserDTO = myUserDTO;
		this.cabinArea = cabinArea;
		this.cabinName = cabinName;
		this.longitude = longitude;
		this.latitude = latitude;
		this.country = country;
		this.region = region;
		this.municipality = municipality;
		this.streetAdress = streetAdress;
		this.kid = kid;
		this.gid = gid;
		this.bid = bid;
		this.cabinStatus = cabinStatus;
		this.lastPlowed = lastPlowed;
		this.created = created;
		this.edited = false;
	}


	public String getCabinName() {
		return cabinName;
	}



	public void setCabinName(String cabinName) {
		this.cabinName = cabinName;
	}



	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public MyUserDTO getMyUserDTO() {
		return myUserDTO;
	}

	public void setMyUserDTO(MyUserDTO myUserDTO) {
		this.myUserDTO = myUserDTO;
	}

	public CabinAreaDTO getCabinArea() {
		return cabinArea;
	}

	public void setCabinArea(CabinAreaDTO cabinArea) {
		this.cabinArea = cabinArea;
	}

	public double getLongitude() {
		return longitude;
	}

	public void setLongitude(double longitude) {
		this.longitude = longitude;
	}

	public double getLatitude() {
		return latitude;
	}

	public void setLatitude(double latitude) {
		this.latitude = latitude;
	}
	

	public String getCountry() {
		return country;
	}

	public void setCountry(String country) {
		this.country = country;
	}

	public String getRegion() {
		return region;
	}

	public void setRegion(String region) {
		this.region = region;
	}

	public String getMunicipality() {
		return municipality;
	}

	public void setMunicipality(String municipality) {
		this.municipality = municipality;
	}

	public String getStreetAdress() {
		return streetAdress;
	}

	public void setStreetAdress(String streetAdress) {
		this.streetAdress = streetAdress;
	}

	public int getKid() {
		return kid;
	}

	public void setKid(int kid) {
		this.kid = kid;
	}

	public int getGid() {
		return gid;
	}

	public void setGid(int gid) {
		this.gid = gid;
	}

	public int getBid() {
		return bid;
	}

	public void setBid(int bid) {
		this.bid = bid;
	}

	public String getCabinStatus() {
		return cabinStatus;
	}

	public void setCabinStatus(String cabinStatus) {
		this.cabinStatus = cabinStatus;
	}

	public Timestamp getLastPlowed() {
		return lastPlowed;
	}

	public void setLastPlowed(Timestamp lastPlowed) {
		this.lastPlowed = lastPlowed;
	}

	public Timestamp getCreated() {
		return created;
	}

	public void setCreated(Timestamp created) {
		this.created = created;
	}
	

	public boolean isEdited() {
		return edited;
	}



	public void setEdited(boolean edited) {
		this.edited = edited;
	}



	public List<Change> getChanges() {
		return changes;
	}



	public void setChanges(List<Change> changes) {
		this.changes = changes;
	}



	@Override
	public String toString() {
		return "CabinDTO [id=" + id + ", myUserDTO=" + myUserDTO + ", cabinArea=" + cabinArea + ", cabinName="
				+ cabinName + ", longitude=" + longitude + ", latitude=" + latitude + ", kid=" + kid + ", gid=" + gid
				+ ", bid=" + bid + ", cabinStatus=" + cabinStatus + ", lastPlowed=" + lastPlowed + ", created="
				+ created + "]";
	}

	

	
	

}
