package com.snplog.backend.dto;

import java.sql.Timestamp;
import java.util.List;

import com.snplog.backend.entity.Change;

/**
 * 
 * MessageDTO class is a Data Transfer Object class.
 * This class models the data that is to be transfered to end users
 * Based upon the {@link.com.snplog.backend.entity.Message} entity class.
 * 
 * @author Theodor Urtegård
 *
 */
public class MessageDTO {

	private int id;
	
	private MyUserDTO sender;
	
	private MessageThreadDTO messageThread;
	
	private String messageContent;
	
	private Timestamp dateCreated;
	
	/**
	 * Boolean value to hold information if the entity should be updated
	 * (May be redundant)
	 */
	private boolean edited;
	
	/**
	 * A list to hold {@link.com.snplog.backend.entity.Change} objects. 
	 * This helps with auditing when the object is returned with changes to its fields.
	 */
	private List<Change> changes;
	
	public MessageDTO() {}

	/**
	 * 
	 * @param id
	 * @param sender
	 * @param messageThread
	 * @param messageContent
	 * @param dateCreated
	 */
	public MessageDTO(int id, MyUserDTO sender, MessageThreadDTO messageThread, String messageContent,
			Timestamp dateCreated) {
		super();
		this.id = id;
		this.sender = sender;
		this.messageThread = messageThread;
		this.messageContent = messageContent;
		this.dateCreated = dateCreated;
		this.edited = false;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public MyUserDTO getSender() {
		return sender;
	}

	public void setSender(MyUserDTO sender) {
		this.sender = sender;
	}

	public MessageThreadDTO getMessageThread() {
		return messageThread;
	}

	public void setMessageThread(MessageThreadDTO messageThread) {
		this.messageThread = messageThread;
	}

	public String getMessageContent() {
		return messageContent;
	}

	public void setMessageContent(String messageContent) {
		this.messageContent = messageContent;
	}

	public Timestamp getDateCreated() {
		return dateCreated;
	}

	public void setDateCreated(Timestamp dateCreated) {
		this.dateCreated = dateCreated;
	}

	public boolean isEdited() {
		return edited;
	}

	public void setEdited(boolean edited) {
		this.edited = edited;
	}

	public List<Change> getChanges() {
		return changes;
	}

	public void setChanges(List<Change> changes) {
		this.changes = changes;
	}
	
	
	
	
}
