package com.snplog.backend.dto;

import java.sql.Timestamp;
import java.util.List;

import com.snplog.backend.entity.Change;

/**
 * 
 * MessageThreadDTO class is a Data Transfer Object class.
 * This class models the data that is to be transfered to end users
 * Based upon the {@link.com.snplog.backend.entity.MessageThread} entity class.
 * 
 * @author Theodor Urtegård
 *
 */
public class MessageThreadDTO {
	
	private int id;
	
	private Timestamp dateCreated;
	
	private boolean closed;
	
	private Timestamp dateClosed;
	
	private List<MyUserDTO> participants;
	
	/**
	 * Boolean value to hold information if the entity should be updated
	 * (May be redundant)
	 */
	private boolean edited;
	
	/**
	 * A list to hold {@link.com.snplog.backend.entity.Change} objects. 
	 * This helps with auditing when the object is returned with changes to its fields.
	 */
	private List<Change> changes;
	
	public MessageThreadDTO() {}

	/**
	 * 
	 * @param id
	 * @param dateCreated
	 * @param closed
	 * @param dateClosed
	 * @param participants
	 */
	public MessageThreadDTO(int id, Timestamp dateCreated, boolean closed, Timestamp dateClosed,
			List<MyUserDTO> participants) {
		super();
		this.id = id;
		this.dateCreated = dateCreated;
		this.closed = closed;
		this.dateClosed = dateClosed;
		this.participants = participants;
		this.edited = false;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public Timestamp getDateCreated() {
		return dateCreated;
	}

	public void setDateCreated(Timestamp dateCreated) {
		this.dateCreated = dateCreated;
	}

	public boolean isClosed() {
		return closed;
	}

	public void setClosed(boolean closed) {
		this.closed = closed;
	}

	public Timestamp getDateClosed() {
		return dateClosed;
	}

	public void setDateClosed(Timestamp dateClosed) {
		this.dateClosed = dateClosed;
	}

	public List<MyUserDTO> getParticipants() {
		return participants;
	}

	public void setParticipants(List<MyUserDTO> participants) {
		this.participants = participants;
	}
	

	public boolean isEdited() {
		return edited;
	}

	public void setEdited(boolean edited) {
		this.edited = edited;
	}

	public List<Change> getChanges() {
		return changes;
	}

	public void setChanges(List<Change> changes) {
		this.changes = changes;
	}

	@Override
	public String toString() {
		return "MessageThreadDTO [id=" + id + ", dateCreated=" + dateCreated + ", closed=" + closed + ", dateClosed="
				+ dateClosed + ", participants=" + participants + "]";
	}
	
	

}
