package com.snplog.backend.dto;

import java.sql.Timestamp;
import java.util.List;

import com.snplog.backend.entity.Change;
import com.snplog.backend.entity.Role;

/**
 * 
 * MyUserDTO class is a Data Transfer Object class.
 * This class models the data that is to be transfered to end users
 * Based upon the {@link.com.snplog.backend.entity.MyUser} entity class.
 * 
 * @author Theodor Urtegård
 *
 */
public class MyUserDTO {

	private int id;
	
	private String firstName;
	
	private String lastName;
	
	private String email;
	
	private String phoneNumber;
	
	private String streetAdress;
	
	private String city;
	
	private String country;
	
	private Timestamp dateTimeCreated;
	
	private List<Role> roles;
	
	private List<CabinDTO> cabins;
	
	/**
	 * Boolean value to hold information if the entity should be updated
	 * (May be redundant)
	 */
	private boolean edited;
	
	/**
	 * A list to hold {@link.com.snplog.backend.entity.Change} objects. 
	 * This helps with auditing when the object is returned with changes to its fields.
	 */
	private List<Change> changes;
	
	public MyUserDTO() {}

	/**
	 * 
	 * @param id
	 * @param firstName
	 * @param lastName
	 * @param email
	 * @param phoneNumber
	 * @param streetAdress
	 * @param city
	 * @param country
	 * @param dateTimeCreated
	 * @param roles
	 * @param cabins
	 */
	public MyUserDTO(int id, String firstName, String lastName, String email, String phoneNumber, String streetAdress,
			String city, String country, Timestamp dateTimeCreated, List<Role> roles, List<CabinDTO> cabins) {
		super();
		this.id = id;
		this.firstName = firstName;
		this.lastName = lastName;
		this.email = email;
		this.phoneNumber = phoneNumber;
		this.streetAdress = streetAdress;
		this.city = city;
		this.country = country;
		this.dateTimeCreated = dateTimeCreated;
		this.roles = roles;
		this.cabins = cabins;
		this.edited = false;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public String getFirstName() {
		return firstName;
	}

	public void setFirstName(String firstName) {
		this.firstName = firstName;
	}

	public String getLastName() {
		return lastName;
	}

	public void setLastName(String lastName) {
		this.lastName = lastName;
	}

	public String getEmail() {
		return email;
	}

	public void setEmail(String email) {
		this.email = email;
	}

	public String getPhoneNumber() {
		return phoneNumber;
	}

	public void setPhoneNumber(String phoneNumber) {
		this.phoneNumber = phoneNumber;
	}

	public String getStreetAdress() {
		return streetAdress;
	}

	public void setStreetAdress(String streetAdress) {
		this.streetAdress = streetAdress;
	}

	public String getCity() {
		return city;
	}

	public void setCity(String city) {
		this.city = city;
	}

	public String getCountry() {
		return country;
	}

	public void setCountry(String country) {
		this.country = country;
	}

	public Timestamp getDateTimeCreated() {
		return dateTimeCreated;
	}

	public void setDateTimeCreated(Timestamp dateTimeCreated) {
		this.dateTimeCreated = dateTimeCreated;
	}

	public List<Role> getRoles() {
		return roles;
	}

	public void setRoles(List<Role> roles) {
		this.roles = roles;
	}

	public List<CabinDTO> getCabins() {
		return cabins;
	}

	public void setCabins(List<CabinDTO> cabins) {
		this.cabins = cabins;
	}

	public boolean isEdited() {
		return edited;
	}

	public void setEdited(boolean edited) {
		this.edited = edited;
	}

	public List<Change> getChanges() {
		return changes;
	}

	public void setChanges(List<Change> changes) {
		this.changes = changes;
	}

	@Override
	public String toString() {
		return "MyUserDTO [id=" + id + ", firstName=" + firstName + ", lastName=" + lastName + ", email=" + email
				+ ", phoneNumber=" + phoneNumber + ", streetAdress=" + streetAdress + ", city=" + city + ", country="
				+ country + ", dateTimeCreated=" + dateTimeCreated + ", cabins=" + cabins + "]";
	}
	
	
	
}
