package com.snplog.backend.dto;

import java.sql.Timestamp;
import java.util.List;

import com.snplog.backend.entity.Change;

/**
 * 
 * PlowerCabinAreaDTO class is a Data Transfer Object class.
 * This class models the data that is to be transfered to end users
 * Based upon the {@link.com.snplog.backend.entity.PlowerCabinArea} entity class.
 * 
 * @author Theodor Urtegård
 *
 */
public class PlowerCabinAreaDTO {
	
	private int id;
	
	private MyUserDTO plower;
	
	private CabinAreaDTO cabinArea;
	
	private boolean valid;
	
	private Timestamp dateCreated;
	
	private Timestamp dateEnded;
	
	/**
	 * Boolean value to hold information if the entity should be updated
	 * (May be redundant)
	 */
	private boolean edited;
	
	/**
	 * A list to hold {@link.com.snplog.backend.entity.Change} objects. 
	 * This helps with auditing when the object is returned with changes to its fields.
	 */
	private List<Change> changes;

	public PlowerCabinAreaDTO() {}

	/**
	 * 
	 * @param id
	 * @param plower
	 * @param cabinArea
	 * @param valid
	 * @param dateCreated
	 * @param dateEnded
	 */
	public PlowerCabinAreaDTO(int id, MyUserDTO plower, CabinAreaDTO cabinArea, boolean valid, Timestamp dateCreated,
			Timestamp dateEnded) {
		super();
		this.id = id;
		this.plower = plower;
		this.cabinArea = cabinArea;
		this.valid = valid;
		this.dateCreated = dateCreated;
		this.dateEnded = dateEnded;
		this.edited = false;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public MyUserDTO getPlower() {
		return plower;
	}

	public void setPlower(MyUserDTO plower) {
		this.plower = plower;
	}

	public CabinAreaDTO getCabinArea() {
		return cabinArea;
	}

	public void setCabinArea(CabinAreaDTO cabinArea) {
		this.cabinArea = cabinArea;
	}

	public boolean isValid() {
		return valid;
	}

	public void setValid(boolean valid) {
		this.valid = valid;
	}

	public Timestamp getDateCreated() {
		return dateCreated;
	}

	public void setDateCreated(Timestamp dateCreated) {
		this.dateCreated = dateCreated;
	}

	public Timestamp getDateEnded() {
		return dateEnded;
	}

	public void setDateEnded(Timestamp dateEnded) {
		this.dateEnded = dateEnded;
	}

	public boolean isEdited() {
		return edited;
	}

	public void setEdited(boolean edited) {
		this.edited = edited;
	}

	public List<Change> getChanges() {
		return changes;
	}

	public void setChanges(List<Change> changes) {
		this.changes = changes;
	}

	@Override
	public String toString() {
		return "PlowerCabinAreaDTO [id=" + id + ", plower=" + plower + ", cabinArea=" + cabinArea + ", valid=" + valid
				+ ", dateCreated=" + dateCreated + ", dateEnded=" + dateEnded + "]";
	}
	
	
	

}
