package com.snplog.backend.dto;

import java.sql.Timestamp;
import java.util.List;

import com.snplog.backend.entity.Change;

/**
 * 
 * PlowerRequestDTO class is a Data Transfer Object class.
 * This class models the data that is to be transfered to end users
 * Based upon the {@link.com.snplog.backend.entity.PlowerRequest} entity class.
 * 
 * @author Theodor Urtegård
 *
 */
public class PlowerRequestDTO {

	private int id;
	
	private MyUserDTO myUser;
	
	private Timestamp dateRequested;
	
	private Timestamp dateResponded;
	
	private boolean status;
	
	/**
	 * Boolean value to hold information if the entity should be updated
	 * (May be redundant)
	 */
	private boolean edited;
	
	/**
	 * A list to hold {@link.com.snplog.backend.entity.Change} objects. 
	 * This helps with auditing when the object is returned with changes to its fields.
	 */
	private List<Change> changes;
	
	public PlowerRequestDTO() {}

	public PlowerRequestDTO(int id, MyUserDTO myUser, Timestamp dateRequested, Timestamp dateResponded,
			boolean status) {
		super();
		this.id = id;
		this.myUser = myUser;
		this.dateRequested = dateRequested;
		this.dateResponded = dateResponded;
		this.status = status;
		this.edited = false;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public MyUserDTO getMyUser() {
		return myUser;
	}

	public void setMyUser(MyUserDTO myUser) {
		this.myUser = myUser;
	}

	public Timestamp getDateRequested() {
		return dateRequested;
	}

	public void setDateRequested(Timestamp dateRequested) {
		this.dateRequested = dateRequested;
	}

	public Timestamp getDateResponded() {
		return dateResponded;
	}

	public void setDateResponded(Timestamp dateResponded) {
		this.dateResponded = dateResponded;
	}

	public boolean isStatus() {
		return status;
	}

	public void setStatus(boolean status) {
		this.status = status;
	}

	public boolean isEdited() {
		return edited;
	}

	public void setEdited(boolean edited) {
		this.edited = edited;
	}

	public List<Change> getChanges() {
		return changes;
	}

	public void setChanges(List<Change> changes) {
		this.changes = changes;
	}

	@Override
	public String toString() {
		return "PlowerRequestDTO [id=" + id + ", myUser=" + myUser + ", dateRequested=" + dateRequested
				+ ", dateResponded=" + dateResponded + ", status=" + status + "]";
	}
	
	
	
}
