package com.snplog.backend.dto;

import java.sql.Timestamp;
import java.util.List;

import com.snplog.backend.entity.Change;

/**
 * 
 * PlowingRequestDTO class is a Data Transfer Object class.
 * This class models the data that is to be transfered to end users
 * Based upon the {@link.com.snplog.backend.entity.PlowingRequest} entity class.
 * 
 * @author Theodor Urtegård
 *
 */
public class PlowingRequestDTO {
	
	private int id;
	
	private CabinDTO cabin;
	
	private CabinAreaDTO cabinArea;
	
	private Timestamp dateOfArrival;
	
	private Timestamp dateOfDeparture;
	
	private Timestamp dateRequested;
	
	private Timestamp dateCompleted;
	
	private boolean completed;
	
	private String description;
	
	/**
	 * Boolean value to hold information if the entity should be updated
	 * (May be redundant)
	 */
	private boolean edited;
	
	/**
	 * A list to hold {@link.com.snplog.backend.entity.Change} objects. 
	 * This helps with auditing when the object is returned with changes to its fields.
	 */
	private List<Change> changes;
	
	public PlowingRequestDTO() {}

	/**
	 * 
	 * @param id
	 * @param cabin
	 * @param cabinArea
	 * @param dateOfArrival
	 * @paran dateOfDeparture
	 * @param dateRequested
	 * @param dateCompleted
	 * @param completed
	 * @param description
	 */
	public PlowingRequestDTO(int id, CabinDTO cabin, CabinAreaDTO cabinArea, Timestamp dateOfArrival, Timestamp dateOfDeparture, Timestamp dateRequested,
			Timestamp dateCompleted, boolean completed, String description) {
		super();
		this.id = id;
		this.cabin = cabin;
		this.cabinArea = cabinArea;
		this.dateOfArrival = dateOfArrival;
		this.dateOfDeparture = dateOfDeparture;
		this.dateRequested = dateRequested;
		this.dateCompleted = dateCompleted;
		this.completed = completed;
		this.description = description;
		this.edited = false;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public CabinDTO getCabin() {
		return cabin;
	}

	public void setCabin(CabinDTO cabin) {
		this.cabin = cabin;
	}

	public CabinAreaDTO getCabinArea() {
		return cabinArea;
	}

	public void setCabinArea(CabinAreaDTO cabinArea) {
		this.cabinArea = cabinArea;
	}

	public Timestamp getDateRequested() {
		return dateRequested;
	}

	public void setDateRequested(Timestamp dateRequested) {
		this.dateRequested = dateRequested;
	}

	public Timestamp getDateCompleted() {
		return dateCompleted;
	}

	public void setDateCompleted(Timestamp dateCompleted) {
		this.dateCompleted = dateCompleted;
	}

	public boolean isCompleted() {
		return completed;
	}

	public void setCompleted(boolean completed) {
		this.completed = completed;
	}

	public String getDescription() {
		return description;
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public boolean isEdited() {
		return edited;
	}

	public void setEdited(boolean edited) {
		this.edited = edited;
	}

	public List<Change> getChanges() {
		return changes;
	}

	public void setChanges(List<Change> changes) {
		this.changes = changes;
	}
	
	

	public Timestamp getDateOfArrival() {
		return dateOfArrival;
	}

	public void setDateOfArrival(Timestamp dateOfArrival) {
		this.dateOfArrival = dateOfArrival;
	}
	
	

	public Timestamp getDateOfDeparture() {
		return dateOfDeparture;
	}

	public void setDateOfDeparture(Timestamp dateOfDeparture) {
		this.dateOfDeparture = dateOfDeparture;
	}

	@Override
	public String toString() {
		return "PlowingRequestDTO [id=" + id + ", cabin=" + cabin + ", cabinArea=" + cabinArea + ", dateOfArrival="
				+ dateOfArrival + ", dateOfDeparture=" + dateOfDeparture + ", dateRequested=" + dateRequested
				+ ", dateCompleted=" + dateCompleted + ", completed=" + completed + ", description=" + description
				+ ", edited=" + edited + ", changes=" + changes + "]";
	}

	
	
	
	
}
