package com.snplog.backend.dto;

import java.sql.Timestamp;
import java.util.List;

import com.snplog.backend.entity.Change;

/**
 * 
 * WeatherStationDTO class is a Data Transfer Object class.
 * This class models the data that is to be transfered to end users
 * Based upon the {@link.com.snplog.backend.entity.WeatherStation} entity class.
 * 
 * @author Theodor Urtegård
 *
 */
public class WeatherStationDTO {

	private int id;
	
	private Timestamp created;
	
	private String frostId;
	
	private double longitude;
	
	private double latitude;
	
	private List<CabinAreaDTO> cabinAreas;
	
	private List<SnowStatisticDTO> snowStatistics;
	
	/**
	 * Boolean value to hold information if the entity should be updated
	 * (May be redundant)
	 */
	private boolean edited;
	
	/**
	 * A list to hold {@link.com.snplog.backend.entity.Change} objects. 
	 * This helps with auditing when the object is returned with changes to its fields.
	 */
	private List<Change> changes;
	
	public WeatherStationDTO() {}

	/**
	 * 
	 * @param id
	 * @param created
	 * @param frostId
	 * @param longitude
	 * @param latitude
	 * @param cabinAreas
	 * @param snowStatistics
	 */
	public WeatherStationDTO(int id, Timestamp created, String frostId, double longitude, double latitude,
			List<CabinAreaDTO> cabinAreas, List<SnowStatisticDTO> snowStatistics) {
		super();
		this.id = id;
		this.created = created;
		this.frostId = frostId;
		this.longitude = longitude;
		this.latitude = latitude;
		this.cabinAreas = cabinAreas;
		this.snowStatistics = snowStatistics;
		this.edited = false;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public Timestamp getCreated() {
		return created;
	}

	public void setCreated(Timestamp created) {
		this.created = created;
	}

	public String getFrostId() {
		return frostId;
	}

	public void setFrostId(String frostId) {
		this.frostId = frostId;
	}

	public double getLongitude() {
		return longitude;
	}

	public void setLongitude(double longitude) {
		this.longitude = longitude;
	}

	public double getLatitude() {
		return latitude;
	}

	public void setLatitude(double latitude) {
		this.latitude = latitude;
	}

	public List<CabinAreaDTO> getCabinAreas() {
		return cabinAreas;
	}

	public void setCabinAreas(List<CabinAreaDTO> cabinAreas) {
		this.cabinAreas = cabinAreas;
	}

	public List<SnowStatisticDTO> getSnowStatistics() {
		return snowStatistics;
	}

	public void setSnowStatistics(List<SnowStatisticDTO> snowStatistics) {
		this.snowStatistics = snowStatistics;
	}

	public boolean isEdited() {
		return edited;
	}

	public void setEdited(boolean edited) {
		this.edited = edited;
	}

	public List<Change> getChanges() {
		return changes;
	}

	public void setChanges(List<Change> changes) {
		this.changes = changes;
	}

	@Override
	public String toString() {
		return "WeatherStationDTO [id=" + id + ", created=" + created + ", frostId=" + frostId + ", longitude="
				+ longitude + ", latitude=" + latitude + ", cabinAreas=" + cabinAreas + ", snowStatistics="
				+ snowStatistics + "]";
	}
	
	
	
}
