package com.snplog.backend.entity;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.GeneratedValue;
import javax.persistence.GenerationType;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.OneToMany;
import javax.persistence.Table;

import com.snplog.backend.dto.CabinAreaDTO;

@Entity
@Table(name="cabin_areas")
public class CabinArea {

	@Id
	@GeneratedValue(strategy=GenerationType.IDENTITY)
	@Column(name="id")
	private int id;
	
	@Column(name="cabin_area_name")
	private String name;
	
	@Column(name="created")
	private Timestamp created;
	
	// TODO check how we want to define cabin areas later
	@Column(name="longitude")
	private double longitude;
	
	@Column(name="latitude")
	private double latitude;
	
	@Column(name="radius")
	private int radius;
	
	@ManyToOne(fetch = FetchType.LAZY)
	@JoinColumn(name="nearest_weather_station")
	private WeatherStation nearestWeatherStation;
	
	@OneToMany(
			mappedBy = "cabinArea",
			cascade = CascadeType.ALL,
			orphanRemoval = true,
			fetch = FetchType.LAZY
			)
	private List<PlowingRequest> plowingRequests = new ArrayList<>();
	
	@OneToMany(
			mappedBy = "cabinArea",
			cascade = CascadeType.ALL,
			orphanRemoval = true,
			fetch = FetchType.LAZY
			)
	private List<PlowerCabinArea> plowerCabinAreas = new ArrayList<>();
	
	@OneToMany(
			mappedBy="cabinArea",
			cascade = CascadeType.ALL,
			orphanRemoval = true,
			fetch = FetchType.LAZY
			)
	private List<Cabin> cabins = new ArrayList<>();

	public CabinArea() {
	}

	public CabinArea(String name, Timestamp created, double longitude, double latitude, int radius) {
		super();
		this.name = name;
		this.created = created;
		this.longitude = longitude;
		this.latitude = latitude;
		this.radius = radius;
	}

	public int getId() {
		return id;
	}

	public void setId(int id) {
		this.id = id;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Timestamp getCreated() {
		return created;
	}

	public void setCreated(Timestamp created) {
		this.created = created;
	}

	public double getLongitude() {
		return longitude;
	}

	public void setLongitude(double longitude) {
		this.longitude = longitude;
	}

	public double getLatitude() {
		return latitude;
	}

	public void setLatitude(double latitude) {
		this.latitude = latitude;
	}

	public int getRadius() {
		return radius;
	}

	public void setRadius(int radius) {
		this.radius = radius;
	}
	
	
	public List<PlowerCabinArea> getPlowerCabinAreas() {
		return plowerCabinAreas;
	}

	public void setPlowerCabinAreas(List<PlowerCabinArea> plowerCabinAreas) {
		this.plowerCabinAreas = plowerCabinAreas;
	}

	public List<Cabin> getCabins() {
		return cabins;
	}

	public void setCabins(List<Cabin> cabins) {
		this.cabins = cabins;
	}

	public WeatherStation getNearestWeatherStation() {
		return nearestWeatherStation;
	}

	public void setNearestWeatherStation(WeatherStation nearestWeatherStation) {
		this.nearestWeatherStation = nearestWeatherStation;
	}

	public List<PlowingRequest> getPlowingRequests() {
		return plowingRequests;
	}

	public void setPlowingRequests(List<PlowingRequest> plowingRequests) {
		this.plowingRequests = plowingRequests;
	}

	@Override
	public String toString() {
		return "CabinArea [id=" + id + ", name=" + name + ", created=" + created + ", longitude=" + longitude
				+ ", latitude=" + latitude + ", radius=" + radius + ", nearestWeatherStation=" + nearestWeatherStation
				+ "]";
	}
	
	
}
