package com.snplog.backend.rest;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.snplog.backend.dto.CabinAreaDTO;
import com.snplog.backend.entity.CabinArea;
import com.snplog.backend.models.GetByIdIntRequest;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.services.CabinAreaService;
import com.snplog.backend.services.misc.JpaDtoMapper;
import com.snplog.backend.services.misc.JwtUtil;
import com.snplog.backend.services.misc.WeatherService;

/**
 * 
 * @author Theodor Urtegård
 * 
 * Rest controller for {@link.com.snplog.backend.entity.CabinArea} entity.
 *
 */
@RestController
@RequestMapping("/cabinarea")
public class CabinAreaRestController {

	@Autowired
	private CabinAreaService cabinAreaService;
	
	@Autowired
	private JwtUtil jwtUtil;
	
	@Autowired
	private WeatherService weatherService;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	/**
	 * 
	 * @param request
	 * @param cabinAreaDTO {@link.com.snplog.backend.dto.CabinAreaDTO}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@DeleteMapping("/delete/{id}")
	public ResponseEntity<?> deleteCabinArea(HttpServletRequest request, @PathVariable(value="id") int id) {
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			if (authorizationHeader != null && authorizationHeader.startsWith("Bearer")) {

				String jwt = authorizationHeader.substring(7);

				if (jwtUtil.extractRoles(jwt).contains("admin")) {
					cabinAreaService.deleteCabinAreaById(id);
					return ResponseEntity.ok().build();
				}
			} 
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO: handle exception
			return ResponseEntity.badRequest().build();
		}	
	}
	
	/**
	 * 
	 * @param request
	 * @param cabinArea {@link.com.snplog.backend.entity.CabinArea}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/save")
	public ResponseEntity<?> createCabinArea(HttpServletRequest request, @RequestBody CabinArea cabinArea) {
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
				if(jwtUtil.extractRoles(jwt).contains("admin")){
					cabinAreaService.saveCabinArea(cabinArea);
					weatherService.addWeatherStation(cabinArea);
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(jpaDtoMapper.toDTO(cabinArea));
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param cabinAreaDTO {@link.com.snplog.backend.dto.CabinAreaDTO}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PutMapping("/update")
	public ResponseEntity<?> updateCabinArea(HttpServletRequest request, @RequestBody CabinAreaDTO cabinAreaDTO) {
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
				if(jwtUtil.extractRoles(jwt).contains("admin")){
					cabinAreaService.updateCabinArea(cabinAreaDTO);
					CabinAreaDTO updatedObject = jpaDtoMapper.toDTO(cabinAreaService.getCabinArea(cabinAreaDTO.getId()));
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(updatedObject);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/cabinareas")
	public ResponseEntity<?> getCabinAreas(HttpServletRequest request) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				List<String> roles = jwtUtil.extractRoles(jwt);
			
				
				return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(cabinAreaService.findAll());
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param getByIdIntRequest {@link.com.snplog.backend.models.GetByIdIntRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/cabinarea/{id}")
	public ResponseEntity<?> getCabinArea(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				List<String> roles = jwtUtil.extractRoles(jwt);
			
				if(roles.contains("admin") || roles.contains("plower") || roles.contains("cabinOwner")){
					CabinAreaDTO response = jpaDtoMapper.toDTO(cabinAreaService.getCabinArea(id));
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(response);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param sortedQueryRequest {@link.com.snplog.backend.models.SortedQueryRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/sortedcabinareas")
	public ResponseEntity<?> getSortedCabinAreas(HttpServletRequest request, @RequestBody SortedQueryRequest sortedQueryRequest) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				List<String> roles = jwtUtil.extractRoles(jwt);
				
				List<CabinAreaDTO> cabinAreaDTOs = cabinAreaService.getCabinAreasSortedBy(sortedQueryRequest);
				
				if(cabinAreaDTOs != null) {
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(cabinAreaDTOs);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	
	/**
	 * 
	 * @param request
	 * @param name
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/cabinareasbyname/{name}")
	public ResponseEntity<?> getCabinAreasByNameSortedByName(HttpServletRequest request, @PathVariable(value="name") String name) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				List<String> roles = jwtUtil.extractRoles(jwt);
				
				List<CabinAreaDTO> cabinAreaDTOs = cabinAreaService.getCabinAreasByNameSortedByName(name);
				
				if(cabinAreaDTOs != null) {
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(cabinAreaDTOs);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param getByIdIntRequest {@link.com.snplog.backend.models.GetByIdIntRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/myuser/{id}")
	public ResponseEntity<?> getCabinAreasByUserId(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				List<String> roles = jwtUtil.extractRoles(jwt);
			
				if(roles.contains("admin") || roles.contains("plower")){
					List<CabinAreaDTO> cabinAreaDTOs = cabinAreaService.getCabinAreasByPlowerId(id);
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(cabinAreaDTOs);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
}
