package com.snplog.backend.rest;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.snplog.backend.dto.CabinDTO;
import com.snplog.backend.entity.Cabin;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.services.CabinService;
import com.snplog.backend.services.MyUserService;
import com.snplog.backend.services.misc.JpaDtoMapper;
import com.snplog.backend.services.misc.JwtUtil;

/**
 * 
 * @author Theodor Urtegård
 * 
 * Rest controller for {@link.com.snplog.backend.entity.Cabin} entity.
 *
 */

@RestController
@RequestMapping("/cabin")
public class CabinRestController {
	
	@Autowired
	private CabinService cabinService;
	
	@Autowired
	private JwtUtil jwtUtil;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	@Autowired
	private MyUserService myUserService;
	
	/**
	 * 
	 * @param request
	 * @param cabinDTO {@link.com.snplog.backend.dto.CabinDTO}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@DeleteMapping("/delete/{id}")
	public ResponseEntity<?> deleteCabin(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
			
				if(jwtUtil.extractRoles(jwt).contains("admin") || jwtUtil.extractRoles(jwt).contains("cabinOwner")){
					cabinService.deleteCabinById(id);
					return ResponseEntity.ok().build();
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param cabin {@link.com.snplog.backend.entity.Cabin}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/create")
	public ResponseEntity<?> saveCabin(HttpServletRequest request, @RequestBody Cabin cabin) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				cabinService.saveCabin(cabin);
				cabinService.addLocation(cabin);
				return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(jpaDtoMapper.toDTO(cabin));
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param cabinDTO {@link.com.snplog.backend.dto.CabinDTO}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PutMapping("/update")
	public ResponseEntity<?> updateCabin(HttpServletRequest request, @RequestBody CabinDTO cabinDTO) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				if(jwtUtil.extractUsername(jwt).equals(cabinDTO.getMyUserDTO().getEmail())) {
					cabinService.updateCabin(cabinDTO);
					CabinDTO updatedObect = cabinService.getCabin(cabinDTO.getId());
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(updatedObect);
				}
			
				if(jwtUtil.extractRoles(jwt).contains("admin")){
					cabinService.updateCabin(cabinDTO);
					CabinDTO updatedObect = cabinService.getCabin(cabinDTO.getId());
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(updatedObect);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param getByIdIntRequest {@link.com.snplog.backend.models.GetByIdIntRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/cabin/{id}")
	public ResponseEntity<?> getCabin(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				CabinDTO cabinDTO = cabinService.getCabin(id);
				
				if(cabinDTO != null) {
					if(jwtUtil.extractRoles(jwt).contains("admin") || jwtUtil.extractRoles(jwt).contains("plower") || jwtUtil.extractUsername(jwt).contains(cabinDTO.getMyUserDTO().getEmail())){
						return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(cabinDTO);
					}
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/cabins")
	public ResponseEntity<?> getCabins(HttpServletRequest request) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				if(jwtUtil.extractRoles(jwt).contains("admin") || jwtUtil.extractRoles(jwt).contains("plower")){
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(cabinService.findAll());
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param myUserDTO {@link.com.snplog.backend.entity.MyUser}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/cabinsbyuser/{id}")
	public ResponseEntity<?> getCabinsByMyUser(HttpServletRequest request, @PathVariable(value="id") int id){
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer")) {
				
				String jwt = authorizationHeader.substring(7);
				
				if(jwtUtil.extractRoles(jwt).contains("admin") || jwtUtil.extractRoles(jwt).contains("cabinOwner")) {
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(cabinService.getCabinsByMyUser(id));
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param sortedQueryRequest {@link.com.snplog.backend.models.SortedQueryRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/sortedcabins")
	public ResponseEntity<?> getSortedCabins(HttpServletRequest request, @RequestBody SortedQueryRequest sortedQueryRequest) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			if (authorizationHeader != null && authorizationHeader.startsWith("Bearer")) {

				String jwt = authorizationHeader.substring(7);

				List<String> roles = jwtUtil.extractRoles(jwt);

				List<CabinDTO> cabinDTOs = cabinService.getCabinsSortedBy(sortedQueryRequest);

				if (cabinDTOs != null) {
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8")
							.body(cabinDTOs);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO: handle exception
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param cabinName
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/getcabinsbyname/{name}")
	public ResponseEntity<?> getCabinsByCabinNameSortedByCabinName(HttpServletRequest request, @PathVariable(value="name") String name) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				List<String> roles = jwtUtil.extractRoles(jwt);
				
				List<CabinDTO> cabinDTOs = cabinService.getCabinsByCabinNameSortedByCabinName(name);
				
				if(cabinDTOs != null) {
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(cabinDTOs);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	
}
