package com.snplog.backend.rest;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.snplog.backend.dto.MessageThreadDTO;
import com.snplog.backend.entity.MessageThread;
import com.snplog.backend.models.GetByIdIntRequest;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.services.MessageThreadService;
import com.snplog.backend.services.misc.JpaDtoMapper;
import com.snplog.backend.services.misc.JwtUtil;

/**
 * 
 * @author Theodor Urtegård
 * 
 * Rest controller for {@link.com.snplog.backend.entity.MessageThread} entity.
 *
 */
@RestController
@RequestMapping("/messageThread")
public class MessageThreadRestController {

	@Autowired
	private MessageThreadService messageThreadService;
	
	@Autowired
	private JwtUtil jwtUtil;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	/**
	 * 
	 * @param request
	 * @param messageThreadDTO {@link.com.snplog.backend.dto.MessageThreadDTO}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@DeleteMapping("/delete/{id}")
	public ResponseEntity<?> deleteMessageThread(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				if(jwtUtil.extractRoles(jwt).contains("admin")){
					messageThreadService.deleteMessageThreadById(id);
					return ResponseEntity.ok().build();
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request 
	 * @param messageThread {@link.com.snplog.backend.entity.MessageThread}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/save")
	public ResponseEntity<?> saveMessageThread(HttpServletRequest request, @RequestBody MessageThread messageThread) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				
				messageThreadService.saveMessageThread(messageThread);
				return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(jpaDtoMapper.toDTO(messageThread));
				
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param getByIdIntRequest {@link.com.snplog.backend.models.GetByIdIntRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/messageThread/{id}")
	public ResponseEntity<?> getMessageThread(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
							
				return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(messageThreadService.getMessageThread(id));
				
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/messageThreads")
	public ResponseEntity<?> getMessageThreads(HttpServletRequest request) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				if(jwtUtil.extractRoles(jwt).contains("admin")){
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(messageThreadService.findAll());
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param sortedQueryRequest {@link.com.snplog.backend.models.SortedQueryRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/sortedmessagethreads")
	public ResponseEntity<?> getSortedMessageThreads(HttpServletRequest request, @RequestBody SortedQueryRequest sortedQueryRequest) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				List<String> roles = jwtUtil.extractRoles(jwt);
				
				List<MessageThreadDTO> messageThreadDTOs = messageThreadService.getMessageThreadsSortedBy(sortedQueryRequest);
				
				if(messageThreadDTOs != null) {
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(messageThreadDTOs);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
}
