package com.snplog.backend.rest;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.snplog.backend.dto.PlowerCabinAreaDTO;
import com.snplog.backend.entity.PlowerCabinArea;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.services.MyUserService;
import com.snplog.backend.services.PlowerCabinAreaService;
import com.snplog.backend.services.misc.JpaDtoMapper;
import com.snplog.backend.services.misc.JwtUtil;

/**
 * 
 * @author Theodor Urtegård
 * 
 * Rest controller for {@link.com.snplog.backend.entity.PlowerCabinArea} entity.
 *
 */
@RestController
@RequestMapping("/plowercabinarea")
public class PlowerCabinAreaRestController {
	
	@Autowired
	private PlowerCabinAreaService plowerCabinAreaService;
	
	@Autowired
	private JwtUtil jwtUtil;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	@Autowired
	private MyUserService myUserService;
	
	/**
	 * 
	 * @param request
	 * @param plowerCabinAreaDTO {@link.com.snplog.backend.dto.PlowerCabinAreaDTO}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@DeleteMapping("/delete/{id}")
	public ResponseEntity<?> deletePlowerCabinArea(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
				if(jwtUtil.extractRoles(jwt).contains("admin")){
					plowerCabinAreaService.deletePlowerCabinAreaById(id);
					return ResponseEntity.ok().build();
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param plowerCabinArea {@link.com.snplog.backend.entity.PlowerCabinArea}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/create")
	public ResponseEntity<?> savePlowerCabinArea(HttpServletRequest request, @RequestBody PlowerCabinArea plowerCabinArea) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
				if(jwtUtil.extractRoles(jwt).contains("admin")){
					plowerCabinAreaService.savePlowerCabinArea(plowerCabinArea);
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(jpaDtoMapper.toDTO(plowerCabinArea));
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param sortedQueryRequest {@link.com.snplog.backend.models.SortedQueryRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/sortedplowercabinreas")
	public ResponseEntity<?> getSortedPlowerCabinAreas(HttpServletRequest request, @RequestBody SortedQueryRequest sortedQueryRequest) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				List<String> roles = jwtUtil.extractRoles(jwt);
				
				List<PlowerCabinAreaDTO> plowerCabinAreaDTOs = plowerCabinAreaService.getPlowerCabinAreasSortedBy(sortedQueryRequest);
				
				if(plowerCabinAreaDTOs != null) {
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(plowerCabinAreaDTOs);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param int id
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("plower/{id}")
	public ResponseEntity<?> getSortedPlowerCabinAreas(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				List<String> roles = jwtUtil.extractRoles(jwt);
				
				if(jwtUtil.extractRoles(jwt).contains("plower")) {
					
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}

}
