package com.snplog.backend.rest;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.snplog.backend.dto.PlowerPositionDTO;
import com.snplog.backend.entity.PlowerPosition;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.services.PlowerPositionService;
import com.snplog.backend.services.misc.JwtUtil;

/**
 * 
 * @author Theodor Urtegård
 * 
 * Rest controller for {@link.com.snplog.backend.entity.PlowerPosition} entity.
 *
 */
@RestController
@RequestMapping("/plowerposition")
public class PlowerPositionRestController {
	
	@Autowired
	private PlowerPositionService plowerPositionService;
	
	@Autowired
	private JwtUtil jwtUtil;
	
	/**
	 * 
	 * @param request
	 * @param plowerPosition {@link.com.snplog.backend.entity.PlowerPosition}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/save")
	public ResponseEntity<?> savePlowerPosition(HttpServletRequest request, @RequestBody PlowerPosition plowerPosition) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
				if(jwtUtil.extractRoles(jwt).contains("plower")){
					plowerPositionService.savePlowerPosition(plowerPosition);
					return ResponseEntity.ok().build();
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/plowerpositions")
	public ResponseEntity<?> getPlowerPositions(HttpServletRequest request) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				if(jwtUtil.extractRoles(jwt).contains("admin")){
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(plowerPositionService.findAll());
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}

	/**
	 * 
	 * @param request
	 * @param sortedQueryRequest {@link.com.snplog.backend.models.SortedQueryRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/sortedplowerpositions")
	public ResponseEntity<?> getSortedPlowerPositions(HttpServletRequest request, @RequestBody SortedQueryRequest sortedQueryRequest) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				List<String> roles = jwtUtil.extractRoles(jwt);
				
				List<PlowerPositionDTO> plowerPositionDTOs = plowerPositionService.getPlowerPositionsSortedBy(sortedQueryRequest);
				
				if(plowerPositionDTOs != null) {
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(plowerPositionDTOs);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
}
