package com.snplog.backend.rest;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.snplog.backend.dto.PlowerRequestDTO;
import com.snplog.backend.entity.Change;
import com.snplog.backend.entity.MyUser;
import com.snplog.backend.entity.PlowerRequest;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.services.MyUserService;
import com.snplog.backend.services.PlowerRequestService;
import com.snplog.backend.services.misc.JpaDtoMapper;
import com.snplog.backend.services.misc.JwtUtil;

/**
 * 
 * @author Theodor Urtegård
 * 
 * Rest controller for {@link.com.snplog.backend.entity.PlowerRequest} entity.
 *
 */
@RestController
@RequestMapping("/plowerrequest")
public class PlowerRequestRestController {
	
	@Autowired
	private  PlowerRequestService  plowerRequestService;
	
	@Autowired
	private JwtUtil jwtUtil;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	@Autowired
	private MyUserService myUserService;
	
	/**
	 * 
	 * @param request
	 * @param cabinAreaDTO {@link.com.snplog.backend.dto.PlowerRequestDTO}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@DeleteMapping("/delete/{id}")
	public ResponseEntity<?> deletePlowerRequest(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
				if(jwtUtil.extractRoles(jwt).contains("admin") || jwtUtil.extractRoles(jwt).contains("plower")){
					plowerRequestService.deletePlowerRequestById(id);
					return ResponseEntity.ok().build();
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param cabinArea {@link.com.snplog.backend.entity.PlowerRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/create")
	public ResponseEntity<?> savePlowerRequest(HttpServletRequest request, @RequestBody PlowerRequest plowerRequest) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				plowerRequestService.savePlowerRequest(plowerRequest);
				return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(jpaDtoMapper.toDTO(plowerRequest));
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param cabinAreaDTO {@link.com.snplog.backend.dto.PlowerRequestDTO}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PutMapping("/update")
	public ResponseEntity<?> updatePlowerRequest(HttpServletRequest request, @RequestBody PlowerRequestDTO plowerRequestDTO) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
				if(jwtUtil.extractRoles(jwt).contains("admin")){
					MyUser myUser = myUserService.getMyUserByEmail(jwtUtil.extractUsername(jwt));
					
					for(Change change : plowerRequestDTO.getChanges()) {
						change.setChangedBy(myUser);
					}
					if(plowerRequestDTO.isEdited() && plowerRequestDTO.isStatus()) {
						myUserService.addPlowerRole(myUserService.getMyUserById(plowerRequestDTO.getMyUser().getId()));
					}
					
					plowerRequestService.updatePlowerRequest(plowerRequestDTO);
					PlowerRequestDTO updatedObject = plowerRequestService.getPlowerRequest(plowerRequestDTO.getId());
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(updatedObject);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param getByIdIntRequest {@link.com.snplog.backend.models.GetByIdIntRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/plowerrequest/{id}")
	public ResponseEntity<?> getPlowerRequest(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				PlowerRequestDTO plowerRequestDTO = plowerRequestService.getPlowerRequest(id);
				
				if(plowerRequestDTO != null) {
					if(jwtUtil.extractRoles(jwt).contains("admin") || jwtUtil.extractRoles(jwt).contains("plower")){
						return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(plowerRequestDTO);
					}
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/plowerrequests")
	public ResponseEntity<?> getPlowerRequests(HttpServletRequest request) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				if(jwtUtil.extractRoles(jwt).contains("admin") || jwtUtil.extractRoles(jwt).contains("plower")){
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(plowerRequestService.findActivePlowerRequests());
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param sortedQueryRequest {@link.com.snplog.backend.models.SortedQueryRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/sortedplowerrequests")
	public ResponseEntity<?> getSortedPlowerRequests(HttpServletRequest request, @RequestBody SortedQueryRequest sortedQueryRequest) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				List<String> roles = jwtUtil.extractRoles(jwt);
				
				List<PlowerRequestDTO> plowerRequestDTOs = plowerRequestService.getPlowerRequestsSortedBy(sortedQueryRequest);
				
				if(plowerRequestDTOs != null) {
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(plowerRequestDTOs);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
}
