package com.snplog.backend.rest;

import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.snplog.backend.dto.PlowingRequestDTO;
import com.snplog.backend.entity.PlowingRequest;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.services.PlowingRequestService;
import com.snplog.backend.services.misc.JpaDtoMapper;
import com.snplog.backend.services.misc.JwtUtil;

/**
 * 
 * @author Theodor Urtegård
 * 
 * Rest controller for {@link.com.snplog.backend.entity.PlowingRequest} entity.
 *
 */
@RestController
@RequestMapping("/plowingrequest")
public class PlowingRequestRestController {

	@Autowired
	private PlowingRequestService plowingRequestService;
	
	@Autowired
	private JwtUtil jwtUtil;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	/**
	 * 
	 * @param request
	 * @param plowingRequest {@link.com.snplog.backend.entity.PlowingRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/create")
	public ResponseEntity<?> savePlowingRequest(HttpServletRequest request, @RequestBody PlowingRequest plowingRequest) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
				if(jwtUtil.extractRoles(jwt).contains("cabinOwner")){
					plowingRequestService.savePlowingRequest(plowingRequest);
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(jpaDtoMapper.toDTO(plowingRequest));
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param plowingRequest {@link.com.snplog.backend.entity.PlowingRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PutMapping("/update")
	public ResponseEntity<?> updatePlowingRequest(HttpServletRequest request, @RequestBody PlowingRequestDTO plowingRequestDTO) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
				if(jwtUtil.extractRoles(jwt).contains("cabinOwner") || jwtUtil.extractRoles(jwt).contains("plower")){
					plowingRequestService.updatePlowingRequest(plowingRequestDTO);
					PlowingRequestDTO updatedObject = plowingRequestService.getPlowingRequest(plowingRequestDTO.getId());
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(jpaDtoMapper.toDTO(updatedObject));
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/plowingrequests")
	public ResponseEntity<?> getPlowingRequests(HttpServletRequest request) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				if(jwtUtil.extractRoles(jwt).contains("admin") || jwtUtil.extractRoles(jwt).contains("plower")){
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(plowingRequestService.findAll());
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param getByIdIntRequest {@link.com.snplog.backend.models.GetByIdIntRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/{id}")
	public ResponseEntity<?> getPlowingRequest(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				if(jwtUtil.extractRoles(jwt).contains("admin") || jwtUtil.extractRoles(jwt).contains("plower") || jwtUtil.extractRoles(jwt).contains("cabinOwner")){
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(plowingRequestService.getPlowingRequest(id));
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param cabinAreaDTO {@link.com.snplog.backend.dto.PlowingRequestDTO}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@DeleteMapping("/delete/{id}")
	public ResponseEntity<?> deletePlowingRequest(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
				if(jwtUtil.extractRoles(jwt).contains("admin") || jwtUtil.extractRoles(jwt).contains("cabinOwner")){
					plowingRequestService.deletePlowingRequestById(id);
					return ResponseEntity.ok().build();
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param sortedQueryRequest {@link.com.snplog.backend.models.SortedQueryRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/sortedplowingrequests")
	public ResponseEntity<?> getSortedPlowingRequests(HttpServletRequest request, @RequestBody SortedQueryRequest sortedQueryRequest) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				List<String> roles = jwtUtil.extractRoles(jwt);
				
				List<PlowingRequestDTO> plowingRequestDTOs = plowingRequestService.getPlowingRequestsSortedBy(sortedQueryRequest);
				
				if(plowingRequestDTOs != null) {
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(plowingRequestDTOs);
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param int id
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/cabin/{id}")
	public ResponseEntity<?> getPlowingRequestsByCabinId(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				if(jwtUtil.extractRoles(jwt).contains("admin") || jwtUtil.extractRoles(jwt).contains("plower") || jwtUtil.extractRoles(jwt).contains("cabinOwner")){
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(plowingRequestService.getPlowingRequestByCabinId(id));
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param int id
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/cabinarea/{id}")
	public ResponseEntity<?> getPlowingRequestsByCabinAreaId(HttpServletRequest request, @PathVariable(value="id") int id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				if(jwtUtil.extractRoles(jwt).contains("admin") || jwtUtil.extractRoles(jwt).contains("plower")){
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(plowingRequestService.getPlowingRequestsByCabinAreaId(id));
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	

	
}
