package com.snplog.backend.rest;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.snplog.backend.entity.Role;
import com.snplog.backend.models.GetByIdStringRequest;
import com.snplog.backend.services.RoleService;
import com.snplog.backend.services.misc.JpaDtoMapper;
import com.snplog.backend.services.misc.JwtUtil;

/**
 * 
 * @author Theodor Urtegård
 * 
 * Rest controller for {@link.com.snplog.backend.entity.Role} entity.
 *
 */
@RestController
@RequestMapping("/role")
public class RoleRestController {

	@Autowired
	private RoleService roleService;
	
	@Autowired
	private JwtUtil jwtUtil;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	/**
	 * 
	 * @param request
	 * @param cabinAreaDTO {@link.com.snplog.backend.dto.Role}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@DeleteMapping("/delete/{id}")
	public ResponseEntity<?> deleteRole(HttpServletRequest request, @PathVariable(value="id") String id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
				if(jwtUtil.extractRoles(jwt).contains("admin")){
					roleService.deleteRoleById(id);
					return ResponseEntity.ok().build();
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param cabinArea {@link.com.snplog.backend.entity.Role}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@PostMapping("/save")
	public ResponseEntity<?> createRole(HttpServletRequest request, @RequestBody Role role) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
				if(jwtUtil.extractRoles(jwt).contains("admin")){
					roleService.saveRole(role);
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(jpaDtoMapper.toDTO(role));
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/roles")
	public ResponseEntity<?> getRoles(HttpServletRequest request) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
				
				if(jwtUtil.extractRoles(jwt).contains("admin")){
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(roleService.findAll());
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	/**
	 * 
	 * @param request
	 * @param getByIdIntRequest {@link.com.snplog.backend.models.GetByIdStringRequest}
	 * @return ResponseEntity<?>, JSON Object
	 */
	@GetMapping("/role/{id}")
	public ResponseEntity<?> getCabinArea(HttpServletRequest request, @PathVariable(value="id") String id) {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer" )) {
				
				String jwt = authorizationHeader.substring(7);
			
				if(jwtUtil.extractRoles(jwt).contains("admin")){
					return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(roleService.getRole(id));
				}
			}
			return ResponseEntity.badRequest().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
}
