package com.snplog.backend.rest;

import java.util.Date;
import java.util.List;

import javax.servlet.http.HttpServletRequest;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.security.authentication.AuthenticationManager;
import org.springframework.security.authentication.BadCredentialsException;
import org.springframework.security.authentication.UsernamePasswordAuthenticationToken;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.snplog.backend.misc.MyUserPrincipal;
import com.snplog.backend.models.AuthenticationRequest;
import com.snplog.backend.models.AuthenticationResponse;
import com.snplog.backend.models.OtpRequest;
import com.snplog.backend.services.misc.JwtUtil;
import com.snplog.backend.services.misc.MyUserDetailsService;
import com.snplog.backend.services.misc.OtpService;

@RestController
public class SecurityRestController {

	@Autowired
	private AuthenticationManager authenticationManager;
	
	@Autowired
	private MyUserDetailsService userDetailsService;
	
	@Autowired
	private JwtUtil jwtUtil;
	
	@Autowired
	private OtpService otpService;
	

	@RequestMapping( "/hello" )
	public String hello() {
		return "Hello world";
	}
	
	// Authenticate request
	@PostMapping(value="/authenticate")
	public ResponseEntity<?> createAuthenticationToken(@RequestBody AuthenticationRequest authenticationRequest) throws Exception {
		
		
		try {
			authenticationManager.authenticate(
					
					// Default jwt token method, change later?
					new UsernamePasswordAuthenticationToken(authenticationRequest.getUsername(), authenticationRequest.getPassword())
					
			);
			
			final MyUserPrincipal myUserPrincipal = userDetailsService.loadUserByUsername(authenticationRequest.getUsername());
			
			final String jwt = jwtUtil.generateToken(myUserPrincipal);
			
			return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(new AuthenticationResponse(jwt));
			
		} catch (Exception e) {
			return ResponseEntity.badRequest().build();
		}
		
	}
	
	@PostMapping(value="/getOtp")
	public ResponseEntity<?> getOtp(@RequestBody OtpRequest otpRequest) throws Exception {
		System.out.println(otpRequest.getEmail());
		try {
			String email = otpRequest.getEmail();
			otpService.sendOtp(email);
			return ResponseEntity.ok().build();
		} catch (Exception e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
			return ResponseEntity.badRequest().build();
		}
	}
	
	@GetMapping(value="/testJWT")
	public ResponseEntity<?> testJWT(HttpServletRequest request) throws Exception {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer ")) {
				// retrieves jwt where token begins in auth header
				String jwt = authorizationHeader.substring(7);
				String username = jwtUtil.extractUsername(jwt);
				List<String> roles = jwtUtil.extractRoles(jwt);
				String response = username 
						+ "\n\n" + "Admin: " + roles.contains("admin") 
						+ "\n\n" + "Snowplower: " + roles.contains("plower")
						+ "\n\n" + "CabinOwner: " + roles.contains("cabinOwner")
						+ "\n\n is valid (1-true/0-false)   " 
						+ jwtUtil.extractExpiration(jwt).compareTo(new Date())
						+ "Expiration date:  " + jwtUtil.extractExpiration(jwt);
				return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(response);
			} else {
				return ResponseEntity.badRequest().header("Content-Type", "application/json; charset=utf-8").body("User not foudn");
			}
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	@GetMapping(value="/validatejwt")
	public ResponseEntity<?> validatejwt(HttpServletRequest request) throws Exception {
		
		try {
			final String authorizationHeader = request.getHeader("Authorization");
			
			if(authorizationHeader != null && authorizationHeader.startsWith("Bearer ")) {
				// retrieves jwt where token begins in auth header
				String jwt = authorizationHeader.substring(7);
				boolean valid = jwtUtil.isTokenExpired(jwt);
				return ResponseEntity.ok().header("Content-Type", "application/json; charset=utf-8").body(valid);
			} else {
				return ResponseEntity.badRequest().header("Content-Type", "application/json; charset=utf-8").body("User not found");
			}
		} catch (Exception e) {
			// TODO Auto-generated catch block
			return ResponseEntity.badRequest().build();
		}
	}
	
	
	
}
