package com.snplog.backend.services.implementations;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

import com.snplog.backend.dto.CabinAreaDTO;
import com.snplog.backend.entity.CabinArea;
import com.snplog.backend.entity.PlowerCabinArea;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.repository.CabinAreaRepository;
import com.snplog.backend.repository.ChangeRepository;
import com.snplog.backend.repository.MyUserRepository;
import com.snplog.backend.services.CabinAreaService;
import com.snplog.backend.services.misc.JpaDtoMapper;

@Service
public class CabinAreaServiceImpl implements CabinAreaService {
	
	@Autowired
	private CabinAreaRepository cabinAreaRepository;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	@Autowired
	private ChangeRepository changeRepository;
	
	@Autowired
	private MyUserRepository myUserRepository;

	@Override
	public List<CabinAreaDTO> findAll() {
		List<CabinArea> cabinAreas = cabinAreaRepository.findAll();
		
		List<CabinAreaDTO> cabinAreaDTO = new ArrayList<>();
		
		for (CabinArea cabinArea : cabinAreas ) {
			cabinAreaDTO.add(jpaDtoMapper.toDTO(cabinArea));
		}
		return cabinAreaDTO;
	}

	@Override
	public CabinAreaDTO getCabinArea(int id) {
		Optional<CabinArea> result = cabinAreaRepository.findById(id);
		
		CabinArea cabinArea = null;
		
		if(result.isPresent()) {
			cabinArea = result.get();
		} else {
			throw new RuntimeException("Did not find the cabin area id - " + id);
		}
		
		return jpaDtoMapper.toDTO(cabinArea);
	}

	@Override
	public void saveCabinArea(CabinArea cabinArea) {
		cabinAreaRepository.save(cabinArea);
	}


	@Override
	public void deleteCabinArea(CabinAreaDTO cabinAreaDTO) {
		cabinAreaRepository.deleteById(cabinAreaDTO.getId());
	}
	
	@Override
	public void updateCabinArea(CabinAreaDTO cabinAreaDTO) {
		Optional<CabinArea> result = cabinAreaRepository.findById(cabinAreaDTO.getId());
		
		CabinArea cabinArea = null;
		
		if(result.isPresent()) {
			
			if(cabinAreaDTO.isEdited()) {
				cabinArea = jpaDtoMapper.fromDTO(cabinAreaDTO);
				
				cabinAreaRepository.save(cabinArea);
				
				if(cabinAreaDTO.getChanges() != null) {
					changeRepository.saveAll(cabinAreaDTO.getChanges());
				}
			}
		} else {
			throw new RuntimeException("Did not find the cabin id - " + cabinAreaDTO.getId());
		}
		
	}
	
	@Override
	public List<CabinAreaDTO> getCabinAreasSortedBy(SortedQueryRequest sortedQueryRequest) {
		
		List<CabinArea> cabinAreas = null;
		
		if(sortedQueryRequest.getOrder().contains("ASC")) {
			Pageable paging = PageRequest.of(
						sortedQueryRequest.getOffset(),
						sortedQueryRequest.getRowCount(),
						Sort.by(sortedQueryRequest.getColumn()).ascending()
					);
			
			cabinAreas = cabinAreaRepository.findAll(paging).toList();

		} else if (sortedQueryRequest.getOrder().contains("DESC")) {
			Pageable paging = PageRequest.of(
					sortedQueryRequest.getOffset(),
					sortedQueryRequest.getRowCount(),
					Sort.by(sortedQueryRequest.getColumn()).descending()
				);
		
		cabinAreas = cabinAreaRepository.findAll(paging).toList();
		}
		
		if(cabinAreas != null) {
			List<CabinAreaDTO> cabinAreaDTOs = new ArrayList<>();
			
			for(CabinArea cabinArea : cabinAreas) {
				cabinAreaDTOs.add(jpaDtoMapper.toDTO(cabinArea));
			}
			
			return cabinAreaDTOs;
		}
		
		return null;
	}
	
	@Override
	public List<CabinAreaDTO> getCabinAreasByNameSortedByName(String name){
		List<CabinAreaDTO> result = new ArrayList<>();
		List<CabinArea> cabinAreas = cabinAreaRepository.findByNameOrderByName(name);
		for(CabinArea cabinArea : cabinAreas) {
			result.add(jpaDtoMapper.toDTO(cabinArea));
		}
		return result;
	}
	
	@Override
	public void deleteCabinAreaById(int id) {
		cabinAreaRepository.deleteById(id);
	}

	@Override
	public List<CabinAreaDTO> getCabinAreasByPlowerId(int id) {
		List<PlowerCabinArea> plowerCabinAreas = myUserRepository.getOne(id).getPlowerCabinAreas();
		List<CabinAreaDTO> cabinAreas = new ArrayList<>();
		for(PlowerCabinArea pca : plowerCabinAreas) {
			cabinAreas.add(jpaDtoMapper.toDTO(pca.getCabinArea()));
		}
		return cabinAreas;
	}
}
