package com.snplog.backend.services.implementations;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

import com.snplog.backend.dto.ChangeDTO;
import com.snplog.backend.entity.Change;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.repository.ChangeRepository;
import com.snplog.backend.services.ChangeService;
import com.snplog.backend.services.misc.JpaDtoMapper;

@Service
public class ChangeServiceImpl implements ChangeService {
	
	@Autowired
	private ChangeRepository changeRepository;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;

	@Override
	public List<ChangeDTO> findAll() {
		List<Change> changes = changeRepository.findAll();
		
		List<ChangeDTO> changesDTO = new ArrayList<>();
		
		for (Change change : changes ) {
			changesDTO.add(jpaDtoMapper.toDTO(change));
		}
		return changesDTO;
	}

	@Override
	public ChangeDTO getChange(int id) {
		Optional<Change> result = changeRepository.findById(id);
		
		Change change = null;
		
		if(result.isPresent()) {
			change = result.get();
		} else {
			throw new RuntimeException("Did not find the change id - " + id);
		}
		
		return jpaDtoMapper.toDTO(change);
	}

	@Override
	public void saveChange(Change change) {
		changeRepository.save(change);
	}

	@Override
	public void deleteChange(Change change) {
		changeRepository.delete(change);
	}
	
	@Override
	public void updateChange(ChangeDTO changeDTO) {
		Optional<Change> result = changeRepository.findById(changeDTO.getId());
		
		Change change = null;
		
		if(result.isPresent()) {
			change = jpaDtoMapper.fromDTO(changeDTO);
			
			changeRepository.save(change);
			
		} else {
			throw new RuntimeException("Did not find the cabin id - " + changeDTO.getId());
		}
		
	}
	
	@Override
	public List<ChangeDTO> getChangesSortedBy(SortedQueryRequest sortedQueryRequest) {
		
		List<Change> changes = null;
		
		if(sortedQueryRequest.getOrder().contains("ASC")) {
			Pageable paging = PageRequest.of(
						sortedQueryRequest.getOffset(),
						sortedQueryRequest.getRowCount(),
						Sort.by(sortedQueryRequest.getColumn()).ascending()
					);
			
			changes = changeRepository.findAll(paging).toList();

		} else if (sortedQueryRequest.getOrder().contains("DESC")) {
			Pageable paging = PageRequest.of(
					sortedQueryRequest.getOffset(),
					sortedQueryRequest.getRowCount(),
					Sort.by(sortedQueryRequest.getColumn()).descending()
				);
		
		changes = changeRepository.findAll(paging).toList();
		}
		
		if(changes != null) {
			List<ChangeDTO> changeDTOs = new ArrayList<>();
			
			for(Change change : changes) {
				changeDTOs.add(jpaDtoMapper.toDTO(change));
			}
			
			return changeDTOs;
		}
		
		return null;
	}
	
	@Override
	public void deleteChangeById(int id) {
		changeRepository.deleteById(id);
	}

}
