package com.snplog.backend.services.implementations;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

import com.snplog.backend.dto.MessageDTO;
import com.snplog.backend.entity.Message;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.repository.ChangeRepository;
import com.snplog.backend.repository.MessageRepository;
import com.snplog.backend.services.MessageService;
import com.snplog.backend.services.misc.JpaDtoMapper;

@Service
public class MessageServiceImpl implements MessageService {

	@Autowired
	private MessageRepository messageRepository;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	@Autowired
	private ChangeRepository changeRepository;
	
	@Override
	public List<MessageDTO> findAll() {
		List<Message> messages = messageRepository.findAll();
		
		List<MessageDTO> messagesDTO = new ArrayList<>();
		
		for (Message message : messages ) {
			messagesDTO.add(jpaDtoMapper.toDTO(message));
		}
		return messagesDTO;
	}

	@Override
	public MessageDTO getMessage(int id) {
		Optional<Message> result = messageRepository.findById(id);
		
		Message message = null;
		
		if(result.isPresent()) {
			message = result.get();
		} else {
			throw new RuntimeException("Did not find the message id - " + id);
		}
		
		return jpaDtoMapper.toDTO(message);
	}

	@Override
	public void saveMessage(Message message) {
		messageRepository.save(message);
	}

	@Override
	public void deleteMessage(MessageDTO messageDTO) {
		messageRepository.deleteById(messageDTO.getId());
	}
	
	@Override
	public void updateMessage(MessageDTO messageDTO) {
		Optional<Message> result = messageRepository.findById(messageDTO.getId());
		
		Message message = null;
		
		if(result.isPresent()) {
			
			if(messageDTO.isEdited()) {
				message = jpaDtoMapper.fromDTO(messageDTO);
				
				messageRepository.save(message);
				
				changeRepository.saveAll(messageDTO.getChanges());
			}
			
			
		} else {
			throw new RuntimeException("Did not find the cabin id - " + messageDTO.getId());
		}
		
	}
	
	@Override
	public List<MessageDTO> getMessagesSortedBy(SortedQueryRequest sortedQueryRequest) {
		
		List<Message> messages = null;
		
		if(sortedQueryRequest.getOrder().contains("ASC")) {
			Pageable paging = PageRequest.of(
						sortedQueryRequest.getOffset(),
						sortedQueryRequest.getRowCount(),
						Sort.by(sortedQueryRequest.getColumn()).ascending()
					);
			
			messages = messageRepository.findAll(paging).toList();

		} else if (sortedQueryRequest.getOrder().contains("DESC")) {
			Pageable paging = PageRequest.of(
					sortedQueryRequest.getOffset(),
					sortedQueryRequest.getRowCount(),
					Sort.by(sortedQueryRequest.getColumn()).descending()
				);
		
		messages = messageRepository.findAll(paging).toList();
		}
		
		if(messages != null) {
			List<MessageDTO> messageDTOs = new ArrayList<>();
			
			for(Message message : messages) {
				messageDTOs.add(jpaDtoMapper.toDTO(message));
			}
			
			return messageDTOs;
		}
		
		return null;
	}
	
	@Override
	public void deleteMessageById(int id) {
		messageRepository.deleteById(id);
	}

}
