package com.snplog.backend.services.implementations;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

import com.snplog.backend.dto.MessageThreadDTO;
import com.snplog.backend.entity.MessageThread;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.repository.ChangeRepository;
import com.snplog.backend.repository.MessageThreadRepository;
import com.snplog.backend.services.MessageThreadService;
import com.snplog.backend.services.misc.JpaDtoMapper;

@Service
public class MessageThreadServiceImpl implements MessageThreadService {

	@Autowired
	private MessageThreadRepository messageThreadRepository;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	@Autowired
	private ChangeRepository changeRepository;
	
	@Override
	public List<MessageThreadDTO> findAll() {
		List<MessageThread> messageThreads = messageThreadRepository.findAll();
		
		List<MessageThreadDTO> messageThreadsDTO = new ArrayList<>();
		
		for (MessageThread messageThread : messageThreads ) {
			messageThreadsDTO.add(jpaDtoMapper.toDTO(messageThread));
		}
		return messageThreadsDTO;
	}


	@Override
	public MessageThreadDTO getMessageThread(int id) {
		Optional<MessageThread> result = messageThreadRepository.findById(id);
		
		MessageThread messageThread = null;
		
		if(result.isPresent()) {
			messageThread = result.get();
		} else {
			throw new RuntimeException("Did not find the messageThread id - " + id);
		}
		
		return jpaDtoMapper.toDTO(messageThread);
	}

	@Override
	public void saveMessageThread(MessageThread messageThread) {
		messageThreadRepository.save(messageThread);
	}

	@Override
	public void deleteMessageThread(MessageThreadDTO messageThreadDTO) {
		messageThreadRepository.deleteById(messageThreadDTO.getId());
	}
	
	@Override
	public void updateMessageThread(MessageThreadDTO messageThreadDTO) {
		Optional<MessageThread> result = messageThreadRepository.findById(messageThreadDTO.getId());
		
		MessageThread messageThread = null;
		
		if(result.isPresent()) {
			
			if(messageThreadDTO.isEdited()) {
				messageThread = jpaDtoMapper.fromDTO(messageThreadDTO);
				
				messageThreadRepository.save(messageThread);
				
				changeRepository.saveAll(messageThreadDTO.getChanges());
			}

			
		} else {
			throw new RuntimeException("Did not find the cabin id - " + messageThreadDTO.getId());
		}
		
	}
	
	@Override
	public List<MessageThreadDTO> getMessageThreadsSortedBy(SortedQueryRequest sortedQueryRequest) {
		
		List<MessageThread> messageThreads = null;
		
		if(sortedQueryRequest.getOrder().contains("ASC")) {
			Pageable paging = PageRequest.of(
						sortedQueryRequest.getOffset(),
						sortedQueryRequest.getRowCount(),
						Sort.by(sortedQueryRequest.getColumn()).ascending()
					);
			
			messageThreads = messageThreadRepository.findAll(paging).toList();

		} else if (sortedQueryRequest.getOrder().contains("DESC")) {
			Pageable paging = PageRequest.of(
					sortedQueryRequest.getOffset(),
					sortedQueryRequest.getRowCount(),
					Sort.by(sortedQueryRequest.getColumn()).descending()
				);
		
		messageThreads = messageThreadRepository.findAll(paging).toList();
		}
		
		if(messageThreads != null) {
			List<MessageThreadDTO> messageThreadDTOs = new ArrayList<>();
			
			for(MessageThread messageThread : messageThreads) {
				messageThreadDTOs.add(jpaDtoMapper.toDTO(messageThread));
			}
			
			return messageThreadDTOs;
		}
		
		return null;
	}
	
	@Override
	public void deleteMessageThreadById(int id) {
		messageThreadRepository.deleteById(id);
	}

}
