package com.snplog.backend.services.implementations;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import javax.persistence.NoResultException;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import com.snplog.backend.dao.MyUserDAO;
import com.snplog.backend.dto.MyUserDTO;
import com.snplog.backend.entity.MyUser;
import com.snplog.backend.entity.MyUserRole;
import com.snplog.backend.entity.Role;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.repository.ChangeRepository;
import com.snplog.backend.repository.MyUserRepository;
import com.snplog.backend.repository.MyUserRoleRepository;
import com.snplog.backend.repository.RoleRepository;
import com.snplog.backend.services.MyUserService;
import com.snplog.backend.services.misc.JpaDtoMapper;

@Service
public class MyUserServiceImpl implements MyUserService {
	
	@Autowired
	private MyUserDAO myUserDAO;
	
	@Autowired
	private MyUserRepository myUserRepository;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	@Autowired
	private ChangeRepository changesRepository;
	
	@Autowired
	private RoleRepository roleRepository;
	
	@Autowired
	private MyUserRoleRepository myUserRoleRepository;

	@Override
	public List<MyUserDTO> findAll() {
		List<MyUser> myUsers = myUserRepository.findAll();
		
		List<MyUserDTO> myUsersDTO = new ArrayList<>();
		
		for (MyUser myUser : myUsers ) {
			myUsersDTO.add(jpaDtoMapper.toDTO(myUser));
		}
		return myUsersDTO;
	}

	@Override
	public MyUserDTO getMyUserDTOByEmail(String email) {
		return jpaDtoMapper.toDTO(myUserRepository.getMyUserByEmail(email));
	}

	@Override
	public void saveMyUser(MyUser myUser) {
		Role cabinOwner = roleRepository.getOne("cabinOwner");
		myUserRepository.save(myUser);
		myUserRoleRepository.save(new MyUserRole(0, cabinOwner, myUser));
	}

	@Override
	public void deleteMyUser(MyUserDTO myUserDTO) {
		myUserRepository.deleteById(myUserDTO.getId());
	}
	
	@Override
	@Transactional
	public boolean checkIfUserExist(String email) throws NoResultException {
		
		if(myUserDAO.getMyUserByEmail(email) != null) {
			return true;
		} else {
			return false;
		}
		
	}
	
	@Override
	public MyUserDTO getMyUser(int id) {
		Optional<MyUser> result = myUserRepository.findById(id);
		
		MyUser myUser = null;
		
		if(result.isPresent()) {
			myUser = result.get();
		} else {
			throw new RuntimeException("Did not find the myUser id - " + id);
		}
		
		return jpaDtoMapper.toDTO(myUser);
	}
	
	@Override
	public void updateMyUser(MyUserDTO myUserDTO) {
		Optional<MyUser> result = myUserRepository.findById(myUserDTO.getId());
		
		MyUser myUser = null;
		
		if(result.isPresent()) {			
			if(myUserDTO.isEdited()) {
				myUser = jpaDtoMapper.fromDTO(myUserDTO);
				
				myUserRepository.save(myUser);
				
				changesRepository.saveAll(myUserDTO.getChanges());
			}
		} else {
			throw new RuntimeException("Did not find the cabin id - " + myUserDTO.getId());
		}
		
	}

	@Override
	public MyUser getMyUserByEmail(String email) {
		return myUserRepository.getMyUserByEmail(email);
	}
	
	@Override
	public List<MyUserDTO> getMyUsersSortedBy(SortedQueryRequest sortedQueryRequest) {
		
		List<MyUser> myUsers = null;
		
		if(sortedQueryRequest.getOrder().contains("ASC")) {
			Pageable paging = PageRequest.of(
						sortedQueryRequest.getOffset(),
						sortedQueryRequest.getRowCount(),
						Sort.by(sortedQueryRequest.getColumn()).ascending()
					);
			
			myUsers = myUserRepository.findAll(paging).toList();

		} else if (sortedQueryRequest.getOrder().contains("DESC")) {
			Pageable paging = PageRequest.of(
					sortedQueryRequest.getOffset(),
					sortedQueryRequest.getRowCount(),
					Sort.by(sortedQueryRequest.getColumn()).descending()
				);
		
		myUsers = myUserRepository.findAll(paging).toList();
		}
		
		if(myUsers != null) {
			List<MyUserDTO> myUserDTOs = new ArrayList<>();
			
			for(MyUser myUser : myUsers) {
				myUserDTOs.add(jpaDtoMapper.toDTO(myUser));
			}
			
			return myUserDTOs;
		}
		
		return null;
	}
	
	@Override
	public List<MyUserDTO> getMyUsersByFirstNameSortedByFirstName(String firstName){
		List<MyUserDTO> result = new ArrayList<>();
		List<MyUser> myUsers = myUserRepository.findByFirstName(firstName);
		for(MyUser myUser : myUsers) {
			result.add(jpaDtoMapper.toDTO(myUser));
		}
		return result;
	}
	
	@Override
	public void deleteMyUserById(int id) {
		myUserRepository.deleteById(id);
	}
	
	@Override
	public void addPlowerRole(MyUser myUser) {
		Role role =roleRepository.getOne("plower");
		myUserRoleRepository.save(new MyUserRole(0, role, myUser));
	}
	
	@Override
	public MyUser getMyUserById(int id) {
		return myUserRepository.getOne(id);
	}

}
