package com.snplog.backend.services.implementations;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

import com.snplog.backend.dto.CabinAreaDTO;
import com.snplog.backend.dto.PlowerCabinAreaDTO;
import com.snplog.backend.entity.PlowerCabinArea;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.repository.ChangeRepository;
import com.snplog.backend.repository.PlowerCabinAreaRepository;
import com.snplog.backend.services.PlowerCabinAreaService;
import com.snplog.backend.services.misc.JpaDtoMapper;

@Service
public class PlowerCabinAreaServiceImpl implements PlowerCabinAreaService {
	
	@Autowired
	private PlowerCabinAreaRepository plowerCabinAreaRepository;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	@Autowired
	private ChangeRepository changeRepository;

	@Override
	public List<PlowerCabinAreaDTO> findAll() {
		List<PlowerCabinArea> plowerCabinAreas = plowerCabinAreaRepository.findAll();
		
		List<PlowerCabinAreaDTO> plowerCabinAreasDTO = new ArrayList<>();
		
		for (PlowerCabinArea plowerCabinArea : plowerCabinAreas ) {
			plowerCabinAreasDTO.add(jpaDtoMapper.toDTO(plowerCabinArea));
		}
		return plowerCabinAreasDTO;
	}

	@Override
	public PlowerCabinAreaDTO getPlowerCabinArea(int id) {
		Optional<PlowerCabinArea> result = plowerCabinAreaRepository.findById(id);
		
		PlowerCabinArea plowerCabinArea = null;
		
		if(result.isPresent()) {
			plowerCabinArea = result.get();
		} else {
			throw new RuntimeException("Did not find the plowerCabinArea id - " + id);
		}
		
		return jpaDtoMapper.toDTO(plowerCabinArea);
	}

	@Override
	public void savePlowerCabinArea(PlowerCabinArea plowerCabinArea) {
		plowerCabinAreaRepository.save(plowerCabinArea);
	}

	@Override
	public void deletePlowerCabinArea(PlowerCabinAreaDTO plowerCabinAreaDTO) {
		plowerCabinAreaRepository.deleteById(plowerCabinAreaDTO.getId());
	}
	
	@Override
	public void updatePlowerCabinArea(PlowerCabinAreaDTO plowerCabinAreaDTO) {
		Optional<PlowerCabinArea> result = plowerCabinAreaRepository.findById(plowerCabinAreaDTO.getId());
		
		PlowerCabinArea plowerCabinArea = null;
		
		if(result.isPresent()) {
			
			if(plowerCabinAreaDTO.isEdited()) {
				plowerCabinArea = jpaDtoMapper.fromDTO(plowerCabinAreaDTO);
				
				plowerCabinAreaRepository.save(plowerCabinArea);
				
				changeRepository.saveAll(plowerCabinAreaDTO.getChanges());
			}

			
		} else {
			throw new RuntimeException("Did not find the plowerCabinArea id - " + plowerCabinAreaDTO.getId());
		}
		
	}
	
	@Override
	public List<PlowerCabinAreaDTO> getPlowerCabinAreasSortedBy(SortedQueryRequest sortedQueryRequest) {
		
		List<PlowerCabinArea> plowerCabinAreas = null;
		
		if(sortedQueryRequest.getOrder().contains("ASC")) {
			Pageable paging = PageRequest.of(
						sortedQueryRequest.getOffset(),
						sortedQueryRequest.getRowCount(),
						Sort.by(sortedQueryRequest.getColumn()).ascending()
					);
			
			plowerCabinAreas = plowerCabinAreaRepository.findAll(paging).toList();

		} else if (sortedQueryRequest.getOrder().contains("DESC")) {
			Pageable paging = PageRequest.of(
					sortedQueryRequest.getOffset(),
					sortedQueryRequest.getRowCount(),
					Sort.by(sortedQueryRequest.getColumn()).descending()
				);
		
		plowerCabinAreas = plowerCabinAreaRepository.findAll(paging).toList();
		}
		
		if(plowerCabinAreas != null) {
			List<PlowerCabinAreaDTO> plowerCabinAreaDTOs = new ArrayList<>();
			
			for(PlowerCabinArea plowerCabinArea : plowerCabinAreas) {
				plowerCabinAreaDTOs.add(jpaDtoMapper.toDTO(plowerCabinArea));
			}
			
			return plowerCabinAreaDTOs;
		}
		
		return null;
	}

	@Override
	public void deletePlowerCabinAreaById(int id) {
		plowerCabinAreaRepository.deleteById(id);
	}
	
	@Override
	public List<PlowerCabinAreaDTO> getPlowerCabinAreaByPlowerId(int id){
		List<PlowerCabinArea> plowerCabinAreas = plowerCabinAreaRepository.getPlowerCabinAreaByPlowerId(id);
		List<PlowerCabinAreaDTO> plowerCabinAreaDTOs = new ArrayList<>();
		for(PlowerCabinArea pca : plowerCabinAreas) {
			plowerCabinAreaDTOs.add(jpaDtoMapper.toDTO(pca));
		}
		return plowerCabinAreaDTOs;
	}
	
}
