package com.snplog.backend.services.implementations;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

import com.snplog.backend.dto.PlowerPositionDTO;
import com.snplog.backend.entity.PlowerPosition;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.repository.PlowerPositionRepository;
import com.snplog.backend.services.PlowerPositionService;
import com.snplog.backend.services.misc.JpaDtoMapper;

@Service
public class PlowerPositionServiceImpl implements PlowerPositionService {
	
	@Autowired
	private PlowerPositionRepository plowerPositionRepository;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;

	@Override
	public List<PlowerPositionDTO> findAll() {
		List<PlowerPosition> plowerPositions = plowerPositionRepository.findAll();
		
		List<PlowerPositionDTO> plowerPositionsDTO = new ArrayList<>();
		
		for (PlowerPosition plowerPosition : plowerPositions ) {
			plowerPositionsDTO.add(jpaDtoMapper.toDTO(plowerPosition));
		}
		return plowerPositionsDTO;
	}

	@Override
	public PlowerPositionDTO getPlowerPosition(int id) {
		Optional<PlowerPosition> result = plowerPositionRepository.findById(id);
		
		PlowerPosition plowerPosition = null;
		
		if(result.isPresent()) {
			plowerPosition = result.get();
		} else {
			throw new RuntimeException("Did not find the PlowerPosition id - " + id);
		}
		
		return jpaDtoMapper.toDTO(plowerPosition);
	}

	@Override
	public void savePlowerPosition(PlowerPosition plowerPosition) {
		plowerPositionRepository.save(plowerPosition);
	}

	@Override
	public void deletePlowerPosition(PlowerPosition plowerPosition) {
		plowerPositionRepository.delete(plowerPosition);
	}
	
	@Override
	public List<PlowerPositionDTO> getPlowerPositionsSortedBy(SortedQueryRequest sortedQueryRequest) {
		
		List<PlowerPosition> plowerPositions = null;
		
		if(sortedQueryRequest.getOrder().contains("ASC")) {
			Pageable paging = PageRequest.of(
						sortedQueryRequest.getOffset(),
						sortedQueryRequest.getRowCount(),
						Sort.by(sortedQueryRequest.getColumn()).ascending()
					);
			
			plowerPositions = plowerPositionRepository.findAll(paging).toList();

		} else if (sortedQueryRequest.getOrder().contains("DESC")) {
			Pageable paging = PageRequest.of(
					sortedQueryRequest.getOffset(),
					sortedQueryRequest.getRowCount(),
					Sort.by(sortedQueryRequest.getColumn()).descending()
				);
		
		plowerPositions = plowerPositionRepository.findAll(paging).toList();
		}
		
		if(plowerPositions != null) {
			List<PlowerPositionDTO> plowerPositionDTOs = new ArrayList<>();
			
			for(PlowerPosition plowerPosition : plowerPositions) {
				plowerPositionDTOs.add(jpaDtoMapper.toDTO(plowerPosition));
			}
			
			return plowerPositionDTOs;
		}
		
		return null;
	}

	@Override
	public void deletePlowerPositionById(int id) {
		plowerPositionRepository.deleteById(id);
	}
}
