package com.snplog.backend.services.implementations;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

import com.snplog.backend.dto.PlowerRequestDTO;
import com.snplog.backend.entity.PlowerRequest;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.repository.ChangeRepository;
import com.snplog.backend.repository.PlowerRequestRepository;
import com.snplog.backend.services.PlowerRequestService;
import com.snplog.backend.services.misc.JpaDtoMapper;

@Service
public class PlowerRequestServiceImpl implements PlowerRequestService {
	
	@Autowired
	private PlowerRequestRepository plowerRequestRepository;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	@Autowired
	private ChangeRepository changeRepository;

	@Override
	public List<PlowerRequestDTO> findAll() {
		List<PlowerRequest> plowerRequests = plowerRequestRepository.findAll();
		
		List<PlowerRequestDTO> plowerRequestsDTO = new ArrayList<>();
		
		for (PlowerRequest plowerRequest : plowerRequests ) {
			plowerRequestsDTO.add(jpaDtoMapper.toDTO(plowerRequest));
		}
		return plowerRequestsDTO;
	}
	
	@Override
	public List<PlowerRequestDTO> findActivePlowerRequests() {
		List<PlowerRequest> plowerRequests = plowerRequestRepository.getActivePlowerRequests();
		
		List<PlowerRequestDTO> plowerRequestsDTO = new ArrayList<>();
		
		for (PlowerRequest plowerRequest : plowerRequests ) {
			plowerRequestsDTO.add(jpaDtoMapper.toDTO(plowerRequest));
		}
		return plowerRequestsDTO;
	}

	@Override
	public PlowerRequestDTO getPlowerRequest(int id) {
		Optional<PlowerRequest> result = plowerRequestRepository.findById(id);
		
		PlowerRequest plowerRequest = null;
		
		if(result.isPresent()) {
			plowerRequest = result.get();
		} else {
			throw new RuntimeException("Did not find the plowerRequest id - " + id);
		}
		
		return jpaDtoMapper.toDTO(plowerRequest);
	}

	@Override
	public void savePlowerRequest(PlowerRequest plowerRequest) {
		plowerRequestRepository.save(plowerRequest);
	}

	@Override
	public void deletePlowerRequest(PlowerRequestDTO plowerRequestDTO) {
		plowerRequestRepository.deleteById(plowerRequestDTO.getId());
	}
	
	@Override
	public void updatePlowerRequest(PlowerRequestDTO plowerRequestDTO) {
		Optional<PlowerRequest> result = plowerRequestRepository.findById(plowerRequestDTO.getId());
		
		PlowerRequest plowerRequest = null;
		
		if(result.isPresent()) {
			
			if(plowerRequestDTO.isEdited()) {
				plowerRequest = jpaDtoMapper.fromDTO(plowerRequestDTO);
				
				plowerRequestRepository.save(plowerRequest);
				
				changeRepository.saveAll(plowerRequestDTO.getChanges());
			}
			
		} else {
			throw new RuntimeException("Did not find the plowerRequest id - " + plowerRequestDTO.getId());
		}
		
	}
	
	@Override
	public List<PlowerRequestDTO> getPlowerRequestsSortedBy(SortedQueryRequest sortedQueryRequest) {
		
		List<PlowerRequest> plowerRequests = null;
		
		if(sortedQueryRequest.getOrder().contains("ASC")) {
			Pageable paging = PageRequest.of(
						sortedQueryRequest.getOffset(),
						sortedQueryRequest.getRowCount(),
						Sort.by(sortedQueryRequest.getColumn()).ascending()
					);
			
			plowerRequests = plowerRequestRepository.findAll(paging).toList();

		} else if (sortedQueryRequest.getOrder().contains("DESC")) {
			Pageable paging = PageRequest.of(
					sortedQueryRequest.getOffset(),
					sortedQueryRequest.getRowCount(),
					Sort.by(sortedQueryRequest.getColumn()).descending()
				);
		
		plowerRequests = plowerRequestRepository.findAll(paging).toList();
		}
		
		if(plowerRequests != null) {
			List<PlowerRequestDTO> plowerRequestDTOs = new ArrayList<>();
			
			for(PlowerRequest plowerRequest : plowerRequests) {
				plowerRequestDTOs.add(jpaDtoMapper.toDTO(plowerRequest));
			}
			
			return plowerRequestDTOs;
		}
		
		return null;
	}
	
	@Override
	public void deletePlowerRequestById(int id) {
		plowerRequestRepository.deleteById(id);
	}
}
