package com.snplog.backend.services.implementations;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

import com.snplog.backend.dto.PlowingRequestDTO;
import com.snplog.backend.entity.PlowingRequest;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.repository.ChangeRepository;
import com.snplog.backend.repository.PlowingRequestRepository;
import com.snplog.backend.services.PlowingRequestService;
import com.snplog.backend.services.misc.JpaDtoMapper;

@Service
public class PlowingRequestServiceImpl implements PlowingRequestService {

	@Autowired
	private PlowingRequestRepository plowingRequestRepository;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	@Autowired
	private ChangeRepository changeRepository;
	
	@Override
	public List<PlowingRequestDTO> findAll() {
		List<PlowingRequest> plowingRequests = plowingRequestRepository.findAll();
		
		List<PlowingRequestDTO> plowingRequestsDTO = new ArrayList<>();
		
		for (PlowingRequest plowingRequest : plowingRequests ) {
			plowingRequestsDTO.add(jpaDtoMapper.toDTO(plowingRequest));
		}
		return plowingRequestsDTO;
	}

	@Override
	public PlowingRequestDTO getPlowingRequest(int id) {

		Optional<PlowingRequest> result = plowingRequestRepository.findById(id);
		
		PlowingRequest plowingRequest = null;
		
		if(result.isPresent()) {
			plowingRequest = result.get();
		} else {
			throw new RuntimeException("Did not find the plowingRequest id - " + id);
		}
		
		return jpaDtoMapper.toDTO(plowingRequest);
	}

	@Override
	public void savePlowingRequest(PlowingRequest plowingRequest) {
		plowingRequestRepository.save(plowingRequest);
	}

	@Override
	public void deletePlowingRequest(PlowingRequestDTO plowingRequestDTO) {
		plowingRequestRepository.deleteById(plowingRequestDTO.getId());
	}
	
	@Override
	public void updatePlowingRequest(PlowingRequestDTO plowingRequestDTO) {
		Optional<PlowingRequest> result = plowingRequestRepository.findById(plowingRequestDTO.getId());
		
		PlowingRequest plowingRequest = null;
		
		if(result.isPresent()) {
			
			if(plowingRequestDTO.isEdited()) {
				plowingRequest = jpaDtoMapper.fromDTO(plowingRequestDTO);
				
				plowingRequestRepository.save(plowingRequest);
				
				changeRepository.saveAll(plowingRequestDTO.getChanges());
			}

			
		} else {
			throw new RuntimeException("Did not find the plowingRequest id - " + plowingRequestDTO.getId());
		}
		
	}
	
	@Override
	public List<PlowingRequestDTO> getPlowingRequestsSortedBy(SortedQueryRequest sortedQueryRequest) {
		
		List<PlowingRequest> plowingRequests = null;
		
		if(sortedQueryRequest.getOrder().contains("ASC")) {
			Pageable paging = PageRequest.of(
						sortedQueryRequest.getOffset(),
						sortedQueryRequest.getRowCount(),
						Sort.by(sortedQueryRequest.getColumn()).ascending()
					);
			
			plowingRequests = plowingRequestRepository.findAll(paging).toList();

		} else if (sortedQueryRequest.getOrder().contains("DESC")) {
			Pageable paging = PageRequest.of(
					sortedQueryRequest.getOffset(),
					sortedQueryRequest.getRowCount(),
					Sort.by(sortedQueryRequest.getColumn()).descending()
				);
		
		plowingRequests = plowingRequestRepository.findAll(paging).toList();
		}
		
		if(plowingRequests != null) {
			List<PlowingRequestDTO> plowingRequestDTOs = new ArrayList<>();
			
			for(PlowingRequest plowingRequest : plowingRequests) {
				plowingRequestDTOs.add(jpaDtoMapper.toDTO(plowingRequest));
			}
			
			return plowingRequestDTOs;
		}
		
		return null;
	}

	@Override
	public void deletePlowingRequestById(int id) {
		plowingRequestRepository.deleteById(id);
	}
	
	@Override
	public List<PlowingRequestDTO> getPlowingRequestByCabinId(int id) {
		List<PlowingRequest> plowingRequest = plowingRequestRepository.findPlowingRequestByCabinId(1);
		List<PlowingRequestDTO> plowingRequestDTOs = new ArrayList<>();
		for(PlowingRequest pr : plowingRequest) {
			plowingRequestDTOs.add(jpaDtoMapper.toDTO(pr));
		}
		return plowingRequestDTOs;
	}
	
	@Override
	public List<PlowingRequestDTO> getPlowingRequestsByCabinAreaId(int id){
		List<PlowingRequest> plowingRequests = plowingRequestRepository.findPlowingRequestByCabinAreaId(id);
		List<PlowingRequestDTO> plowingRequestDTOs = new ArrayList<>();
		if(plowingRequests != null) {
			for(PlowingRequest pr : plowingRequests) {
				plowingRequestDTOs.add(jpaDtoMapper.toDTO(pr));
			}
			return plowingRequestDTOs;
		}
		else return null;
	}
}
