package com.snplog.backend.services.implementations;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

import com.snplog.backend.dto.SnowStatisticDTO;
import com.snplog.backend.entity.SnowStatistic;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.repository.SnowStatisticRepository;
import com.snplog.backend.services.SnowStatisticService;
import com.snplog.backend.services.misc.JpaDtoMapper;

@Service
public class SnowStatisticServiceImpl implements SnowStatisticService {

	@Autowired
	private SnowStatisticRepository snowStatisticRepository;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	@Override
	public List<SnowStatisticDTO> findAll() {
		List<SnowStatistic> snowStatistics = snowStatisticRepository.findAll();
		
		List<SnowStatisticDTO> snowStatisticsDTO = new ArrayList<>();
		
		for (SnowStatistic snowStatistic : snowStatistics ) {
			snowStatisticsDTO.add(jpaDtoMapper.toDTO(snowStatistic));
		}
		
		return snowStatisticsDTO;
	}
		
	@Override
	public SnowStatisticDTO getSnowStatistic(int id) {
		Optional<SnowStatistic> result = snowStatisticRepository.findById(id);
		
		SnowStatistic snowStatistic = null;
		
		if(result.isPresent()) {
			snowStatistic = result.get();
		} else {
			throw new RuntimeException("Did not find the snowStatistic id - " + id);
		}
		
		return jpaDtoMapper.toDTO(snowStatistic);
	}

	@Override
	public void saveSnowStatistic(SnowStatistic snowStatistic) {
		snowStatisticRepository.save(snowStatistic);
	}

	@Override
	public void deleteSnowStatistic(SnowStatistic snowStatistic) {
		snowStatisticRepository.delete(snowStatistic);
	}
	
	@Override
	public void updateSnowStatistic(SnowStatisticDTO snowStatisticDTO) {
		Optional<SnowStatistic> result = snowStatisticRepository.findById(snowStatisticDTO.getId());
		
		SnowStatistic snowStatistic = null;
		
		if(result.isPresent()) {
			snowStatistic = jpaDtoMapper.fromDTO(snowStatisticDTO);
			
			snowStatisticRepository.save(snowStatistic);
			
		} else {
			throw new RuntimeException("Did not find the snowStatistic id - " + snowStatisticDTO.getId());
		}
		
	}
	
	@Override
	public List<SnowStatisticDTO> getSnowStatisticsSortedBy(SortedQueryRequest sortedQueryRequest) {
		
		List<SnowStatistic> snowStatistics = null;
		
		if(sortedQueryRequest.getOrder().contains("ASC")) {
			Pageable paging = PageRequest.of(
						sortedQueryRequest.getOffset(),
						sortedQueryRequest.getRowCount(),
						Sort.by(sortedQueryRequest.getColumn()).ascending()
					);
			
			snowStatistics = snowStatisticRepository.findAll(paging).toList();

		} else if (sortedQueryRequest.getOrder().contains("DESC")) {
			Pageable paging = PageRequest.of(
					sortedQueryRequest.getOffset(),
					sortedQueryRequest.getRowCount(),
					Sort.by(sortedQueryRequest.getColumn()).descending()
				);
		
		snowStatistics = snowStatisticRepository.findAll(paging).toList();
		}
		
		if(snowStatistics != null) {
			List<SnowStatisticDTO> snowStatisticDTOs = new ArrayList<>();
			
			for(SnowStatistic snowStatistic : snowStatistics) {
				snowStatisticDTOs.add(jpaDtoMapper.toDTO(snowStatistic));
			}
			
			return snowStatisticDTOs;
		}
		
		return null;
	}


}
