package com.snplog.backend.services.implementations;

import java.util.ArrayList;
import java.util.List;
import java.util.Optional;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

import com.snplog.backend.dto.WeatherStationDTO;
import com.snplog.backend.entity.WeatherStation;
import com.snplog.backend.models.SortedQueryRequest;
import com.snplog.backend.repository.ChangeRepository;
import com.snplog.backend.repository.WeatherStationRepository;
import com.snplog.backend.services.WeatherStationService;
import com.snplog.backend.services.misc.JpaDtoMapper;

@Service
public class WeatherStationServiceImpl implements WeatherStationService {

	@Autowired 
	private WeatherStationRepository weatherStationRepository;
	
	@Autowired
	private JpaDtoMapper jpaDtoMapper;
	
	@Autowired
	private ChangeRepository changeRepository;
	
	@Override
	public List<WeatherStationDTO> findAll() {
		List<WeatherStation> weatherStations = weatherStationRepository.findAll();
		
		List<WeatherStationDTO> weatherStationsDTO = new ArrayList<>();
		
		for (WeatherStation weatherStation : weatherStations ) {
			weatherStationsDTO.add(jpaDtoMapper.toDTO(weatherStation));
		}
		return weatherStationsDTO;
	}

	@Override
	public WeatherStationDTO getWeatherStation(int id) {
		Optional<WeatherStation> result = weatherStationRepository.findById(id);
		
		WeatherStation weatherStation = null;
		
		if(result.isPresent()) {
			weatherStation = result.get();
		} else {
			throw new RuntimeException("Did not find the weatherStation id - " + id);
		}
		
		return jpaDtoMapper.toDTO(weatherStation);
	}

	@Override
	public void saveWeatherStation(WeatherStation weatherStation) {
		weatherStationRepository.save(weatherStation);
	}

	@Override
	public void deleteWeatherStation(WeatherStation weatherStation) {
		weatherStationRepository.delete(weatherStation);
	}
	
	@Override
	public void updateWeatherStation(WeatherStationDTO weatherStationDTO) {
		Optional<WeatherStation> result = weatherStationRepository.findById(weatherStationDTO.getId());
		
		WeatherStation weatherStation = null;
		
		if(result.isPresent()) {
			
			if(weatherStationDTO.isEdited()) {
				weatherStation = jpaDtoMapper.fromDTO(weatherStationDTO);
				
				weatherStationRepository.save(weatherStation);
				
				changeRepository.saveAll(weatherStationDTO.getChanges());
			}

			
		} else {
			throw new RuntimeException("Did not find the weatherStation id - " + weatherStationDTO.getId());
		}
		
	}
	
	@Override
	public List<WeatherStationDTO> getWeatherStationsSortedBy(SortedQueryRequest sortedQueryRequest) {
		
		List<WeatherStation> weatherStations = null;
		
		if(sortedQueryRequest.getOrder().contains("ASC")) {
			Pageable paging = PageRequest.of(
						sortedQueryRequest.getOffset(),
						sortedQueryRequest.getRowCount(),
						Sort.by(sortedQueryRequest.getColumn()).ascending()
					);
			
			weatherStations = weatherStationRepository.findAll(paging).toList();

		} else if (sortedQueryRequest.getOrder().contains("DESC")) {
			Pageable paging = PageRequest.of(
					sortedQueryRequest.getOffset(),
					sortedQueryRequest.getRowCount(),
					Sort.by(sortedQueryRequest.getColumn()).descending()
				);
		
		weatherStations = weatherStationRepository.findAll(paging).toList();
		}
		
		if(weatherStations != null) {
			List<WeatherStationDTO> weatherStationDTOs = new ArrayList<>();
			
			for(WeatherStation weatherStation : weatherStations) {
				weatherStationDTOs.add(jpaDtoMapper.toDTO(weatherStation));
			}
			
			return weatherStationDTOs;
		}
		
		return null;
	}

	@Override
	public void deleteWeatherStationById(int id) {
		weatherStationRepository.deleteById(id);
	}
}
