package com.snplog.backend.services.misc;

import java.io.IOException;

import org.apache.http.HttpEntity;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;
import org.json.JSONObject;
import org.springframework.stereotype.Service;

import com.snplog.backend.entity.Cabin;

@Service
public class CabinPositionService {

	public CabinPositionService() {}

	public Cabin getLongLatForCabin(Cabin cabin) throws ClientProtocolException, IOException {
		CloseableHttpClient httpClient = HttpClients.createDefault();
		// %20 = space
		HttpGet httpGet = new HttpGet(
				"https://ws.geonorge.no/adresser/v1/sok?sokemodus=AND&kommunenummer=" +
				cabin.getKid() +
				"&gardsnummer=" +
				cabin.getGid() +
				"&bruksnummer=" +
				cabin.getBid() + 
				"&treffPerSide=10&side=0&asciiKompatibel=true"
				);
		CloseableHttpResponse response = httpClient.execute(httpGet);
		
		JSONObject jsonObject = null;
		
		try {
			if(response.getStatusLine().getStatusCode() != 200) {
				return null;
			}
			
			HttpEntity entity = response.getEntity();
			
			String responseString = EntityUtils.toString(entity);
	
			jsonObject = new JSONObject(responseString);
			EntityUtils.consume(entity);
		} catch(ClientProtocolException cpe){
			return null;
		} catch(IOException ioe){
			return null;
		} finally {
			response.close();
		}
		
		if(jsonObject != null) {
			JSONObject adress = jsonObject.getJSONArray("adresser").getJSONObject(0);
			cabin.setLongitude(Double.parseDouble(adress.getJSONObject("representasjonspunkt").get("lon").toString()));
			cabin.setLatitude(Double.parseDouble(adress.getJSONObject("representasjonspunkt").get("lat").toString()));
			cabin.setCountry("Norge");
			cabin.setStreetAdress(adress.get("adressetekstutenadressetilleggsnavn").toString());
			cabin.setMunicipality(adress.get("postnummer") + " " + adress.get("poststed"));
			
			return cabin;
		}
		return null; 
	}
}
