package com.snplog.backend.services.misc;

import java.io.IOException;
import java.sql.Timestamp;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.List;
import java.util.Optional;

import org.apache.http.client.ClientProtocolException;
import org.apache.http.message.BasicNameValuePair;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.google.maps.model.DirectionsResult;
import com.snplog.backend.entity.Cabin;
import com.snplog.backend.entity.CabinArea;
import com.snplog.backend.entity.PlowingRequest;
import com.snplog.backend.models.PlowerRouteRequest;
import com.snplog.backend.models.RouteXLLocation;
import com.snplog.backend.repository.CabinAreaRepository;
import com.snplog.backend.repository.CabinRepository;
import com.snplog.backend.repository.PlowingRequestRepository;
import com.snplog.backend.singleton.DirectionsService;
import com.snplog.backend.thirdprtapi.RoutePlanner;

@Service
public class OptimalRouteService {

	
	@Autowired
	private RoutePlanner routePlanner;
	
	@Autowired
	private PlowingRequestRepository plowingRequestRepository;
	
	@Autowired
	private CabinRepository cabinRepository;
	
	@Autowired
	private CabinAreaRepository cabinAreaRepository;
	
	@Autowired
	private DirectionsService directionsService;
	
	
	private List<RouteXLLocation> getQuickestRoute(List<RouteXLLocation> locations) {
		String request = transformLocationsToString(locations);
		BasicNameValuePair nvp = new BasicNameValuePair("locations", request);
		ArrayList<BasicNameValuePair> postParameters = new ArrayList<BasicNameValuePair>();
		postParameters.add(nvp);
		
		try {
			List<RouteXLLocation> result = routePlanner.getQuickestRoute(postParameters, locations);
			return result;
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		
		return null;
	}
	
	
	private String transformLocationsToString(List<RouteXLLocation> locations) {
		String request = "[";
		int counter = 0;
		for(RouteXLLocation loc : locations) {
			counter++;
			request += "{\"address\": \"" + loc.getCabinId() + "\",";
			request += "\"lat\": \"" + loc.getLat() + "\",";
			request += "\"lng\": \"" + loc.getLng() + "\"}";
			if (counter < locations.size()) {
				request += ",";
			}
		}
		
		request += "]";
		
		System.out.println(request);
		
		return request;
	}
	
	
	public DirectionsResult getDirectionsForQuickestRoute(PlowerRouteRequest plowerRouteRequest) {
		CabinArea cabinArea = cabinAreaRepository.getOne(plowerRouteRequest.getCabinAreaId());
		List<Cabin> cabins = getCabinsToPlow(
						cabinArea, 
						plowerRouteRequest.getDateOfArrival(), 
						plowerRouteRequest.getDateOfDeparture()
				);
		List<RouteXLLocation> quickestRoute = getQuickestRoute(cabinToLocation(cabins));
		
		return directionsService.getDirections(plowerRouteRequest.getStartLocation(), plowerRouteRequest.getEndLocation(), quickestRoute);			
	}
	
	private List<Cabin> getCabinsToPlow(CabinArea cabinArea, Timestamp dateOfArrival, Timestamp dateOfDeparture){
		List<PlowingRequest> plowingRequests = plowingRequestRepository.findPlowingRequestByCabinAreaIdAndDateOfArrival(cabinArea, dateOfArrival, dateOfDeparture);
		List<Cabin> cabins = new ArrayList<>();
		for(PlowingRequest pr : plowingRequests) {
			cabins.add(pr.getCabin());
		}
		return cabins;
	}
	
	private List<RouteXLLocation> cabinToLocation(List<Cabin> cabins){
		List<RouteXLLocation> locations = new ArrayList<>();
		for(Cabin cabin : cabins) {
			locations.add(new RouteXLLocation(
						cabin.getId(),
						cabin.getLatitude(),
						cabin.getLongitude()
					));
		}
		return locations;
	}
	
	private List<Cabin> locationToCabin(List<RouteXLLocation> locations){
		List<Cabin> cabins = new ArrayList<>();
		for(RouteXLLocation location : locations) {
			cabins.add(cabinRepository.getOne(location.getCabinId()));
		}
		return cabins;
	}
}
