package com.snplog.backend.services.misc;

import java.util.Random;
import java.util.Timer;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.mail.SimpleMailMessage;
import org.springframework.mail.javamail.JavaMailSender;
import org.springframework.stereotype.Service;

import com.snplog.backend.entity.MyUser;
import com.snplog.backend.services.MyUserService;
import com.snplog.backend.timertasks.OtpHandler;

@Service
public class OtpService {

	@Autowired
	private JavaMailSender javaMailSender;
	
	@Autowired
	private MyUserService myUserService;
	
	private static final int timeToDeleteOtp = 1000 * 60 * 15; // delete otp after 15 minutes
	
	public void sendOtp(String email) {
		
		MyUser myUser = myUserService.getMyUserByEmail(email);
		
		SimpleMailMessage msg = new SimpleMailMessage();
		
		msg.setTo(email);
		
		msg.setSubject("Testing from spring boot");

		msg.setText("Your random 6 digit code is : " + setMyUserOtp(myUser) + "\n expires in : " + (timeToDeleteOtp / 60000) + " minutes");
		
		javaMailSender.send(msg);
		
		removeMyUserOtp(myUser);
		
	}
	
	
	private String getRandomNumberString() {
		Random rnd = new Random();
		int number = rnd.nextInt(999999);
		
		return String.format("%06d", number);
	}
	
	private String setMyUserOtp(MyUser myUser) {
		
		
		String otp = getRandomNumberString();
		
		myUser.setOtp(otp);
		
		myUserService.saveMyUser(myUser);
		
		return otp;
	}
	
	public void removeMyUserOtp(MyUser myUser) {
		try {
			Timer timer = new Timer();
			timer.schedule(new OtpHandler(myUser, myUserService), timeToDeleteOtp);	
		} catch (Exception e) {
			System.out.println("Could not remove OTP -- \n\n\n" + e.getStackTrace());
		}
		
	}
	
}
