package com.snplog.backend.thirdprtapi;

import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.List;

import org.apache.commons.codec.binary.Base64;
import org.apache.http.HttpEntity;
import org.apache.http.HttpHeaders;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import org.json.JSONObject;
import org.springframework.stereotype.Component;

import com.snplog.backend.models.RouteXLLocation;

@Component
public class RoutePlanner {

	public List<RouteXLLocation> getQuickestRoute(List<? extends BasicNameValuePair> request, List<RouteXLLocation> locations) throws ClientProtocolException, IOException {
		CloseableHttpClient httpClient = HttpClients.createDefault();
		HttpPost httpPost = new HttpPost("https://api.routexl.com/tour");
		httpPost.addHeader(HttpHeaders.AUTHORIZATION, "Basic " + new String(Base64.encodeBase64(("snplog2020" + ":" + "gewoftjmdckweiiu").getBytes(StandardCharsets.ISO_8859_1))));
		
		httpPost.setHeader("Content-type", "application/x-www-form-urlencoded");
		
		httpPost.setEntity(new UrlEncodedFormEntity(request));
		

		CloseableHttpResponse response = httpClient.execute(httpPost);
		
		JSONObject jsonObject = null;
		
		try {
			if(response.getStatusLine().getStatusCode() != 200) {
				return null;
			}
			HttpEntity entity = response.getEntity();
			
			String responseString = EntityUtils.toString(entity);
				
			jsonObject = new JSONObject(responseString);
			EntityUtils.consume(entity);
		} catch(ClientProtocolException cpe){
			return null;
		} catch(IOException ioe){
			return null;
		} finally {
			response.close();
		}
		
		JSONObject route = jsonObject.getJSONObject("route");
		List<Integer> cabinIds = new ArrayList<>();
		
		for(int i = 0; i < locations.size(); i++) {
			cabinIds.add(Integer.parseInt(route.getJSONObject(i + "").getString("name")));
		}
		
		return sortLocations(cabinIds, locations);
	}
	
	public void getRouteXlStatus() throws ClientProtocolException, IOException {
		CloseableHttpClient httpClient = HttpClients.createDefault();
		HttpGet httpGet = new HttpGet("https://api.routexl.com/status/Hello+world");
		httpGet.addHeader(HttpHeaders.CONTENT_TYPE, "application/json");
		httpGet.addHeader(HttpHeaders.AUTHORIZATION, "Basic " + new String(Base64.encodeBase64(("snplog2020" + ":" + "gewoftjmdckweiiu").getBytes(StandardCharsets.ISO_8859_1))));

		CloseableHttpResponse response = httpClient.execute(httpGet);
		
		JSONObject jsonObject = null;
		
		try {
			System.out.println(response);
		} finally {
			response.close();
		}
		
	}
	
	private List<RouteXLLocation> sortLocations(List<Integer> cabinIds, List<RouteXLLocation> locations){
		List<RouteXLLocation> result = new ArrayList<>();
		
		for(Integer id : cabinIds) {
			for(RouteXLLocation location : locations) {
				if(location.getCabinId() == id) {
					result.add(location);
					break;
				}
			}
		}
		return result;
	}
	
}
