package com.snplog.backend.thirdprtapi;

import java.io.IOException;
import java.sql.Timestamp;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.Date;

import org.apache.commons.codec.binary.Base64;
import org.apache.http.HttpEntity;
import org.apache.http.client.ClientProtocolException;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.util.EntityUtils;
import org.json.JSONObject;
import org.springframework.stereotype.Service;

import com.snplog.backend.entity.WeatherStation;

@Service
public class WeatherData {
	
	private final double MAX_DISTANSE_TO_SENSOR = 50.00;

	// function to get nearest sensor of a location
		public WeatherStation getNearestSensor(double longitude, double latitude) throws ClientProtocolException, IOException {
			CloseableHttpClient httpClient = HttpClients.createDefault();
			// %20 = space
			HttpGet httpGet = new HttpGet("https://frost.met.no/sources/v0.jsonld?geometry=nearest(POINT(" + longitude + "%20" + latitude + "))");
			httpGet.addHeader("Authorization", "Basic " + new String(Base64.encodeBase64(("2ac1e693-03ca-44cf-8b2b-a53259b8491a"+":").getBytes("UTF-8"))));
			CloseableHttpResponse response = httpClient.execute(httpGet);
			
			JSONObject jsonObject = null;
			
			try {
				if(response.getStatusLine().getStatusCode() != 200) {
					return null;
				}
				HttpEntity entity = response.getEntity();
				
				String responseString = EntityUtils.toString(entity);
		
				jsonObject = new JSONObject(responseString);
				EntityUtils.consume(entity);
			} finally {
				response.close();
			}
			
			if(jsonObject != null) {
				JSONObject data = jsonObject.getJSONArray("data").getJSONObject(0);
				if(Float.parseFloat(data.get("distance").toString()) < MAX_DISTANSE_TO_SENSOR) {
					String wid = data.getString("id");
					double longitudeData = data.getJSONObject("geometry").getJSONArray("coordinates").getDouble(0);
					double latitudeData = data.getJSONObject("geometry").getJSONArray("coordinates").getDouble(1);
					
					Timestamp now = Timestamp.valueOf(LocalDateTime.now());
					
					return new WeatherStation(
								0,
								now,
								wid,
								longitudeData,
								latitudeData
							);
				}
			}
			return null;
		}
		
		public String getSurfaceSnowThickness(String weatherStationId) throws ClientProtocolException, IOException {
			CloseableHttpClient httpClient = HttpClients.createDefault();
			
			String pattern = "yyyy-MM-dd";
			SimpleDateFormat simpleDateFormat = new SimpleDateFormat(pattern);
			String dateToday = simpleDateFormat.format(new Date());
			String dateYesterday = simpleDateFormat.format(new Date(System.currentTimeMillis() - 24 * 60 * 60 * 1000));
			
			// %20 = space
			HttpGet httpGet = new HttpGet("https://frost.met.no/observations/v0.jsonld?sources=" + weatherStationId + "&referencetime=" + dateYesterday + "%2F" + dateToday + "&elements=surface_snow_thickness");
			httpGet.addHeader("Authorization", "Basic " + new String(Base64.encodeBase64(("2ac1e693-03ca-44cf-8b2b-a53259b8491a"+":").getBytes("UTF-8"))));
			CloseableHttpResponse response = httpClient.execute(httpGet);
			
			JSONObject jsonObject = null;
			
			try {
				HttpEntity entity = response.getEntity();
				
				String responseString = EntityUtils.toString(entity);
								
				int statusCode = response.getStatusLine().getStatusCode();
				
				if(statusCode == 200) {
					jsonObject = new JSONObject(responseString);
					EntityUtils.consume(entity);
					if(jsonObject != null) {
						Object data = jsonObject.getJSONArray("data").getJSONObject(0).getJSONArray("observations").getJSONObject(0).get("value");
						return data.toString();
					}
				} else {
					return null;
				}
		
				
			} finally {
				response.close();
			}
			

			return null;
		}
	
}
