package com.snplog.backend.timertasks;

import java.io.IOException;
import java.sql.Timestamp;
import java.time.LocalDateTime;
import java.util.List;
import java.util.TimerTask;

import javax.annotation.PostConstruct;

import org.apache.http.client.ClientProtocolException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import com.snplog.backend.entity.SnowStatistic;
import com.snplog.backend.entity.WeatherStation;
import com.snplog.backend.repository.SnowStatisticRepository;
import com.snplog.backend.repository.WeatherStationRepository;
import com.snplog.backend.thirdprtapi.WeatherData;

@Component
public class WeatherHandler extends TimerTask {
	
	private WeatherStationRepository weatherStationRepository;
	
	private SnowStatisticRepository snowStatisticRepository;
	
	private WeatherData weatherData;
	
	@Autowired
	public WeatherHandler(
			WeatherStationRepository weatherStationRepository,
			SnowStatisticRepository snowStatisticRepository,
			WeatherData weatherData) {
		this.weatherStationRepository = weatherStationRepository;
		this.snowStatisticRepository = snowStatisticRepository;
		this.weatherData = weatherData;
	}

	@PostConstruct
	@Override
	public void run() {
		if(weatherStationRepository != null) {
			List<WeatherStation> weatherStations = weatherStationRepository.findAll();
			Timestamp timestamp = Timestamp.valueOf(LocalDateTime.now());
			for (WeatherStation weatherStation : weatherStations) {
				
				try {
					String snowThickness = weatherData.getSurfaceSnowThickness(weatherStation.getFrostId());
					if(snowThickness != null) {
						snowStatisticRepository.save(
								new SnowStatistic(
										0,
										weatherStation,
										timestamp,
										Integer.parseInt(snowThickness)
										)
								);
					}
					
				} catch (NumberFormatException e) {
					e.printStackTrace();
				} catch (ClientProtocolException e) {
					e.printStackTrace();
				} catch (IOException e) {
					e.printStackTrace();
				}
			}
				
			
		} 
		
	}

}
