CREATE SCHEMA  IF NOT EXISTS `snowplowdb`;
USE `snowplowdb`;

SET FOREIGN_KEY_CHECKS = 0;

--
-- Table structure for table `users`
--

DROP TABLE IF EXISTS `users`;

CREATE TABLE `users` (
  `id` int(24) NOT NULL AUTO_INCREMENT,
  `first_name` varchar(45) DEFAULT NULL,
  `last_name` varchar(45) DEFAULT NULL,
  `email` varchar(45) NOT NULL,
  `otp` varchar(12) DEFAULT NULL,
  `phone_number` varchar(45) DEFAULT NULL,
  `street_adress` varchar(45) DEFAULT NULL,
  `city` varchar(45) DEFAULT NULL,
  `country` varchar(45) DEFAULT NULL,
  `time_created` timestamp NOT NULL,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=latin1;

--
-- Table structure for table `changes`
--

DROP TABLE IF EXISTS `changes`;

CREATE TABLE `changes` (
  `id` int(24) NOT NULL AUTO_INCREMENT,
  `changed_by` int(24) NOT NULL,
  `created` timestamp NOT NULL,
  `table_name_` varchar(256) DEFAULT NULL,
  `column_name_` varchar(256) DEFAULT NULL,
  `row_id` int(24) DEFAULT NULL,
  `old_value` varchar(256) DEFAULT NULL,
  `new_value` varchar(256) DEFAULT NULL,
  PRIMARY KEY (`id`),
  FOREIGN KEY (`changed_by`) REFERENCES `users` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=latin1;

--
-- Table structure for table `plower_requests`
--

DROP TABLE IF EXISTS `plower_requests`;

CREATE TABLE `plower_requests` (
  `id` int(24) NOT NULL AUTO_INCREMENT,
  `user_id` int(24) NOT NULL,
  `date_requested` timestamp NOT NULL,
  `date_responded` timestamp,
  `request_status` boolean DEFAULT FALSE,
  PRIMARY KEY (`id`),
  FOREIGN KEY (`user_id`) REFERENCES `users` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=latin1;

--
-- Table structure for table `cabins`
--

DROP TABLE IF EXISTS `cabins`;

CREATE TABLE `cabins` (
  `id` int(24) NOT NULL AUTO_INCREMENT,
  `user_id` int(24) DEFAULT NULL,
  `cabin_area_id` int(24) DEFAULT NULL,
  `cabin_name` varchar (255) DEFAULT NULL,
  `longitude` float,
  `latitude` float,
  `country` varchar (255),
  `region` varchar(255),
  `municipality`varchar (255),
  `street_adress` varchar(255),
  `kid` int(8) NOT NULL, -- kommunenr
  `gid` int(8) NOT NULL, -- gardsnr
  `bid` int(8) NOT NULL, -- bruksnr
  `sid` int(8) , -- seksjonsnr
  `cabin_status` ENUM('red', 'yellow', 'green', 'gray', 'black'),
  `last_plowed` timestamp,
  `created` timestamp,
  PRIMARY KEY (`id`),
  FOREIGN KEY (`user_id`) REFERENCES `users` (`id`),
  FOREIGN KEY (`cabin_area_id`) REFERENCES `cabin_areas` (`id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=latin1;

--
-- Table structure for table `plowing_requests`
--

DROP TABLE IF EXISTS `plowing_requests`;

CREATE TABLE `plowing_requests` (
  `id` int(24) NOT NULL AUTO_INCREMENT,
  `cabin_id` int(24) NOT NULL, 
  `cabin_area_id` int(24) NOT NULL,
  `date_of_arrival` timestamp,
  `date_of_departure` timestamp,
  `date_requested` timestamp,
  `date_completed` timestamp,
  `completed` boolean,
  `description_` varchar(255),
  PRIMARY KEY (`id`),
  FOREIGN KEY (`cabin_id`) REFERENCES `cabins` (`id`),
  FOREIGN KEY (`cabin_area_id`) REFERENCES `cabin_areas` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `roles`
--

DROP TABLE IF EXISTS `roles`;

CREATE TABLE `roles` (
  `role` varchar(24) NOT NULL,
  `description` varchar(256) DEFAULT NULL,
  PRIMARY KEY (`role`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `plower_positions`
--

DROP TABLE IF EXISTS `plower_positions`;

CREATE TABLE `plower_positions` (
  `id` int(24) NOT NULL auto_increment,
  `plower_id` int(24) NOT NULL,
  `timestamp_` timestamp,
  `longitude` float,
  `latitude` float,
  PRIMARY KEY (`id`),
  FOREIGN KEY (`plower_id`) REFERENCES `users` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `cabin_areas`
--

DROP TABLE IF EXISTS `cabin_areas`;

CREATE TABLE `cabin_areas` (
  `id` int(24) NOT NULL auto_increment,
  `cabin_area_name` varchar(128) NOT NULL,
  `created` timestamp,
  `longitude` float,
  `latitude` float,
  `radius`int(64),
  `nearest_weather_station` int(24),
  PRIMARY KEY (`id`),
  FOREIGN KEY (`nearest_weather_station`) REFERENCES `weather_stations` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `weather_stations`
--

DROP TABLE IF EXISTS `weather_stations`;

CREATE TABLE `weather_stations` (
  `id` int(24) NOT NULL auto_increment,
  `created` timestamp,
  `frost_id`varchar(12) NOT NULL,
  `longitude` float,
  `latitude` float,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `snow_statistics`
--

DROP TABLE IF EXISTS `snow_statistics`;

CREATE TABLE `snow_statistics` (
  `id` int(24) NOT NULL auto_increment,
  `weather_station_id` int(24) NOT NULL,
  `created` timestamp,
  `surface_snow_thickness`int(64),
  PRIMARY KEY (`id`),
  FOREIGN KEY (`weather_station_id`) REFERENCES `weather_stations` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `user_roles`
--

DROP TABLE IF EXISTS `user_roles`;

CREATE TABLE `user_roles` (
 `id` int(24) NOT NULL auto_increment,
 `role`varchar(24) NOT NULL,
 `user_id`int(24) NOT NULL,
  PRIMARY KEY (`id`),
  FOREIGN KEY (`user_id`) REFERENCES `users` (`id`),
  FOREIGN KEY (`role`) REFERENCES `roles` (`role`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `user_threads`
--

DROP TABLE IF EXISTS `user_threads`;

CREATE TABLE `user_threads` (
 `id` int(24) NOT NULL auto_increment,
 `thread_id`int(24) NOT NULL,
 `user_id`int(24) NOT NULL,
  PRIMARY KEY (`id`),
  FOREIGN KEY (`user_id`) REFERENCES `users` (`id`),
  FOREIGN KEY (`thread_id`) REFERENCES `message_threads` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `plower_cabin_area`
--

DROP TABLE IF EXISTS `plower_cabin_area`;

CREATE TABLE `plower_cabin_area` (
 `id` int(24) NOT NULL auto_increment,
 `plower_id`int(24) NOT NULL,
 `cabin_area_id`int(24) NOT NULL,
 `valid` boolean DEFAULT FALSE,
 `date_created` timestamp,
 `date_ended` timestamp,
  PRIMARY KEY (`id`),
  FOREIGN KEY (`plower_id`) REFERENCES `users` (`id`),
  FOREIGN KEY (`cabin_area_id`) REFERENCES `cabin_areas` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `message_threads`
--

DROP TABLE IF EXISTS `message_threads`;

CREATE TABLE `message_threads` (
 `id` int(24) NOT NULL auto_increment,
 `date_created` timestamp,
 `closed` boolean DEFAULT false,
 `date_closed` timestamp,
  PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

--
-- Table structure for table `messages`
--

DROP TABLE IF EXISTS `messages`;

CREATE TABLE `messages` (
 `id` int(24) NOT NULL auto_increment,
 `sender_id`int(24) NOT NULL,
 `thread_id`int(24) NOT NULL,
 `message` varchar(512),
 `date_created` timestamp,
  PRIMARY KEY (`id`),
  FOREIGN KEY (`sender_id`) REFERENCES `users` (`id`),
  FOREIGN KEY (`thread_id`) REFERENCES `message_threads` (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=latin1;

INSERT INTO `users`(id, first_name, last_name, email, phone_number, street_adress, city, country, time_created) VALUE(1, 'Theodor', 'Urtegård', 'theodoru@stud.ntnu.no', '97424218', 'Nedre Strandgate 9 D', 'Ålesund', 'Norge', '2020-02-20 15:00:00.000000');
INSERT INTO `users`(id, first_name, last_name, email, phone_number, street_adress, city, country, time_created) VALUE(2, 'Regine', 'Namsen', 'navn@email.no', '12345678', 'Øvre Strandgate 8 A', 'Giske', 'Norge', '2020-03-20 15:00:00.000000');
INSERT INTO `users`(id, first_name, last_name, email, phone_number, street_adress, city, country, time_created) VALUE(3, 'Henrik', 'Olsen', 'navn@email.no', '23456789', 'Sideveis Strandgate 20', 'Sula', 'Norge', '2020-04-20 15:00:00.000000');
INSERT INTO `users`(id, first_name, last_name, email, phone_number, street_adress, city, country, time_created) VALUE(4, 'Marius', 'Trulsen', 'navn@email.no', '98765432', 'Hosliggende Strandgate 1', 'Gjernmundnes', 'Norge', '2019-01-20 15:00:00.000000');
INSERT INTO `users`(id, first_name, last_name, email, phone_number, street_adress, city, country, time_created) VALUE(5, 'Tone', 'Isaksen', 'navn@email.no', '87654321', 'Åleveg 1', 'Godøy', 'Norge', '2019-02-20 15:00:00.000000');
INSERT INTO `users`(id, first_name, last_name, email, phone_number, street_adress, city, country, time_created) VALUE(6, 'Kurt', 'Giske', 'navn@email.no', '12341234', 'Giskeveg 9', 'Vigra', 'Norge', '2019-03-20 15:00:00.000000');
INSERT INTO `users`(id, first_name, last_name, email, phone_number, street_adress, city, country, time_created) VALUE(7, 'Ida', 'Hessen', 'navn@email.no', '23452345', 'Godøyveg 9', 'Ålesund', 'Norge', '2019-04-20 15:00:00.000000');
INSERT INTO `users`(id, first_name, last_name, email, phone_number, street_adress, city, country, time_created) VALUE(8, 'Leander', 'Knudsen', 'navn@email.no', '34563456', 'Jolsveg 2', 'Langevåg', 'Norge', '2019-04-20 15:00:00.000000');
INSERT INTO `users`(id, first_name, last_name, email, phone_number, street_adress, city, country, time_created) VALUE(9, 'Geir', 'Solund', 'navn@email.no', '45674567', 'Gjerdeveg 2', 'Ålesund', 'Norge', '2019-05-20 15:00:00.000000');
INSERT INTO `users`(id, first_name, last_name, email, phone_number, street_adress, city, country, time_created) VALUE(10, 'Hallvard', 'Gårsund', 'navn@email.no', '56785678', 'Nyveg 23', 'Ålesund', 'Norge', '2019-06-20 15:00:00.000000');

INSERT INTO `roles`(role, description) VALUE('admin', 'This user should have access to all user management');
INSERT INTO `roles`(role, description) VALUE('plower', 'This user should have access to all plower functionality');
INSERT INTO `roles`(role, description) VALUE('cabinOwner', 'This user should have access to all cabin functionality');

INSERT INTO `user_roles` (id, role, user_id) VALUE(1, 'admin', 1);
INSERT INTO `user_roles` (id, role, user_id) VALUE(2, 'plower', 1);
INSERT INTO `user_roles` (id, role, user_id) VALUE(3, 'cabinOwner', 1);
INSERT INTO `user_roles` (id, role, user_id) VALUE(4, 'cabinOwner', 2);
INSERT INTO `user_roles` (id, role, user_id) VALUE(5, 'cabinOwner', 3);
INSERT INTO `user_roles` (id, role, user_id) VALUE(6, 'cabinOwner', 4);
INSERT INTO `user_roles` (id, role, user_id) VALUE(7, 'cabinOwner', 5);
INSERT INTO `user_roles` (id, role, user_id) VALUE(8, 'cabinOwner', 6);
INSERT INTO `user_roles` (id, role, user_id) VALUE(9, 'cabinOwner', 7);
INSERT INTO `user_roles` (id, role, user_id) VALUE(10, 'cabinOwner', 8);
INSERT INTO `user_roles` (id, role, user_id) VALUE(11, 'cabinOwner', 9);
INSERT INTO `user_roles` (id, role, user_id) VALUE(12,'cabinOwner', 10);

INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(1, 5,'2012-02-20 15:00:00.000000', 'users', 'first_name', '1', 'Todoro', 'Nedoro');
INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(2, 4,'2019-02-20 15:00:00.000000', 'users', 'first_name', '2', 'Todoro', 'Nedoro');
INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(3, 3,'2019-03-20 15:00:00.000000', 'users', 'first_name', '3', 'Todoro', 'Nedoro');
INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(4, 2,'2019-04-20 15:00:00.000000', 'users', 'first_name', '4', 'Todoro', 'Nedoro');
INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(5, 1,'2019-05-20 15:00:00.000000', 'users', 'first_name', '5', 'Todoro', 'Nedoro');
INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(6, 9,'2019-06-20 15:00:00.000000', 'users', 'first_name', '6', 'Todoro', 'Nedoro');
INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(7, 8,'2019-07-20 15:00:00.000000', 'users', 'first_name', '7', 'Todoro', 'Nedoro');
INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(8, 7,'2019-08-20 15:00:00.000000', 'users', 'first_name', '8', 'Todoro', 'Nedoro');
INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(9, 6,'2019-09-20 15:00:00.000000', 'users', 'first_name', '9', 'Todoro', 'Nedoro');
INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(10, 5,'2019-10-20 15:00:00.000000', 'users', 'first_name', '1', 'Todoro', 'Nedoro');
INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(11, 4,'2019-11-20 15:00:00.000000', 'users', 'first_name', '2', 'Todoro', 'Nedoro');
INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(12, 3,'2019-12-20 15:00:00.000000', 'users', 'first_name', '3', 'Todoro', 'Nedoro');
INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(13, 2,'2019-01-20 15:00:00.000000', 'users', 'first_name', '4', 'Todoro', 'Nedoro');
INSERT INTO `changes` (id, changed_by, created, table_name_, column_name_, row_id, old_value, new_value) VALUE(14, 1,'2019-02-10 15:00:00.000000', 'users', 'first_name', '5', 'Todoro', 'Nedoro');

INSERT INTO `plower_requests`(id, user_id, date_requested, date_responded, request_status) VALUE(1, 1, '2020-02-01 15:00:00.000000', '2020-02-20 15:00:00.000000', true);
INSERT INTO `plower_requests`(id, user_id, date_requested, date_responded, request_status) VALUE(2, 2, '2020-02-02 15:00:00.000000', null, false);
INSERT INTO `plower_requests`(id, user_id, date_requested, date_responded, request_status) VALUE(3, 3, '2020-02-03 15:00:00.000000', '2020-02-20 15:00:00.000000', true);
INSERT INTO `plower_requests`(id, user_id, date_requested, date_responded, request_status) VALUE(4, 4, '2020-02-04 15:00:00.000000', null, false);
INSERT INTO `plower_requests`(id, user_id, date_requested, date_responded, request_status) VALUE(5, 5, '2020-02-05 15:00:00.000000', null, false);
INSERT INTO `plower_requests`(id, user_id, date_requested, date_responded, request_status) VALUE(6, 6, '2020-02-06 15:00:00.000000', '2020-02-20 15:00:00.000000', true);
INSERT INTO `plower_requests`(id, user_id, date_requested, date_responded, request_status) VALUE(7, 7, '2020-02-07 15:00:00.000000', '2020-02-20 15:00:00.000000', true);
INSERT INTO `plower_requests`(id, user_id, date_requested, date_responded, request_status) VALUE(8, 8, '2020-02-08 15:00:00.000000', null, false);
INSERT INTO `plower_requests`(id, user_id, date_requested, date_responded, request_status) VALUE(9, 9, '2020-02-09 15:00:00.000000', null, false);
INSERT INTO `plower_requests`(id, user_id, date_requested, date_responded, request_status) VALUE(10, 1, '2020-02-10 15:00:00.000000', '2020-02-20 15:00:00.000000', true);

INSERT INTO `cabins`(id, user_id, cabin_area_id, cabin_name, longitude, latitude, country, region, municipality, street_adress, kid, gid, bid, sid, cabin_status, last_plowed, created) VALUE(1, 1, 1, 'hytte1', 6.1118784, 62.4634805, 'Norway', 'Oppland', 'Lesja', 'Bjorligata 1', 1532, 130, 93, 0, 'green', '2020-02-20 15:00:00.000000', '2020-02-01 15:00:00.000000');
INSERT INTO `cabins`(id, user_id, cabin_area_id, cabin_name, longitude, latitude, country, region, municipality, street_adress, kid, gid, bid, sid, cabin_status, last_plowed, created) VALUE(2, 1, 1, 'hytte2', 6.1350914, 62.4587064, 'Norway', 'Oppland', 'Lesja', 'Bjorligata 2', 1532, 130, 93, 0, 'green', '2020-02-21 15:00:00.000000', '2020-02-02 15:00:00.000000');
INSERT INTO `cabins`(id, user_id, cabin_area_id, cabin_name, longitude, latitude, country, region, municipality, street_adress, kid, gid, bid, sid, cabin_status, last_plowed, created) VALUE(3, 1, 1, 'hytte3', 6.200897, 62.4696918, 'Norway', 'Oppland', 'Lesja', 'Bjorligata 3', 1532, 130, 93, 0, 'green', '2020-02-22 15:00:00.000000', '2020-02-03 15:00:00.000000');
INSERT INTO `cabins`(id, user_id, cabin_area_id, cabin_name, longitude, latitude, country, region, municipality, street_adress, kid, gid, bid, sid, cabin_status, last_plowed, created) VALUE(4, 1, 1, 'hytte4', 6.2232578, 62.4736918, 'Norway', 'Oppland', 'Lesja', 'Bjorligata 4', 1532, 130, 93, 0, 'green', '2020-02-23 15:00:00.000000', '2020-02-04 15:00:00.000000');
INSERT INTO `cabins`(id, user_id, cabin_area_id, cabin_name, longitude, latitude, country, region, municipality, street_adress, kid, gid, bid, sid, cabin_status, last_plowed, created) VALUE(5, 1, 1, 'hytte5', 6.2635837, 62.4651049, 'Norway', 'Oppland', 'Lesja', 'Bjorligata 5', 1532, 130, 93, 0, 'green', '2020-02-24 15:00:00.000000', '2020-02-05 15:00:00.000000');
INSERT INTO `cabins`(id, user_id, cabin_area_id, cabin_name, longitude, latitude, country, region, municipality, street_adress, kid, gid, bid, sid, cabin_status, last_plowed, created) VALUE(6, 2, 2, 'hytte6', 6.345535, 62.4725916, 'Norway', 'Oppland', 'Lesja', 'Bjorligata 6', 1532, 130, 93, 0, 'green', '2020-02-25 15:00:00.000000', '2020-02-06 15:00:00.000000');
INSERT INTO `cabins`(id, user_id, cabin_area_id, cabin_name, longitude, latitude, country, region, municipality, street_adress, kid, gid, bid, sid, cabin_status, last_plowed, created) VALUE(7, 2, 2, 'hytte7', 6.3535863, 62.4541702, 'Norway', 'Oppland', 'Lesja', 'Bjorligata 7', 1532, 130, 93, 0, 'green', '2020-02-22 15:00:00.000000', '2020-02-07 15:00:00.000000');
INSERT INTO `cabins`(id, user_id, cabin_area_id, cabin_name, longitude, latitude, country, region, municipality, street_adress, kid, gid, bid, sid, cabin_status, last_plowed, created) VALUE(8, 2, 2, 'hytte8', 6.3637375, 62.4440993, 'Norway', 'Oppland', 'Lesja', 'Bjorligata 8', 1532, 130, 93, 0, 'green', '2020-02-23 15:00:00.000000', '2020-02-08 15:00:00.000000');
INSERT INTO `cabins`(id, user_id, cabin_area_id, cabin_name, longitude, latitude, country, region, municipality, street_adress, kid, gid, bid, sid, cabin_status, last_plowed, created) VALUE(9, 3, 3, 'hytte9', 6.3727054, 62.4426992, 'Norway', 'Oppland', 'Lesja', 'Bjorligata 9', 1532, 130, 93, 0, 'green', '2020-02-24 15:00:00.000000', '2020-02-09 15:00:00.000000');
INSERT INTO `cabins`(id, user_id, cabin_area_id, cabin_name, longitude, latitude, country, region, municipality, street_adress, kid, gid, bid, sid, cabin_status, last_plowed, created) VALUE(10, 4, 4, 'hytte10', 6.4137192, 62.433542, 'Norway', 'Oppland', 'Lesja', 'Bjorligata 10', 1532, 130, 93, 0, 'green', '2020-02-25 15:00:00.000000', '2020-02-10 15:00:00.000000');
INSERT INTO `cabins`(id, user_id, cabin_area_id, cabin_name, longitude, latitude, country, region, municipality, street_adress, kid, gid, bid, sid, cabin_status, last_plowed, created) VALUE(11, 5, 5, 'hytte11', 6.4631469, 62.4348312, 'Norway', 'Oppland', 'Lesja', 'Bjorligata 11', 1532, 130, 93, 0, 'green', '2020-02-26 15:00:00.000000', '2020-02-11 15:00:00.000000');
INSERT INTO `cabins`(id, user_id, cabin_area_id, cabin_name, longitude, latitude, country, region, municipality, street_adress, kid, gid, bid, sid, cabin_status, last_plowed, created) VALUE(12, 6, 6, 'hytte12', 6.4897469, 62.4330289, 'Norway', 'Oppland', 'Lesja', 'Bjorligata 12', 1532, 130, 93, 0, 'green', '2020-02-20 15:00:00.000000', '2020-02-12 15:00:00.000000');
INSERT INTO `cabins`(id, user_id, cabin_area_id, cabin_name, longitude, latitude, country, region, municipality, street_adress, kid, gid, bid, sid, cabin_status, last_plowed, created) VALUE(13, 7, 7, 'hytte13', 6.4003071, 62.425016, 'Norway', 'Oppland', 'Lesja', 'Bjorligata 13', 1532, 130, 93, 0, 'green', '2020-02-19 15:00:00.000000', '2020-02-13 15:00:00.000000');

INSERT INTO `plowing_requests`(id, cabin_id, cabin_area_id, date_of_arrival, date_of_departure, date_requested, date_completed, completed, description_) VALUE(1, 1, 1, '2020-12-12 15:00:00.000000', '2020-12-15 15:00:00.000000', '2020-02-01 15:00:00.000000', null, false, 'Plow my cabin plox');
INSERT INTO `plowing_requests`(id, cabin_id, cabin_area_id, date_of_arrival, date_of_departure, date_requested, date_completed, completed, description_) VALUE(2, 1, 1, '2020-12-12 15:00:00.000000', '2020-12-15 15:00:00.000000', '2020-02-02 15:00:00.000000', '2020-02-13 15:00:00.000000', true, 'Plow my cabin plox');
INSERT INTO `plowing_requests`(id, cabin_id, cabin_area_id, date_of_arrival, date_of_departure, date_requested, date_completed, completed, description_) VALUE(3, 1, 1, '2020-12-12 15:00:00.000000', '2020-12-15 15:00:00.000000', '2020-02-03 15:00:00.000000', null, false, 'Plow my cabin plox');
INSERT INTO `plowing_requests`(id, cabin_id, cabin_area_id, date_of_arrival, date_of_departure, date_requested, date_completed, completed, description_) VALUE(4, 4, 1, '2020-12-12 15:00:00.000000', '2020-12-15 15:00:00.000000', '2020-02-04 15:00:00.000000', '2020-02-13 15:00:00.000000', true, 'Plow my cabin plox');
INSERT INTO `plowing_requests`(id, cabin_id, cabin_area_id, date_of_arrival, date_of_departure, date_requested, date_completed, completed, description_) VALUE(5, 5, 1, '2020-12-12 15:00:00.000000', '2020-12-15 15:00:00.000000', '2020-02-05 15:00:00.000000', null, false, 'Plow my cabin plox');
INSERT INTO `plowing_requests`(id, cabin_id, cabin_area_id, date_of_arrival, date_of_departure, date_requested, date_completed, completed, description_) VALUE(6, 6, 2, '2020-12-12 15:00:00.000000', '2020-12-15 15:00:00.000000', '2020-02-06 15:00:00.000000', '2020-02-13 15:00:00.000000', true, 'Plow my cabin plox');
INSERT INTO `plowing_requests`(id, cabin_id, cabin_area_id, date_of_arrival, date_of_departure, date_requested, date_completed, completed, description_) VALUE(7, 7, 2, '2020-12-12 15:00:00.000000', '2020-12-15 15:00:00.000000', '2020-02-07 15:00:00.000000', null, false, 'Plow my cabin plox');
INSERT INTO `plowing_requests`(id, cabin_id, cabin_area_id, date_of_arrival, date_of_departure, date_requested, date_completed, completed, description_) VALUE(8, 8, 2, '2020-12-12 15:00:00.000000', '2020-12-15 15:00:00.000000', '2020-02-08 15:00:00.000000', '2020-02-13 15:00:00.000000', true, 'Plow my cabin plox');
INSERT INTO `plowing_requests`(id, cabin_id, cabin_area_id, date_of_arrival, date_of_departure, date_requested, date_completed, completed, description_) VALUE(9, 9, 3, '2020-12-12 15:00:00.000000', '2020-12-15 15:00:00.000000', '2020-02-09 15:00:00.000000', null, false, 'Plow my cabin plox');
INSERT INTO `plowing_requests`(id, cabin_id, cabin_area_id, date_of_arrival, date_of_departure, date_requested, date_completed, completed, description_) VALUE(10, 1, 1, '2020-12-12 15:00:00.000000', '2020-12-15 15:00:00.000000', '2020-02-10 15:00:00.000000', '2020-02-13 15:00:00.000000', true, 'Plow my cabin plox');
INSERT INTO `plowing_requests`(id, cabin_id, cabin_area_id, date_of_arrival, date_of_departure, date_requested, date_completed, completed, description_) VALUE(11, 2, 1, '2020-12-12 15:00:00.000000', '2020-12-15 15:00:00.000000', '2020-02-11 15:00:00.000000', null, false, 'Plow my cabin plox');
INSERT INTO `plowing_requests`(id, cabin_id, cabin_area_id, date_of_arrival, date_of_departure, date_requested, date_completed, completed, description_) VALUE(12, 3, 1, '2020-12-12 15:00:00.000000', '2020-12-15 15:00:00.000000', '2020-02-12 15:00:00.000000', '2020-02-13 15:00:00.000000', true, 'Plow my cabin plox');

INSERT INTO `cabin_areas`(id, cabin_area_name, created, longitude, latitude, radius) VALUE(1, 'Bjorli hyttefelt', '2020-02-02 15:00:00.000000', 62.513027, 6.062299, 50);
INSERT INTO `cabin_areas`(id, cabin_area_name, created, longitude, latitude, radius) VALUE(2, 'Namsos hyttefelt', '2020-02-03 15:00:00.000000', 62.513027, 6.062299, 70);
INSERT INTO `cabin_areas`(id, cabin_area_name, created, longitude, latitude, radius) VALUE(3, 'Gudmund hyttefelt', '2020-02-04 15:00:00.000000', 62.513027, 6.062299, 120);
INSERT INTO `cabin_areas`(id, cabin_area_name, created, longitude, latitude, radius) VALUE(4, 'Hjertlig hyttefelt', '2020-02-05 15:00:00.000000', 62.513027, 6.062299, 50);
INSERT INTO `cabin_areas`(id, cabin_area_name, created, longitude, latitude, radius) VALUE(5, 'Norges hyttefelt', '2020-02-06 15:00:00.000000', 62.513027, 6.062299, 50);
INSERT INTO `cabin_areas`(id, cabin_area_name, created, longitude, latitude, radius) VALUE(6, 'Åle hyttefelt', '2020-02-07 15:00:00.000000', 62.513027, 6.062299, 23);
INSERT INTO `cabin_areas`(id, cabin_area_name, created, longitude, latitude, radius) VALUE(7, 'Åre hyttefelt', '2020-02-08 15:00:00.000000', 62.513027, 6.062299, 25);
INSERT INTO `cabin_areas`(id, cabin_area_name, created, longitude, latitude, radius) VALUE(8, 'Sunde hyttefelt', '2020-02-09 15:00:00.000000', 62.513027, 6.062299, 26);
INSERT INTO `cabin_areas`(id, cabin_area_name, created, longitude, latitude, radius) VALUE(9, 'Strand hyttefelt', '2020-02-10 15:00:00.000000', 62.513027, 6.062299, 13);
INSERT INTO `cabin_areas`(id, cabin_area_name, created, longitude, latitude, radius) VALUE(10, 'Oslo hyttefelt', '2020-02-11 15:00:00.000000', 62.513027, 6.062299, 230);
INSERT INTO `cabin_areas`(id, cabin_area_name, created, longitude, latitude, radius) VALUE(11, 'Skodje hyttefelt', '2020-02-12 15:00:00.000000', 62.513027, 6.062299, 60);
INSERT INTO `cabin_areas`(id, cabin_area_name, created, longitude, latitude, radius) VALUE(12, 'Nedredal hyttefelt', '2020-02-13 15:00:00.000000', 62.513027, 6.062299, 40);





SET FOREIGN_KEY_CHECKS = 1;
