import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:snow_plow/components/PlowingRequestCard.dart';
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/CabinAreaDTO.dart';
import 'package:snow_plow/models/PlowingRequestDTO.dart';
import 'package:snow_plow/services/CabinAreaService.dart';
import 'package:snow_plow/services/PlowingRequestService.dart';
import 'package:snow_plow/services/RouteService.dart';
import 'package:snow_plow/map/map_view.dart';

class CabinAreaPage extends StatefulWidget {
  static const routeName = "/cabinArea";

  _CabinAreaPageState createState() => _CabinAreaPageState();
}

class _CabinAreaPageState extends State<CabinAreaPage> {
  PlowingRequestService plowingRequestService = new PlowingRequestService();
  CabinAreaService cabinAreaService = new CabinAreaService();
  CabinAreaDTO cabinArea = globals.selectedCabinArea;
  List<PlowingRequestDTO> plowingRequests = new List();
  String _deletePlowingRequestFailedText = "";

  RouteService routeService = new RouteService();

  void viewRoute() {
    globals.plowingRequests = plowingRequests;
    Navigator.of(context).pushReplacementNamed(PlowerMapView.routeName);
  }

  String _deleteCabinAreaFailedErrorMessage = "";

  void _doDeleteCabinArea() {
    cabinAreaService.deleteCabinArea(cabinArea).then((value) {
      if (value) {
        Navigator.of(context).pop();
      } else {
        print("ran");
        setState(() {
          _deleteCabinAreaFailedErrorMessage =
              "Kunne ikke fjerne hytte, venligst prøv igjenn senere";
        });
      }
    });
  }

  void _fetchPlowingRequests() {
    plowingRequestService
        .getPlowingRequestByCabinAreaId(cabinArea)
        .then((value) {
      print(value.length);
      if (value != null) {
        setState(() {
          print(plowingRequests.length);
          plowingRequests = value;
        });
      }
    });
  }

  void _showDialog(PlowingRequestDTO plowingRequest) {
    showDialog(
        context: context,
        builder: (BuildContext context) {
          return AlertDialog(
            title: Text("Slett ploge forespursel?"),
            content:
                Text("Velg slett for å fortsette eller avbryt for å avbryte"),
            actions: <Widget>[
              FlatButton(
                child: Text("avbryt"),
                onPressed: () {
                  Navigator.of(context).pop();
                },
              ),
              FlatButton(
                child: Text("bekreft"),
                onPressed: () {
                  _onPlowingRequestPressed(plowingRequest);
                },
              )
            ],
          );
        });
  }

  void _onPlowingRequestPressed(PlowingRequestDTO plowingRequest) {
    plowingRequestService.deletePlowingRequest(plowingRequest).then((value) {
      if (value) {
        Navigator.of(context).pop();
        initState();
      } else {
        setState(() {
          _deletePlowingRequestFailedText =
              "Kunne ikke slette, prøv igjenn senere";
        });
      }
    });
  }

  @override
  void initState() {
    _fetchPlowingRequests();
    super.initState();
  }

  //Widget build
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: Text(cabinArea?.name ?? ""),
        ),
        body: ListView.builder(
            itemCount: plowingRequests.length + 2,
            itemBuilder: (BuildContext context, int index) {
              if (index == 0) {
                return Card(
                  child: Container(
                    width: MediaQuery.of(context).size.width - 10,
                    padding:
                        EdgeInsets.symmetric(horizontal: 20.0, vertical: 10.0),
                    child: Row(
                      children: <Widget>[
                        Icon(
                          Icons.home,
                          size: 50,
                          color: Colors.teal,
                        ),
                        Text(
                          cabinArea.name,
                          style: TextStyle(
                              fontSize: 15, color: Colors.teal, wordSpacing: 3),
                          textAlign: TextAlign.center,
                        ),
                      ],
                    ),
                  ),
                );
              } else if (index == 1) {
                return FloatingActionButton(
                  onPressed: viewRoute,
                  child: Icon(
                    Icons.map,
                    size: 50,
                    color: Colors.white,
                  ),
                );
              }
              index -= 2;

              PlowingRequestDTO plowingRequest =
                  plowingRequests.elementAt(index);
              return ListBody(
                children: <Widget>[
                  PlowingRequestCardComponent(
                    plowingRequest: plowingRequest,
                    onPlowingRequestLongPress: (plowingRequest) =>
                        _showDialog(plowingRequest),
                  ),
                  Text(
                    _deletePlowingRequestFailedText,
                    style: TextStyle(color: Colors.red),
                  )
                ],
              );
            }));
  }
}
