import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:snow_plow/components/CabinAreaCardComponent.dart';
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/CabinAreaDTO.dart';
import 'package:snow_plow/services/CabinAreaService.dart';
import 'package:snow_plow/widgets/main_drawer.dart';

import 'CabinArea.dart';
import 'NewPlowerCabinAreaPage.dart';

class MyCabinAreasScreen extends StatefulWidget {
  static const routeName = "/MyCabinAreasScreen";

  @override
  _MyCabinAreasScreenState createState() => _MyCabinAreasScreenState();
}

class _MyCabinAreasScreenState extends State<MyCabinAreasScreen> {
  List<CabinAreaDTO> cabinAreas = new List();

  CabinAreaService cabinAreaService = new CabinAreaService();

  CabinAreaDTO cabinArea = null;

  void fetchCabinAreas() {
    cabinAreaService.fetchCabinAreasByUserId().then((value) {
      setState(() {
        cabinAreas = value;
      });
    });
  }

  void onCabinAreaPressed(CabinAreaDTO cabinArea) {
    globals.selectedCabinArea = cabinArea;
    Navigator.of(context).pushNamed(CabinAreaPage.routeName);
  }

  void onAddCabinAreaPress() {
    Navigator.of(context).pushNamed(NewPlowerCabinAreaPage.routeName);
  }

  @override
  void initState() {
    cabinArea = null;
    cabinAreas = null;
    globals.selectedCabinArea = null;
    fetchCabinAreas();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    if (cabinAreas == null) {
      return Scaffold(
        drawer: MainDrawer(),
        appBar: AppBar(
          title: Text("Mine hytteområder"),
        ),
        body: Center(
          child: Text(
              "Ingen hytteområder lagt til, trykk på pluss knappen for å legge til"),
        ),
        floatingActionButton: FloatingActionButton(
          onPressed: onAddCabinAreaPress,
          child: Icon(
            Icons.add,
            size: 50,
            color: Colors.white,
          ),
        ),
      );
    } else {
      return Scaffold(
        drawer: MainDrawer(),
        appBar: AppBar(
          title: Text("Mine Hytteområder"),
        ),
        body: new ListView.builder(
            padding: const EdgeInsets.symmetric(vertical: 8, horizontal: 0),
            itemCount: cabinAreas.length,
            itemBuilder: (BuildContext context, int index) {
              CabinAreaDTO cabinArea = cabinAreas.elementAt(index);
              return ListBody(
                children: <Widget>[
                  new CabinAreaCardComponent(
                      cabinArea: cabinArea,
                      onCabinAreaPressed: onCabinAreaPressed)
                ],
              );
            }),
        floatingActionButton: FloatingActionButton(
          onPressed: onAddCabinAreaPress,
          child: Icon(
            Icons.add,
            size: 50,
            color: Colors.white,
          ),
        ),
      );
    }
  }
}
