import 'package:flutter/material.dart';
import 'package:snow_plow/Plower/CabinAreas.dart';
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/CabinAreaDTO.dart';
import 'package:snow_plow/models/PlowerCabinAreaDTO.dart';
import 'package:snow_plow/services/CabinAreaService.dart';
import 'package:snow_plow/services/PlowerCabinAreaService.dart';

class NewPlowerCabinAreaPage extends StatefulWidget {
  static const routeName = "/newCabinArea";

  @override
  _NewCabinAreaPageState createState() => _NewCabinAreaPageState();
}

class _NewCabinAreaPageState extends State<NewPlowerCabinAreaPage> {
  String _createCabinAreaErrorMessage = "";

  CabinAreaService cabinAreaService = new CabinAreaService();
  PlowerCabinAreaService plowerCabinAreaService = new PlowerCabinAreaService();

  List<CabinAreaDTO> cabinAreas;
  List<DropdownMenuItem<CabinAreaDTO>> _dropDownMenuItems;
  CabinAreaDTO _selectedItem;

  void _sendAddPlowerCabinAreaRequest() {
    plowerCabinAreaService
        .createPlowerCabinArea(new PlowerCabinAreaDTO(
            id: 0,
            plower: globals.myUserDTO,
            cabinArea: _selectedItem,
            valid: true,
            dateCreated: DateTime.now()))
        .then((value) {
      if (value) {
        Navigator.of(context).pushNamed(MyCabinAreasScreen.routeName);
      } else {
        setState(() {
          _createCabinAreaErrorMessage = "Kunne ikke legge til hytteområde";
        });
      }
    });
  }

  void _fetchCabinAreas() {
    // TODO hent hytteområde og bruk dei som valg av hytteområde
    cabinAreaService.fetchCabinAreas().then((value) {
      setState(() {
        cabinAreas = value;
        _dropDownMenuItems = buildDropDownMenuItems(value);
        _selectedItem = _dropDownMenuItems[0].value;
      });
    });
  }

  List<DropdownMenuItem<CabinAreaDTO>> buildDropDownMenuItems(List cabinAreas) {
    List<DropdownMenuItem<CabinAreaDTO>> items = List();
    for (CabinAreaDTO cabinArea in cabinAreas) {
      items.add(DropdownMenuItem(
        value: cabinArea,
        child: Text(cabinArea.name),
      ));
    }
    return items;
  }

  void onChangeDropdownItem(CabinAreaDTO cabinArea) {
    setState(() {
      _selectedItem = cabinArea;
    });
  }

  @override
  void initState() {
    _fetchCabinAreas();
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Legg til hytteområde"),
      ),
      body: SingleChildScrollView(
        child: Center(
        child: Column(
          children: <Widget>[
            Container(
              padding: EdgeInsets.fromLTRB(0, 30, 0, 0),
              child: Column(
                children: <Widget>[
                  Text(
                    "Hyttefelt",
                    style: Theme.of(context).accentTextTheme.headline,
                  ),
                  SizedBox(
                    height: 10,
                  ),
                  DropdownButton(
                    value: _selectedItem,
                    items: _dropDownMenuItems,
                    onChanged: onChangeDropdownItem,
                  ),
                  SizedBox(
                    height: 10,
                  ),
                ],
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(0, 10, 0, 0),
              child: RaisedButton(
                child: Text(
                  "Legg til",
                  style: TextStyle(
                    fontSize: 25,
                    color: Colors.white,
                  ),
                ),
                color: Colors.lightGreen,
                onPressed: _sendAddPlowerCabinAreaRequest,
                splashColor: Colors.white,
                padding: EdgeInsets.symmetric(vertical: 12, horizontal: 50),
              ),
            ),
          ],
        ),
      ),
      ),
    );
  }
}
