import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:snow_plow/admin/PlowerRequests.dart';
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/Change.dart';
import 'package:snow_plow/models/PlowerRequestDTO.dart';
import 'package:snow_plow/services/PlowerRequestService.dart';

class PlowerRequestPage extends StatefulWidget {
  static const routeName = "/plowerRequest";

  _PlowerRequestPageState createState() => _PlowerRequestPageState();
}

class _PlowerRequestPageState extends State<PlowerRequestPage> {
  PlowerRequestService plowerRequestService = new PlowerRequestService();

  PlowerRequestDTO plowerRequest = globals.selectedPlowerRequest;

  @override
  void initState() {
    super.initState();
  }

  void _onApprovePlowerRequestPressed() {
    _acceptPlower();
    plowerRequestService.updatePlowerRequest(plowerRequest).then((value) {
      if (value) {
        globals.selectedPlowerRequest = null;
        Navigator.of(context).pushNamed(PlowerRequestsScreen.routeName);
      } else {
        print("failed");
      }
    });
  }

  void _onDeclinePlowerRequestPressed() {
    _declinePlower();
    plowerRequestService.updatePlowerRequest(plowerRequest).then((value) {
      if (value) {
        globals.selectedPlowerRequest = null;
        Navigator.of(context).pushNamed(PlowerRequestsScreen.routeName);
      } else {
        print("failed");
      }
    });
  }

  void _acceptPlower() {
    Change roleChange = new Change(
        id: 0,
        created: DateTime.now(),
        tableName: "user_roles",
        columnName: "new entry",
        rowNumber: 0,
        oldValue: null,
        newValue: "...plower");
    plowerRequest.changes.add(roleChange);
    Change plowerRequestChange = new Change(
        id: 0,
        created: DateTime.now(),
        tableName: "plower_requests",
        columnName: "date_responded",
        rowNumber: plowerRequest.id,
        oldValue: null,
        newValue: DateTime.now().toIso8601String());
    plowerRequest.changes.add(plowerRequestChange);
    plowerRequest.status = true;
    plowerRequest.edited = true;
    plowerRequest.dateResponded = DateTime.now();
  }

  void _declinePlower() {
    Change change = new Change(
        id: 0,
        created: DateTime.now(),
        tableName: "plower_requests",
        columnName: "date_responded",
        rowNumber: plowerRequest.id,
        oldValue: null,
        newValue: DateTime.now().toIso8601String());
    plowerRequest.changes.add(change);
    plowerRequest.status = false;
    plowerRequest.edited = true;
    plowerRequest.dateResponded = DateTime.now();
  }

  //Widget build
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: Text(plowerRequest?.myUser.firstName ?? ""),
        ),
        body: Container(
          child: Card(
            child: Column(
              children: <Widget>[
                Container(
                  width: MediaQuery.of(context).size.width - 10,
                  padding:
                      EdgeInsets.symmetric(horizontal: 20.0, vertical: 10.0),
                  child: Row(
                    children: <Widget>[
                      Icon(
                        Icons.home,
                        size: 50,
                        color: Colors.teal,
                      ),
                      Text(
                        "Dato forespurt: " +
                            (plowerRequest?.dateRequested != null
                                ? DateFormat("dd-MM-yyyy - kk:mm")
                                    .format(plowerRequest.dateRequested)
                                : "No date") +
                            "\n" +
                            "Fornavn: " +
                            (plowerRequest?.myUser.firstName ??
                                "Fornavn ikke funnet") +
                            "\n" +
                            "Etternavn: " +
                            (plowerRequest.myUser.lastName ??
                                "Etternavn ikke funnet") +
                            "\n" +
                            "E-post: " +
                            plowerRequest?.myUser.email,
                        style: TextStyle(
                            fontSize: 15, color: Colors.teal, wordSpacing: 3),
                        textAlign: TextAlign.center,
                      ),
                    ],
                  ),
                ),
                Row(
                  mainAxisAlignment: MainAxisAlignment.spaceAround,
                  children: <Widget>[
                    RaisedButton(
                      child: Text('Avslag'),
                      onPressed: _onDeclinePlowerRequestPressed,
                    ),
                    SizedBox(width: 10.0),
                    RaisedButton(
                      child: Text('Godkjenn'),
                      onPressed: _onApprovePlowerRequestPressed,
                    ),
                  ],
                ),
              ],
            ),
          ),
        ));
  }
}
