import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:snow_plow/components/DateTimeForm.dart';
import 'package:snow_plow/components/PlowingRequestCard.dart';
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/CabinDTO.dart';
import 'package:snow_plow/models/PlowingRequestDTO.dart';
import 'package:snow_plow/screens/MyCabinsScreen.dart';
import 'package:snow_plow/services/CabinService.dart';
import 'package:snow_plow/services/PlowingRequestService.dart';

class CabinPage extends StatefulWidget {
  static const routeName = "/cabin";

  _CabinPageState createState() => _CabinPageState();
}

class _CabinPageState extends State<CabinPage> {
  PlowingRequestService plowingRequestService = new PlowingRequestService();
  CabinService cabinService = new CabinService();
  CabinDTO cabin = globals.selectedCabin;
  List<PlowingRequestDTO> plowingRequests;
  String _deletePlowingRequestFailedText = "";

  String _deleteCabinFailedErrorMessage = "";

  void _doDeleteCabin() {
    cabinService.deleteCabin(cabin).then((value) {
      if (value) {
        Navigator.of(context).pushNamed(MyCabinsScreen.routeName);
      } else {
        print("ran");
        setState(() {
          _deleteCabinFailedErrorMessage =
              "Kunne ikke fjerne hytte, venligst prøv igjenn senere";
        });
      }
    });
  }

  void _fetchPlowingRequests() {
    plowingRequestService.getPlowingRequestByCabinId(cabin).then((value) {
      if (value != null) {
        setState(() {
          plowingRequests = value;
        });
      }
    });
  }

  void _showDialog(PlowingRequestDTO plowingRequest) {
    showDialog(
        context: context,
        builder: (BuildContext context) {
          return AlertDialog(
            title: Text("Slett ploge forespursel?"),
            content:
                Text("Velg slett for å fortsette eller avbryt for å avbryte"),
            actions: <Widget>[
              FlatButton(
                child: Text("avbryt"),
                onPressed: () {
                  Navigator.of(context).pop();
                },
              ),
              FlatButton(
                child: Text("bekreft"),
                onPressed: () {
                  _onPlowingRequestPressed(plowingRequest);
                },
              )
            ],
          );
        });
  }

  void _onPlowingRequestPressed(PlowingRequestDTO plowingRequest) {
    plowingRequestService.deletePlowingRequest(plowingRequest).then((value) {
      if (value) {
        Navigator.push(context,
            new MaterialPageRoute(builder: (context) => new MyCabinsScreen()));
      } else {
        setState(() {
          _deletePlowingRequestFailedText =
              "Kunne ikke slette, prøv igjenn senere";
        });
      }
    });
  }

  @override
  void initState() {
    _fetchPlowingRequests();
    super.initState();
  }

  //Widget build
  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(
          title: Text(cabin?.cabinName ?? ""),
        ),
        body: ListView.builder(
            itemCount: plowingRequests != null ? plowingRequests.length + 2 : 2,
            itemBuilder: (BuildContext context, int index) {
              if (index == 0) {
                return Card(
                  child: Container(
                    width: MediaQuery.of(context).size.width - 10,
                    padding:
                        EdgeInsets.symmetric(horizontal: 5.0, vertical: 10.0),
                    child: Row(
                      children: <Widget>[
                        Icon(
                          Icons.home,
                          size: 50,
                          color: Colors.teal,
                        ),
                        Text(
                          "Land: " +
                              (cabin?.country ?? "Ukjent land") +
                              "\n" +
                              "Kommune: " +
                              (cabin?.municipality ?? "Kommune ikke funnet") +
                              "\n" +
                              "Adresse: " +
                              (cabin?.streetAdress ?? "Adresse ikke funnet") +
                              "\n" +
                              "Hytteområde: " +
                              cabin?.cabinArea?.name,
                          style: TextStyle(
                              fontSize: 15, color: Colors.teal, wordSpacing: 3),
                          textAlign: TextAlign.center,
                        ),
                        SizedBox(
                          width: 5,
                        ),
                        RaisedButton(
                          child: Text(
                            "Slett hytte",
                            style: TextStyle(color: Colors.white),
                          ),
                          color: Colors.red,
                          splashColor: Colors.red,
                          onPressed: _doDeleteCabin,
                        ),
                      ],
                    ),
                  ),
                );
              } else if (index == 1) {
                return Card(
                  child: Container(
                    width: MediaQuery.of(context).size.width - 10,
                    height: 250,
                    padding:
                        EdgeInsets.symmetric(horizontal: 20.0, vertical: 10.0),
                    child: Column(
                      children: <Widget>[
                        Text("Legg til hytte opphold"),
                        Container(
                          width: MediaQuery.of(context).size.width - 50,
                          height: 210,
                          child: DateTimeForm(
                            updateParent: _fetchPlowingRequests,
                          ),
                        ),
                      ],
                    ),
                  ),
                );
              }
              index -= 2;
              PlowingRequestDTO plowingRequest =
                  plowingRequests.elementAt(index);
              return ListBody(
                children: <Widget>[
                  PlowingRequestCardComponent(
                    plowingRequest: plowingRequest,
                    onPlowingRequestLongPress: (plowingRequest) =>
                        _showDialog(plowingRequest),
                  ),
                  Text(
                    _deletePlowingRequestFailedText,
                    style: TextStyle(color: Colors.red),
                  )
                ],
              );
            }));
  }
}
