import 'package:flutter/material.dart';
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/input/input_form.dart';
import 'package:snow_plow/models/CabinAreaDTO.dart';
import 'package:snow_plow/models/CabinDTO.dart';
import 'package:snow_plow/screens/MyCabinsScreen.dart';
import 'package:snow_plow/services/CabinAreaService.dart';
import 'package:snow_plow/services/CabinService.dart';
import 'package:snow_plow/utility/form_validation.dart';

class NewCabinPage extends StatefulWidget {
  static const routeName = "/newCabin";

  @override
  _NewCabinPageState createState() => _NewCabinPageState();
}

class _NewCabinPageState extends State<NewCabinPage> {
  TextEditingController _cabinNameController = new TextEditingController();
  String _cabinNameErrorMessage = "";
  TextEditingController _cabinAreaController = new TextEditingController();
  String _cabinAreaErrorMessage = "";
  TextEditingController _gardsnrController = new TextEditingController();
  String _gardsnrErrorMessage = "";
  TextEditingController _bruksnrController = new TextEditingController();
  String _bruksnrErrorMessage = "";
  TextEditingController _festenrController = new TextEditingController();
  String _festenrErrorMessage = "";
  TextEditingController _seksjonsnrController = new TextEditingController();
  String _seksjonsnrErrorMessage = "";
  TextEditingController _kommunenrController = new TextEditingController();
  String _kommunenrErrorMessage = "";

  String _createCabinErrorMessage = "";

  RegExp nonNumber = new RegExp("[^0-9]");

  CabinAreaService cabinAreaService = new CabinAreaService();
  CabinService cabinService = new CabinService();

  List<CabinAreaDTO> cabinAreas;
  List<DropdownMenuItem<CabinAreaDTO>> _dropDownMenuItems;
  CabinAreaDTO _selectedItem;

  void _doAddCabin() {
    if (_validInput()) {
      _sendAddCabinRequest();
    }
  }

  void _sendAddCabinRequest() {
    cabinService
        .createCabin(
      new CabinDTO(
          cabinName: _cabinNameController.text.trim(),
          kid: int.parse(_kommunenrController.text),
          bid: int.parse(_bruksnrController.text),
          gid: int.parse(_gardsnrController.text),
          cabinArea: _selectedItem,
          id: 0,
          myUser: globals.myUserDTO,
          created: DateTime.now(),
          country: "Norge"),
    )
        .then((value) {
      if (value) {
        Navigator.of(context).pushNamed(MyCabinsScreen.routeName);
      } else {
        setState(() {
          _createCabinErrorMessage = "Kunne ikke legge til hytte";
        });
      }
    });
  }

  void _fetchCabinAreas() {
    // TODO hent hytteområde og bruk dei som valg av hytteområde
    cabinAreaService.fetchCabinAreas().then((value) {
      setState(() {
        cabinAreas = value;
        _dropDownMenuItems = buildDropDownMenuItems(value);
        _selectedItem = _dropDownMenuItems[0].value;
      });
    });
  }

  List<DropdownMenuItem<CabinAreaDTO>> buildDropDownMenuItems(List cabinAreas) {
    List<DropdownMenuItem<CabinAreaDTO>> items = List();
    for (CabinAreaDTO cabinArea in cabinAreas) {
      items.add(DropdownMenuItem(
        value: cabinArea,
        child: Text(cabinArea.name),
      ));
    }
    return items;
  }

  void onChangeDropdownItem(CabinAreaDTO cabinArea) {
    setState(() {
      _selectedItem = cabinArea;
    });
  }

  String _mapErrorMessage(InputFieldResult result, String missingMessage,
      [String notANumberMeesage]) {
    String message = "";
    switch (result) {
      case InputFieldResult.VALID:
        break;
      case InputFieldResult.MISSING:
        message = missingMessage;
        break;
      case InputFieldResult.NOT_A_NUMBER:
        message = notANumberMeesage;
        break;
    }
    return message;
  }

  @override
  void initState() {
    _fetchCabinAreas();
    super.initState();
  }

  bool _validInput() {
    //Do checks on all fields induvidually
    InputFieldResult cabinNameResult =
        validateIfNotEmpty(_cabinNameController.text);
    setState(() {
      _cabinNameErrorMessage =
          _mapErrorMessage(cabinNameResult, "Hyttenavn mangler");
    });

    InputFieldResult cabinFieldResult =
        validateIfNotEmpty(_cabinAreaController.text);
    setState(() {
      _cabinAreaErrorMessage =
          _mapErrorMessage(cabinFieldResult, "Hyttefelt mangler");
    });

    InputFieldResult gardsnrResult =
        validateNumericalInput(_gardsnrController.text);
    setState(() {
      _gardsnrErrorMessage = _mapErrorMessage(
          gardsnrResult, "Gårdsnummer mangler", "Ugyldig gårdsnummer");
    });

    InputFieldResult bruksnrResult =
        validateNumericalInput(_bruksnrController.text);
    setState(() {
      _bruksnrErrorMessage = _mapErrorMessage(
          bruksnrResult, "Bruksnummer mangler", "Ugyldig bruksnummer");
    });

    InputFieldResult festenrResult =
        validateNumericalInput(_festenrController.text);
    setState(() {
      _festenrErrorMessage = _mapErrorMessage(
          festenrResult, "Festenummer mangler", "Ugyldig festenummer");
    });

    InputFieldResult seksjonsnrResult =
        validateNumericalInput(_seksjonsnrController.text);
    setState(() {
      _seksjonsnrErrorMessage = _mapErrorMessage(
          seksjonsnrResult, "Seksjonsnummer mangler", "Ugyldig seksjonsnummer");
    });

    InputFieldResult kommunenrResult =
        validateNumericalInput(_kommunenrController.text);
    setState(() {
      _kommunenrErrorMessage = _mapErrorMessage(
          kommunenrResult, "Kommunenr mangler", "Ugyldig kommunenr");
    });

    return (cabinNameResult == InputFieldResult.VALID &&
        gardsnrResult == InputFieldResult.VALID &&
        bruksnrResult == InputFieldResult.VALID &&
        kommunenrResult == InputFieldResult.VALID);
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Ny Hytte"),
      ),
      body: SingleChildScrollView(
        child: Column(
          children: <Widget>[
            Text(
              _createCabinErrorMessage,
              style: Theme.of(context)
                  .textTheme
                  .subtitle
                  .copyWith(color: Theme.of(context).errorColor),
            ),
            InputForm(
              textInputType: TextInputType.text,
              inputController: _cabinNameController,
              label: "Hyttenavn",
            ),
            Text(
              _cabinNameErrorMessage,
              style: Theme.of(context)
                  .textTheme
                  .subtitle
                  .copyWith(color: Theme.of(context).errorColor),
            ),
            InputForm(
              textInputType: TextInputType.number,
              inputController: _kommunenrController,
              label: "Kommunenummer",
            ),
            Text(
              _kommunenrErrorMessage,
              style: Theme.of(context)
                  .textTheme
                  .subtitle
                  .copyWith(color: Theme.of(context).errorColor),
            ),
            InputForm(
              textInputType: TextInputType.number,
              inputController: _gardsnrController,
              label: "Gardsnummer",
            ),
            Text(
              _bruksnrErrorMessage,
              style: Theme.of(context)
                  .textTheme
                  .subtitle
                  .copyWith(color: Theme.of(context).errorColor),
            ),
            InputForm(
              textInputType: TextInputType.number,
              inputController: _bruksnrController,
              label: "Bruksnummer",
            ),
            Text(
              _bruksnrErrorMessage,
              style: Theme.of(context)
                  .textTheme
                  .subtitle
                  .copyWith(color: Theme.of(context).errorColor),
            ),
            Container(
              child: Column(
                children: <Widget>[
                  Text(
                    "Hyttefelt",
                    textAlign: TextAlign.left,
                  ),
                  SizedBox(
                    height: 10,
                  ),
                  DropdownButton(
                    value: _selectedItem,
                    items: _dropDownMenuItems,
                    onChanged: onChangeDropdownItem,
                  ),
                  SizedBox(
                    height: 10,
                  ),
                ],
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(0, 0, 0, 15),
              child: RaisedButton(
                child: Text(
                  "Send",
                  style: TextStyle(
                    fontSize: 25,
                    color: Colors.white,
                  ),
                ),
                color: Colors.lightGreen,
                onPressed: _doAddCabin,
                splashColor: Colors.white,
                padding: EdgeInsets.symmetric(vertical: 12, horizontal: 50),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
