import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:snow_plow/models/CabinDTO.dart';
import 'package:snow_plow/screens/MyCabinsScreen.dart';
import 'package:snow_plow/services/CabinService.dart';

class CabinComponent extends StatefulWidget {
  final CabinDTO cabin;

  CabinComponent({this.cabin});

  _CabinComponentState createState() => _CabinComponentState(cabin: cabin);
}

class _CabinComponentState extends State<CabinComponent> {
  final CabinDTO cabin;

  _CabinComponentState({this.cabin});

  @override
  Widget build(BuildContext context) {
    CabinService cabinService = new CabinService();

    String _deleteCabinFailedErrorMessage = "";

    void _doDeleteCabin() {
      cabinService.deleteCabin(cabin).then((value) {
        if (value) {
          Navigator.of(context).pushNamed(MyCabinsScreen.routeName);
        } else {
          print("ran");
          setState(() {
            _deleteCabinFailedErrorMessage =
                "Kunne ikke fjerne hytte, venligst prøv igjenn senere";
          });
        }
      });
    }

    return Card(
      child: SingleChildScrollView(
        child: Container(
          padding: EdgeInsets.symmetric(vertical: 50, horizontal: 50),
          child: Column(
            children: <Widget>[
              Text(
                cabin?.cabinName,
                style: TextStyle(
                  fontSize: 30,
                  color: Colors.teal,
                ),
                textAlign: TextAlign.center,
              ),
              Icon(
                Icons.home,
                size: 150,
                color: Colors.teal,
              ),
              Text(
                "Land: " +
                    (cabin?.country ?? "") +
                    "\n\n" +
                    "Kommune: " +
                    (cabin?.municipality ?? "") +
                    "\n\n" +
                    "Adresse: " +
                    (cabin?.streetAdress ?? "") +
                    "\n\n",
                style:
                    TextStyle(fontSize: 20, color: Colors.teal, wordSpacing: 3),
                textAlign: TextAlign.center,
              ),
              Text(
                "Hytteområde: " + cabin?.cabinArea?.name,
                style:
                    TextStyle(fontSize: 25, color: Colors.teal, wordSpacing: 3),
                textAlign: TextAlign.center,
              ),
              Container(
                padding: EdgeInsets.fromLTRB(0, 10, 0, 10),
                child: RaisedButton(
                  child: Text(
                    "Delete",
                    style: TextStyle(
                      fontSize: 25,
                      color: Colors.white,
                    ),
                  ),
                  onPressed: _doDeleteCabin,
                  color: Colors.red,
                  splashColor: Colors.white,
                  padding: EdgeInsets.symmetric(vertical: 20, horizontal: 30),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(0, 5, 0, 0),
                child: Text(
                  _deleteCabinFailedErrorMessage,
                  style: Theme.of(context)
                      .textTheme
                      .subtitle
                      .copyWith(color: Theme.of(context).errorColor),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
