import 'package:datetime_picker_formfield/datetime_picker_formfield.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:intl/intl.dart';
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/PlowingRequestDTO.dart';
import 'package:snow_plow/services/PlowingRequestService.dart';

class DateTimeForm extends StatefulWidget {
  Function() updateParent;

  DateTimeForm({this.updateParent});

  @override
  _DateTimeFormState createState() =>
      _DateTimeFormState(updateParent: updateParent);
}

class _DateTimeFormState extends State<DateTimeForm> {
  PlowingRequestService plowingRequestService = new PlowingRequestService();
  final format = DateFormat("yyyy-MM-dd HH:mm");
  TextEditingController _startDateController = new TextEditingController();
  DateTime startDate = null;
  TextEditingController _endDateController = new TextEditingController();
  DateTime endDate = null;

  Function() updateParent;

  _DateTimeFormState({this.updateParent});

  void _addPlowingRequest() {
    plowingRequestService
        .createPlowingRequest(new PlowingRequestDTO(
            id: 0,
            cabin: globals.selectedCabin,
            cabinArea: globals.selectedCabin.cabinArea,
            dateRequested: DateTime.now(),
            dateOfArrival: startDate,
            dateOfDeparture: endDate))
        .then((value) {
      if (value) {
        updateParent();
      } else {
        print("Error: couldnt save plowingrequest");
      }
    });
  }

  String getTextInput() {}

  @override
  Widget build(BuildContext context) {
    return Form(
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          SizedBox(height: 10.0),
          Text("Fremkomst"),
          DateTimeField(
            format: format,
            onShowPicker: (context, currentValue) async {
              final date = await showDatePicker(
                  context: context,
                  firstDate: DateTime(1900),
                  initialDate: currentValue ?? DateTime.now(),
                  lastDate: DateTime(2100));
              if (date != null) {
                final time = await showTimePicker(
                  context: context,
                  initialTime:
                      TimeOfDay.fromDateTime(currentValue ?? DateTime.now()),
                );
                return DateTimeField.combine(date, time);
              } else {
                return currentValue;
              }
            },
            onChanged: (value) {
              startDate = value;
            },
            controller: _startDateController,
          ),
          SizedBox(height: 10.0),
          Text("Avgang"),
          DateTimeField(
            format: format,
            onShowPicker: (context, currentValue) async {
              final date = await showDatePicker(
                  context: context,
                  firstDate: DateTime(1900),
                  initialDate: currentValue ?? DateTime.now(),
                  lastDate: DateTime(2100));
              if (date != null) {
                final time = await showTimePicker(
                  context: context,
                  initialTime:
                      TimeOfDay.fromDateTime(currentValue ?? DateTime.now()),
                );
                return DateTimeField.combine(date, time);
              } else {
                return currentValue;
              }
            },
            onChanged: (value) {
              endDate = value;
            },
            controller: _endDateController,
          ),
          SizedBox(height: 10.0),
          Row(
            mainAxisAlignment: MainAxisAlignment.spaceAround,
            children: <Widget>[
              RaisedButton(
                child: Text('RESET'),
                onPressed: () => print("reset"),
              ),
              SizedBox(width: 10.0),
              RaisedButton(
                child: Text('SAVE'),
                onPressed: _addPlowingRequest,
              ),
            ],
          ),
        ],
      ),
    );
  }
}

class BasicDateTimeField extends StatelessWidget {
  final format = DateFormat("yyyy-MM-dd HH:mm");
  TextEditingController _inputController = new TextEditingController();

  @override
  Widget build(BuildContext context) {
    return Column(children: <Widget>[
      Text("Manglende header tekst"),
      DateTimeField(
        format: format,
        onShowPicker: (context, currentValue) async {
          final date = await showDatePicker(
              context: context,
              firstDate: DateTime(1900),
              initialDate: currentValue ?? DateTime.now(),
              lastDate: DateTime(2100));
          if (date != null) {
            final time = await showTimePicker(
              context: context,
              initialTime:
                  TimeOfDay.fromDateTime(currentValue ?? DateTime.now()),
            );
            return DateTimeField.combine(date, time);
          } else {
            return currentValue;
          }
        },
        controller: _inputController,
      ),
    ]);
  }
}
