import 'package:flutter/material.dart';
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/login/login_confirmation.dart';
import 'package:snow_plow/login/registration.dart';
import 'package:snow_plow/profile/profile.dart';
import 'package:snow_plow/services/AuthenticationService.dart';
import 'package:snow_plow/services/MyUserService.dart';
import 'package:snow_plow/utility/debug_utility.dart';
import 'package:snow_plow/utility/form_validation.dart';

class LoginPage extends StatefulWidget {
  static const routeName = "/login";

  LoginPage({Key key}) : super(key: key);

  @override
  _LoginPageState createState() => _LoginPageState();
}

class _LoginPageState extends State<LoginPage> {
  MyUserService myUserService = new MyUserService();

  @override
  void initState() {
    super.initState();
    checkIfAlreadyLoggedIn();
  }

  TextEditingController _emailController = new TextEditingController();

  final AuthenticationService authenticationService =
      new AuthenticationService();

  String _inputErrorMessage = "";

  void _doLogin() {
    if (_validEmail()) {
      _sendLoginRequest();
      Navigator.of(context).pushNamed(LoginConfirmationPage.routeName);
    }
  }

  void checkIfAlreadyLoggedIn() {
    myUserService.validateToken().then((value) {
      if (value) {
        Navigator.of(context).pushNamed(ProfilePage.routeName);
      } else {
        print("Not logged in");
      }
    });
  }

  void _sendtOtp() {
    _sendLoginRequest();
  }

  bool _validEmail() {
    EmailValidationResult result = validateEmail(_emailController.text);

    switch (result) {
      case EmailValidationResult.VALID:
        {
          setState(() {
            _inputErrorMessage = "";
          });
          debugPrintMessage("Login with " + _emailController.text);
        }
        break;
      case EmailValidationResult.INVALID:
        {
          setState(() {
            _inputErrorMessage = "Ugyldig epost";
          });
          debugPrintError("Invalid email");
        }
        break;
      case EmailValidationResult.MISSING:
        {
          setState(() {
            _inputErrorMessage = "Epost mangler";
          });
          debugPrintError("Missing email");
        }
        break;
    }

    return (EmailValidationResult.VALID == result);
  }

  void _sendLoginRequest() {
    globals.email = _emailController.text.toLowerCase().trim();
    authenticationService
        .getOtp(_emailController.text.trim().toLowerCase())
        .then((value) {
      if (value) {
        Navigator.of(context).pushNamed(LoginConfirmationPage.routeName);
      } else {
        setState(() {
          _inputErrorMessage = "Bruker ikke funnet, prøv på nytt.";
        });
      }
    });
    globals.email = _emailController.text;
  }

  void _doRegistration() {
    Navigator.of(context).pushNamed(RegistrationPage.routeName);
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        //remove keyboard when tapping outside of the keyboard
        FocusScopeNode focused = FocusScope.of(context);

        if (!focused.hasPrimaryFocus) {
          focused.unfocus();
        }
      },
      child: Scaffold(
        appBar: AppBar(
          title: Text("Log inn"),
        ),
        body: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Text(
                "Log inn med din epost:",
                style: Theme.of(context).textTheme.headline,
              ),
              Container(
                padding: EdgeInsets.fromLTRB(30, 5, 30, 0),
                child: TextField(
                  controller: _emailController,
                  keyboardType: TextInputType.emailAddress,
                  textAlign: TextAlign.center,
                  decoration: new InputDecoration(
                    hintText: "Skriv inn epost",
                    contentPadding: EdgeInsets.all(5.0),
                  ),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(0, 5, 0, 0),
                child: Text(
                  _inputErrorMessage,
                  style: Theme.of(context)
                      .textTheme
                      .subtitle
                      .copyWith(color: Theme.of(context).errorColor),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(0, 5, 0, 60),
                child: RaisedButton(
                  child: Text(
                    "Send innlogging",
                    style: TextStyle(
                      fontSize: 25,
                      color: Colors.white,
                    ),
                  ),
                  onPressed: _doLogin,
                  color: Theme.of(context).primaryColor,
                  splashColor: Colors.white,
                  padding: EdgeInsets.symmetric(vertical: 25, horizontal: 30),
                ),
              ),
              Text(
                "Eller registrer deg:",
                style: Theme.of(context).textTheme.subtitle,
              ),
              Container(
                padding: EdgeInsets.fromLTRB(0, 0, 0, 0),
                child: RaisedButton(
                  child: Text(
                    "Registrer ny bruker",
                    style: TextStyle(
                      fontSize: 15,
                      color: Colors.white,
                    ),
                  ),
                  onPressed: _doRegistration,
                  color: Theme.of(context).accentColor,
                  splashColor: Colors.white,
                  padding: EdgeInsets.symmetric(vertical: 12, horizontal: 30),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
