import 'package:flutter/material.dart';
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/profile/profile.dart';
import 'package:snow_plow/services/AuthenticationService.dart';
import 'package:snow_plow/utility/debug_utility.dart';
import 'package:snow_plow/utility/form_validation.dart';

class LoginConfirmationPage extends StatefulWidget {
  static const routeName = "/loginConfirmation";

  @override
  _LoginConfirmationState createState() => _LoginConfirmationState();
}

class _LoginConfirmationState extends State<LoginConfirmationPage> {
  TextEditingController _confirmationController = new TextEditingController();
  String _confirmationCode = "";
  String _confirmationErrorMessage = "";
  AuthenticationService authenticationService = new AuthenticationService();

  void _doLoginConfirmation() {
    if (_validCodeFormat()) {
      authenticationService
          .authenticate(globals.email, _confirmationController.text.trim())
          .then((value) {
        if (value) {
          Navigator.of(context).pushReplacementNamed(ProfilePage.routeName);
        } else {
          setState(() {
            _confirmationErrorMessage = "Engangskoden er feil eller utløpt";
          });
        }
      });
    }
  }

  bool _validCodeFormat() {
    setState(() {
      _confirmationCode = _confirmationController.text;
    });
    bool valid = false;
    ConfirmationCodeResult result = validateConfirmationCode(_confirmationCode);

    switch (result) {
      case ConfirmationCodeResult.VALID:
        {
          setState(() {
            _confirmationErrorMessage = "";
          });
          debugPrintMessage("Confirmation " + _confirmationCode);
          valid = true;
        }
        break;

      case ConfirmationCodeResult.INVALID:
        {
          setState(() {
            _confirmationErrorMessage = "Engangskoden er ugyldig";
          });
          debugPrintError("One time code is invalid");
        }
        break;

      case ConfirmationCodeResult.TOO_SHORT:
        {
          setState(() {
            _confirmationErrorMessage = "Engangskoden er for kort";
          });
          debugPrintError("One time code too short");
        }
        break;

      case ConfirmationCodeResult.TOO_LONG:
        {
          setState(() {
            _confirmationErrorMessage = "Engangskoden er for lang";
          });
          debugPrintError("One time code too long");
        }
        break;
    }
    return valid;
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        //remove keyboard when tapping outside of the keyboard
        FocusScopeNode focused = FocusScope.of(context);

        if (!focused.hasPrimaryFocus) {
          focused.unfocus();
        }
      },
      child: Scaffold(
        appBar: AppBar(
          title: Text("Bekreft innlogging"),
        ),
        body: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Text(
                "Bekreft innlogging med engangskode:",
                style: Theme.of(context).textTheme.headline,
              ),
              Container(
                padding: EdgeInsets.fromLTRB(30, 5, 30, 0),
                child: TextField(
                  controller: _confirmationController,
                  keyboardType: TextInputType.number,
                  textAlign: TextAlign.center,
                  decoration: new InputDecoration(
                    hintText: "Skriv inn engangskode",
                    contentPadding: EdgeInsets.all(5.0),
                  ),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(0, 5, 0, 0),
                child: Text(
                  _confirmationErrorMessage,
                  style: Theme.of(context)
                      .textTheme
                      .subtitle
                      .copyWith(color: Theme.of(context).errorColor),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(0, 20, 0, 5),
                child: RaisedButton(
                  child: Text(
                    "Bekreft innlogging",
                    style: TextStyle(
                      fontSize: 25,
                      color: Colors.white,
                    ),
                  ),
                  onPressed: _doLoginConfirmation,
                  color: Theme.of(context).primaryColor,
                  splashColor: Colors.white,
                  padding: EdgeInsets.symmetric(vertical: 25, horizontal: 30),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
