import 'package:flutter/material.dart';
import 'package:snow_plow/models/MyUserDTO.dart';
import 'package:snow_plow/services/MyUserService.dart';
import 'package:snow_plow/utility/debug_utility.dart';
import 'package:snow_plow/utility/form_validation.dart';

class RegistrationPage extends StatefulWidget {
  static const routeName = "/registration";

  RegistrationPage({Key key}) : super(key: key);

  @override
  _RegistrationPageState createState() => _RegistrationPageState();
}

class _RegistrationPageState extends State<RegistrationPage> {
  TextEditingController _phoneNumberController = new TextEditingController();
  String _phoneNumber;
  String _phoneInputErrorMessage = "";

  TextEditingController _emailController = new TextEditingController();
  String _email = "";
  String _emailInputErrorMessage = "";

  TextEditingController _firstNameController = new TextEditingController();
  String _firstName = "";
  String _firstNameInputErrorMessage = "";

  TextEditingController _lastNameController = new TextEditingController();
  String _lastName = "";
  String _lastNameInputErrogMessage = "";

  String _createUserFailedErrorMessage = "";

  MyUserService myUserService = new MyUserService();

  void _doRegister() {
    bool validPhone = _validPhoneNumber();
    bool validEmail = _validEmail();
    bool validFirstName = _validFirstname();
    bool validLastName = _validLastName();
    //The above calls checks both fields iregardless, instead of one by one
    if (validPhone && validEmail && validFirstName && validLastName) {
      _sendRegistrationRequest();
    }
  }

  bool _validFirstname() {
    setState(() {
      _firstName = _firstNameController.text;
    });
    bool valid = false;
    InputFieldResult result = validateIfNotEmpty(_firstName);

    switch (result) {
      case InputFieldResult.VALID:
        {
          setState(() {
            _firstNameInputErrorMessage = "";
          });
          debugPrintMessage("Register with firstName " + _firstName);
          valid = true;
        }
        break;

      case InputFieldResult.MISSING:
        {
          setState(() {
            _firstNameInputErrorMessage = "Ugyldig fornavn";
          });
          debugPrintError("Invalid firstName input");
        }
        break;

      case InputFieldResult.NOT_A_NUMBER:
        {
          debugPrintError("Shouldn't happen");
        }
        break;
    }

    return valid;
  }

  bool _validLastName() {
    setState(() {
      _lastName = _lastNameController.text;
    });
    bool valid = false;
    InputFieldResult result = validateIfNotEmpty(_lastName);

    switch (result) {
      case InputFieldResult.VALID:
        {
          setState(() {
            _lastNameInputErrogMessage = "";
          });
          debugPrintMessage("Register with lastName " + _lastName);
          valid = true;
        }
        break;

      case InputFieldResult.MISSING:
        {
          setState(() {
            _lastNameInputErrogMessage = "Ugyldig etternavn";
          });
          debugPrintError("Invalid lastName input");
        }
        break;

      case InputFieldResult.NOT_A_NUMBER:
        {
          debugPrintError("Shouldn't happen");
        }
        break;
    }

    return valid;
  }

  bool _validPhoneNumber() {
    setState(() {
      _phoneNumber = _phoneNumberController.text;
    });
    bool valid = false;
    PhoneValidationResult result = validatePhoneNumber(_phoneNumber);

    switch (result) {
      case PhoneValidationResult.VALID:
        {
          setState(() {
            _phoneInputErrorMessage = "";
          });
          debugPrintMessage("Register with number " + _phoneNumber);
          valid = true;
        }
        break;

      case PhoneValidationResult.INVALID:
        {
          setState(() {
            _phoneInputErrorMessage = "Ugyldig telefonnummer";
          });
          debugPrintError("Invalid number input");
        }
        break;

      case PhoneValidationResult.TOO_SHORT:
        {
          setState(() {
            _phoneInputErrorMessage = "Telefonnummeret er for kort";
          });
          debugPrintError("Number too short");
        }
        break;

      case PhoneValidationResult.TOO_LONG:
        {
          setState(() {
            _phoneInputErrorMessage = "Telefonnummeret er for langt";
          });
          debugPrintError("Number too long");
        }
        break;
    }

    return valid;
  }

  bool _validEmail() {
    setState(() {
      _email = _emailController.text;
    });
    bool valid = false;
    EmailValidationResult result = validateEmail(_email);

    switch (result) {
      case EmailValidationResult.VALID:
        {
          setState(() {
            _emailInputErrorMessage = "";
          });
          debugPrintMessage("Register with email " + _email);
          valid = true;
        }
        break;

      case EmailValidationResult.INVALID:
        {
          setState(() {
            _emailInputErrorMessage = "E-post mangler";
          });
          debugPrintError("Email is missing");
        }
        break;

      case EmailValidationResult.MISSING:
        {
          setState(() {
            _emailInputErrorMessage = "Ugyldig e-post";
          });
          debugPrintError("Invalid email");
        }
        break;
    }
    validateEmail(_email);
    return valid;
  }

  void _sendRegistrationRequest() {
    //TODO
    //Implement API call with registration once backend server is running
    myUserService
        .createMyUser(new MyUserDTO(
            id: 0,
            email: _emailController.text.toLowerCase().trim(),
            phoneNumber: _phoneNumberController.text.toLowerCase().trim(),
            firstName: _firstNameController.text.trim(),
            lastName: _lastNameController.text.trim(),
            dateTimeCreated: DateTime.now()))
        .then((value) {
      if (value) {
        Navigator.of(context).pop();
      } else {
        setState(() {
          _createUserFailedErrorMessage =
              "Kunne ikke lage bruker, prøv igjenn.";
        });
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    return GestureDetector(
      onTap: () {
        //remove keyboard when tapping outside of the keyboard
        FocusScopeNode focused = FocusScope.of(context);

        if (!focused.hasPrimaryFocus) {
          focused.unfocus();
        }
      },
      child: Scaffold(
        appBar: AppBar(
          title: Text("Registrering"),
        ),
        body: SingleChildScrollView(
          padding: EdgeInsets.fromLTRB(0, 30, 0, 0),
          child: Center(
            child: Column(
              mainAxisAlignment: MainAxisAlignment.center,
              children: <Widget>[
                Text(
                  "Brukerregistrering",
                  style: Theme.of(context).textTheme.headline,
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(0, 30, 0, 0),
                  child: Text(
                    "Telefonnummer",
                    style: Theme.of(context).textTheme.subtitle,
                  ),
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(50, 0, 50, 0),
                  child: TextField(
                    controller: _phoneNumberController,
                    keyboardType: TextInputType.number,
                    textAlign: TextAlign.center,
                    decoration: new InputDecoration(
                      hintText: "Skriv inn telefonnummer",
                      contentPadding: EdgeInsets.all(5.0),
                    ),
                  ),
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(0, 5, 0, 0),
                  child: Text(
                    _phoneInputErrorMessage,
                    style: Theme.of(context)
                        .textTheme
                        .subtitle
                        .copyWith(color: Theme.of(context).errorColor),
                  ),
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(0, 30, 0, 0),
                  child: Text(
                    "E-postadresse",
                    style: Theme.of(context).textTheme.subtitle,
                  ),
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(50, 0, 50, 0),
                  child: TextField(
                    controller: _emailController,
                    textAlign: TextAlign.center,
                    decoration: new InputDecoration(
                      hintText: "Skriv inn e-postadresse ",
                      contentPadding: EdgeInsets.all(5.0),
                    ),
                  ),
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(0, 5, 0, 0),
                  child: Text(
                    _emailInputErrorMessage,
                    style: Theme.of(context)
                        .textTheme
                        .subtitle
                        .copyWith(color: Theme.of(context).errorColor),
                  ),
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(0, 30, 0, 0),
                  child: Text(
                    "Fornavn",
                    style: Theme.of(context).textTheme.subtitle,
                  ),
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(50, 0, 50, 0),
                  child: TextField(
                    controller: _firstNameController,
                    textAlign: TextAlign.center,
                    decoration: new InputDecoration(
                      hintText: "Skriv inn fornavn ",
                      contentPadding: EdgeInsets.all(5.0),
                    ),
                  ),
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(0, 5, 0, 0),
                  child: Text(
                    _firstNameInputErrorMessage,
                    style: Theme.of(context)
                        .textTheme
                        .subtitle
                        .copyWith(color: Theme.of(context).errorColor),
                  ),
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(0, 30, 0, 0),
                  child: Text(
                    "Etternavn",
                    style: Theme.of(context).textTheme.subtitle,
                  ),
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(50, 0, 50, 0),
                  child: TextField(
                    controller: _lastNameController,
                    textAlign: TextAlign.center,
                    decoration: new InputDecoration(
                      hintText: "Skriv inn etternavn ",
                      contentPadding: EdgeInsets.all(5.0),
                    ),
                  ),
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(0, 5, 0, 0),
                  child: Text(
                    _lastNameInputErrogMessage,
                    style: Theme.of(context)
                        .textTheme
                        .subtitle
                        .copyWith(color: Theme.of(context).errorColor),
                  ),
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(0, 10, 0, 10),
                  child: RaisedButton(
                    child: Text(
                      "Registrer",
                      style: TextStyle(
                        fontSize: 25,
                        color: Colors.white,
                      ),
                    ),
                    onPressed: _doRegister,
                    color: Theme.of(context).primaryColor,
                    splashColor: Colors.white,
                    padding: EdgeInsets.symmetric(vertical: 20, horizontal: 30),
                  ),
                ),
                Container(
                  padding: EdgeInsets.fromLTRB(0, 5, 0, 0),
                  child: Text(
                    _createUserFailedErrorMessage,
                    style: Theme.of(context)
                        .textTheme
                        .subtitle
                        .copyWith(color: Theme.of(context).errorColor),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
