import 'package:flutter/material.dart';
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/login/login.dart';
import 'package:snow_plow/models/Change.dart';
import 'package:snow_plow/models/ChangeDTO.dart';
import 'package:snow_plow/models/MyUserDTO.dart';
import 'package:snow_plow/services/MyUserService.dart';
import 'package:snow_plow/utility/debug_utility.dart';
import 'package:snow_plow/utility/form_validation.dart';

class ProfileEditPage extends StatefulWidget {
  static const routeName = "/editProfile";

  _ProfileEditPageState createState() => _ProfileEditPageState();
}

class _ProfileEditPageState extends State<ProfileEditPage> {
  TextEditingController _phoneNumberController = new TextEditingController();
  String _phoneNumber;
  String _phoneInputErrorMessage = "";

  TextEditingController _emailController = new TextEditingController();
  String _email = "";
  String _emailInputErrorMessage = "";

  TextEditingController _firstNameController = new TextEditingController();
  String _firstName = "";
  String _firstNameInputErrorMessage = "";

  TextEditingController _lastNameController = new TextEditingController();
  String _lastName = "";
  String _lastNameInputErrogMessage = "";

  String _updateUserFailedErrorMessage = "";

  MyUserDTO myUser = globals.myUserDTO;
  MyUserService myUserService = new MyUserService();

  void _doEditProfile() {
    bool _phoneNumberEdited = _validPhoneNumber();
    bool _emailEdited = _validEmail();
    bool _firstNameEdited = _validFirstname();
    bool _lastNameEdited = _validLastName();
    if (_firstNameEdited) {
      _addFirstNameChange();
      myUser.edited = true;
    }
    if (_lastNameEdited) {
      _addLastNameChange();
      myUser.edited = true;
    }
    if (_emailEdited) {
      _addEmailChange();
      myUser.edited = true;
    }
    if (_phoneNumberEdited) {
      _addFPhoneNumberChange();
      myUser.edited = true;
    }
    if (myUser.edited) {
      _sendEditRequest();
    } else {
      Navigator.of(context).pop();
    }
  }

  void _doDeleteProfile() {
    myUserService.deleteMyUser(myUser).then((value) {
      if (value) {
        globals.myUserDTO = null;
        globals.jsonWebToken = null;
        Navigator.of(context).pushNamed(LoginPage.routeName);
      } else {
        setState(() {
          _updateUserFailedErrorMessage =
              "Kunne ikke slette bruker, prøv på nytt senere";
        });
      }
    });
  }

  void _addFirstNameChange() {
    Change change = new Change(
        id: 0,
        created: DateTime.now(),
        tableName: "users",
        columnName: "first_name",
        rowNumber: myUser.id,
        oldValue: myUser.firstName,
        newValue: _firstNameController.text.trim());
    myUser.changes.add(change);
    myUser.firstName = _firstNameController.text.trim();
  }

  void _addLastNameChange() {
    Change change = new Change(
        id: 0,
        created: DateTime.now(),
        tableName: "users",
        columnName: "last_name",
        rowNumber: myUser.id,
        oldValue: myUser.lastName,
        newValue: _lastNameController.text.trim());
    myUser.changes.add(change);
    myUser.lastName = _lastNameController.text.trim();
  }

  void _addEmailChange() {
    Change change = new Change(
        id: 0,
        created: DateTime.now(),
        tableName: "users",
        columnName: "email",
        rowNumber: myUser.id,
        oldValue: myUser.email,
        newValue: _emailController.text.trim().toLowerCase());
    myUser.changes.add(change);
    myUser.email = _emailController.text.trim().toLowerCase();
  }

  void _addFPhoneNumberChange() {
    Change change = new Change(
        id: 0,
        created: DateTime.now(),
        tableName: "users",
        columnName: "phone_number",
        rowNumber: myUser.id,
        oldValue: myUser.phoneNumber,
        newValue: _phoneNumberController.text.trim());
    myUser.changes.add(change);
    myUser.phoneNumber = _phoneNumberController.text.trim();
  }

  void clearChanges() {
    myUser.changes = new List();
    myUser.edited = false;
  }

  void _sendEditRequest() {
    myUserService.updateMyUser(myUser).then((value) {
      clearChanges();
      if (value) {
        Navigator.of(context).pop();
      } else {
        setState(() {
          _updateUserFailedErrorMessage = "Failed to update user, try again.";
        });
      }
    });
  }

  List<ChangeDTO> getChanges() {}

  bool _validFirstname() {
    setState(() {
      _firstName = _firstNameController.text;
    });
    bool valid = false;
    InputFieldResult result = validateIfNotEmpty(_firstName);

    switch (result) {
      case InputFieldResult.VALID:
        {
          setState(() {
            _firstNameInputErrorMessage = "";
          });
          debugPrintMessage("Update with firstName " + _firstName);
          valid = true;
        }
        break;

      case InputFieldResult.MISSING:
        {
          setState(() {
            _firstNameInputErrorMessage = "Ugyldig fornavn";
          });
          debugPrintError("Invalid firstName input");
        }
        break;

      case InputFieldResult.NOT_A_NUMBER:
        {
          debugPrintError("Shouldn't happen");
        }
        break;
    }

    return valid;
  }

  bool _validLastName() {
    setState(() {
      _lastName = _lastNameController.text;
    });
    bool valid = false;
    InputFieldResult result = validateIfNotEmpty(_lastName);

    switch (result) {
      case InputFieldResult.VALID:
        {
          setState(() {
            _lastNameInputErrogMessage = "";
          });
          debugPrintMessage("Update with lastName " + _lastName);
          valid = true;
        }
        break;

      case InputFieldResult.MISSING:
        {
          setState(() {
            _lastNameInputErrogMessage = "Ugyldig etternavn";
          });
          debugPrintError("Invalid lastName input");
        }
        break;

      case InputFieldResult.NOT_A_NUMBER:
        {
          debugPrintError("Shouldn't happen");
        }
        break;
    }

    return valid;
  }

  bool _validPhoneNumber() {
    setState(() {
      _phoneNumber = _phoneNumberController.text;
    });
    bool valid = false;
    PhoneValidationResult result = validatePhoneNumber(_phoneNumber);

    switch (result) {
      case PhoneValidationResult.VALID:
        {
          setState(() {
            _phoneInputErrorMessage = "";
          });
          debugPrintMessage("Update with number " + _phoneNumber);
          valid = true;
        }
        break;

      case PhoneValidationResult.INVALID:
        {
          setState(() {
            _phoneInputErrorMessage = "Ugyldig telefonnummer";
          });
          debugPrintError("Invalid number input");
        }
        break;

      case PhoneValidationResult.TOO_SHORT:
        {
          setState(() {
            _phoneInputErrorMessage = "Telefonnummeret er for kort";
          });
          debugPrintError("Number too short");
        }
        break;

      case PhoneValidationResult.TOO_LONG:
        {
          setState(() {
            _phoneInputErrorMessage = "Telefonnummeret er for langt";
          });
          debugPrintError("Number too long");
        }
        break;
    }

    return valid;
  }

  bool _validEmail() {
    setState(() {
      _email = _emailController.text;
    });
    bool valid = false;
    EmailValidationResult result = validateEmail(_email);

    switch (result) {
      case EmailValidationResult.VALID:
        {
          setState(() {
            _emailInputErrorMessage = "";
          });
          debugPrintMessage("Update with email " + _email);
          valid = true;
        }
        break;

      case EmailValidationResult.INVALID:
        {
          setState(() {
            _emailInputErrorMessage = "E-post mangler";
          });
          debugPrintError("Email is missing");
        }
        break;

      case EmailValidationResult.MISSING:
        {
          setState(() {
            _emailInputErrorMessage = "Ugyldig e-post";
          });
          debugPrintError("Invalid email");
        }
        break;
    }

    return valid;
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: Text("Rediger profil"),
      ),
      body: SingleChildScrollView(
        child: Column(
          children: <Widget>[
            Container(
              padding: EdgeInsets.fromLTRB(0, 30, 0, 0),
              child: Text(
                "Telefonnummer",
                style: Theme.of(context).textTheme.subtitle,
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(50, 0, 50, 0),
              child: TextField(
                controller: _phoneNumberController,
                keyboardType: TextInputType.number,
                textAlign: TextAlign.center,
                decoration: new InputDecoration(
                  hintText: myUser.phoneNumber,
                  contentPadding: EdgeInsets.all(5.0),
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(0, 5, 0, 0),
              child: Text(
                _phoneInputErrorMessage,
                style: Theme.of(context)
                    .textTheme
                    .subtitle
                    .copyWith(color: Theme.of(context).errorColor),
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(0, 30, 0, 0),
              child: Text(
                "E-postadresse",
                style: Theme.of(context).textTheme.subtitle,
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(50, 0, 50, 0),
              child: TextField(
                controller: _emailController,
                textAlign: TextAlign.center,
                decoration: new InputDecoration(
                  hintText: myUser.email,
                  contentPadding: EdgeInsets.all(5.0),
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(0, 5, 0, 0),
              child: Text(
                _emailInputErrorMessage,
                style: Theme.of(context)
                    .textTheme
                    .subtitle
                    .copyWith(color: Theme.of(context).errorColor),
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(0, 30, 0, 0),
              child: Text(
                "Fornavn",
                style: Theme.of(context).textTheme.subtitle,
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(50, 0, 50, 0),
              child: TextField(
                controller: _firstNameController,
                textAlign: TextAlign.center,
                decoration: new InputDecoration(
                  hintText: myUser.firstName,
                  contentPadding: EdgeInsets.all(5.0),
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(0, 5, 0, 0),
              child: Text(
                _firstNameInputErrorMessage,
                style: Theme.of(context)
                    .textTheme
                    .subtitle
                    .copyWith(color: Theme.of(context).errorColor),
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(0, 30, 0, 0),
              child: Text(
                "Etternavn",
                style: Theme.of(context).textTheme.subtitle,
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(50, 0, 50, 0),
              child: TextField(
                controller: _lastNameController,
                textAlign: TextAlign.center,
                decoration: new InputDecoration(
                  hintText: myUser.lastName,
                  contentPadding: EdgeInsets.all(5.0),
                ),
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(0, 5, 0, 0),
              child: Text(
                _lastNameInputErrogMessage,
                style: Theme.of(context)
                    .textTheme
                    .subtitle
                    .copyWith(color: Theme.of(context).errorColor),
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(0, 10, 0, 10),
              child: RaisedButton(
                child: Text(
                  "Fullfør",
                  style: TextStyle(
                    fontSize: 25,
                    color: Colors.white,
                  ),
                ),
                onPressed: _doEditProfile,
                color: Theme.of(context).primaryColor,
                splashColor: Colors.white,
                padding: EdgeInsets.symmetric(vertical: 20, horizontal: 30),
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(0, 5, 0, 0),
              child: Text(
                _updateUserFailedErrorMessage,
                style: Theme.of(context)
                    .textTheme
                    .subtitle
                    .copyWith(color: Theme.of(context).errorColor),
              ),
            ),
            Container(
              padding: EdgeInsets.fromLTRB(0, 10, 0, 10),
              child: RaisedButton(
                child: Text(
                  "Delete",
                  style: TextStyle(
                    fontSize: 25,
                    color: Colors.white,
                  ),
                ),
                onPressed: _doDeleteProfile,
                color: Colors.red,
                splashColor: Colors.white,
                padding: EdgeInsets.symmetric(vertical: 20, horizontal: 30),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
