import 'package:flutter/material.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/MyUserDTO.dart';
import 'package:snow_plow/models/PlowerRequestDTO.dart';
import 'package:snow_plow/services/MyUserService.dart';
import 'package:snow_plow/services/PlowerRequestService.dart';
import 'package:snow_plow/widgets/main_drawer.dart';

import 'edit_profile.dart';

class ProfilePage extends StatefulWidget {
  static const routeName = "/profile";

  _ProfilePageState createState() => _ProfilePageState();
}

class _ProfilePageState extends State<ProfilePage> {
  //API URL
  var _url =
      "https://15afd3e8-4a3d-480b-af8e-c4355174806a.mock.pstmn.io/Profile";

  bool _isLoading = false;

  //Profile data object
  MyUserDTO _data;

  //DEBUG
  String _debugProfileGet;

  MyUserService myUserService = new MyUserService();
  PlowerRequestService plowerRequestService = new PlowerRequestService();

  void sendPlowerRequest() {
    plowerRequestService
        .createPlowerRequest(new PlowerRequestDTO(
            id: 0, myUser: globals.myUserDTO, dateRequested: DateTime.now()))
        .then((value) {
      if (value) {
        Fluttertoast.showToast(
            msg: "Forespursel sent", toastLength: Toast.LENGTH_SHORT);
      } else {
        Fluttertoast.showToast(
            msg: "Kunne ikke sende forespursel",
            toastLength: Toast.LENGTH_SHORT);
      }
    });
  }

  void fetchMyUser() {
    myUserService.fetchMyUser().then((value) {
      globals.myUserDTO = value;
      print(value);
      setState(() {
        _data = value;
      });
    });
  }

  //Initialization method
  @override
  void initState() {
    super.initState();

    fetchMyUser();
  }

  //Widget build
  @override
  Widget build(BuildContext context) {
    if (_data == null) {
      return new Scaffold(
        appBar: new AppBar(
          title: new Text("Loading"),
        ),
      );
    } else {
      return Scaffold(
        drawer: MainDrawer(),
        appBar: AppBar(
          title: Text("Profil"),
        ),
        body: SingleChildScrollView(
          child: Column(
            children: <Widget>[
              Container(
                child: Icon(
                  Icons.account_circle,
                  color: Theme.of(context).accentColor,
                  size: 220,
                ),
                padding: EdgeInsets.fromLTRB(0, 10, 0, 10),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(50, 0, 50, 0),
                child: Align(
                  alignment: Alignment.centerLeft,
                  child: Text(
                    "Telefonnummer",
                    style: Theme.of(context).textTheme.subtitle,
                  ),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(50, 0, 50, 40),
                child: TextField(
                  readOnly: true,
                  textAlign: TextAlign.left,
                  decoration: new InputDecoration(
                    hintText: "+47 ${_data.phoneNumber}",
                  ),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(50, 0, 50, 0),
                child: Align(
                  alignment: Alignment.centerLeft,
                  child: Text(
                    "Fornavn",
                    style: Theme.of(context).textTheme.subtitle,
                  ),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(50, 0, 50, 40),
                child: TextField(
                  textAlign: TextAlign.left,
                  decoration: new InputDecoration(
                    hintText: "${_data.firstName}",
                  ),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(50, 0, 50, 0),
                child: Align(
                  alignment: Alignment.centerLeft,
                  child: Text(
                    "Etternavn",
                    style: Theme.of(context).textTheme.subtitle,
                  ),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(50, 0, 50, 40),
                child: TextField(
                  textAlign: TextAlign.left,
                  decoration: new InputDecoration(
                    hintText: "${_data.lastName}",
                  ),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(50, 0, 50, 0),
                child: Align(
                  alignment: Alignment.centerLeft,
                  child: Text(
                    "E-postadresse",
                    style: Theme.of(context).textTheme.subtitle,
                  ),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(50, 0, 50, 40),
                child: TextField(
                  textAlign: TextAlign.left,
                  decoration: new InputDecoration(
                    hintText: "${_data.email}",
                  ),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(0, 0, 0, 0),
                child: RaisedButton(
                  child: Text(
                    "Rediger",
                    style: TextStyle(
                      fontSize: 25,
                      color: Colors.white,
                    ),
                  ),
                  color: Theme.of(context).primaryColor,
                  onPressed: () => Navigator.of(context)
                      .pushNamed(ProfileEditPage.routeName),
                  splashColor: Colors.white,
                  padding: EdgeInsets.symmetric(vertical: 12, horizontal: 50),
                ),
              ),
              SizedBox(
                height: 15,
              ),
              Container(
                padding: EdgeInsets.fromLTRB(0, 0, 0, 0),
                child: RaisedButton(
                  child: Text(
                    "Bli ploger",
                    style: TextStyle(
                      fontSize: 15,
                      color: Colors.white,
                    ),
                  ),
                  color: Theme.of(context).primaryColor,
                  onPressed: sendPlowerRequest,
                  splashColor: Colors.white,
                  padding: EdgeInsets.symmetric(vertical: 12, horizontal: 15),
                ),
              ),
              Container(
                padding: EdgeInsets.fromLTRB(0, 10, 0, 0),
                child: RaisedButton(
                  child: Text(
                    "DEBUG_RELOAD_DATA",
                    style: TextStyle(
                      fontSize: 10,
                      color: Colors.white,
                    ),
                  ),
                  onPressed: fetchMyUser,
                  color: Theme.of(context).primaryColor,
                  splashColor: Colors.white,
                  padding: EdgeInsets.symmetric(vertical: 0, horizontal: 10),
                ),
              ),
              Text(
                "LAST_PROFILE_LOAD: $_debugProfileGet",
                style: Theme.of(context).textTheme.caption,
              ),
            ],
          ),
        ),
      );
    }
  }
}
