import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/JsonWebToken.dart';
import 'package:snow_plow/services/MyUserService.dart';

class AuthenticationService {
  MyUserService myUserService = new MyUserService();
  // sends otp to email if user is found
  Future<bool> getOtp(String email) async {
    final body = jsonEncode({"email": email});
    final response = await http.post(globals.baseUrl + "/getOtp",
        headers: {"Content-Type": "application/json"}, body: body);
    if (response.statusCode == 200) {
      print("user found (otp sent) :: do somethng");
      return true;
    } else {
      print("user not found :: do something");
      return false;
    }
  }

  Future<bool> authenticate(String email, String otp) async {
    final body = jsonEncode({"username": email, "password": otp});
    Map<String, String> headers = {
      HttpHeaders.contentTypeHeader: "application/json",
      HttpHeaders.acceptHeader: "application/json"
    };
    final response = await http.post(globals.baseUrl + "/authenticate",
        headers: headers, body: body);
    if (response.statusCode == 200) {
      JsonWebToken jwt = parseJsonWebToken(response.body);
      globals.jsonWebToken = jwt;
      print(jwt.token);
      print("user found :: do somethng");
      return true;
    } else {
      print("user not found :: do something");
      return false;
    }
  }

  JsonWebToken parseJsonWebToken(String responseBody) {
    final Map parsed = jsonDecode(responseBody);
    return JsonWebToken.fromJson(parsed);
  }
}
