import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/CabinAreaDTO.dart';

class CabinAreaService {
  Future<List<CabinAreaDTO>> fetchCabinAreas() async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response = await http.get(globals.baseUrl + "/cabinarea/cabinareas",
        headers: headers);
    if (response.statusCode == 200) {
      print("sucess");
      return parseCabinAreaDTOs(response.body);
    } else {
      print("cabins not found");
      return null;
    }
  }

  Future<List<CabinAreaDTO>> fetchCabinAreasByUserId() async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response = await http.get(
        globals.baseUrl +
            "/cabinarea/myuser/" +
            globals.myUserDTO.id.toString(),
        headers: headers);
    if (response.statusCode == 200) {
      print("sucess");
      return parseCabinAreaDTOs(response.body);
    } else {
      print("cabins not found");
      return null;
    }
  }

  Future<CabinAreaDTO> updateCabinArea(CabinAreaDTO cabinAreaDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final body = jsonEncode(cabinAreaDTO.toJson());
    final response = await http.put(globals.baseUrl + "/cabinarea/update",
        headers: headers, body: body);
    if (response.statusCode == 200) {
      print("sucessful");
      return parseCabinAreaDTO(response.body);
    } else {
      print("cabins not found");
      return null;
    }
  }

  Future<CabinAreaDTO> createCabinArea(CabinAreaDTO cabinAreaDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final body = jsonEncode(cabinAreaDTO.toJson());
    final response = await http.post(globals.baseUrl + "/cabinarea/create",
        headers: headers, body: body);
    if (response.statusCode == 200) {
      print("sucessful");
      return parseCabinAreaDTO(response.body);
    } else {
      print("failed");
      return null;
    }
  }

  Future<bool> deleteCabinArea(CabinAreaDTO cabinAreaDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response = await http.post(
        globals.baseUrl + "/cabinArea/delete/" + cabinAreaDTO.id.toString(),
        headers: headers);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("cabinarea not found");
      return false;
    }
  }

  List<CabinAreaDTO> parseCabinAreaDTOs(String responseBody) {
    final parsed = jsonDecode(responseBody).cast<Map<String, dynamic>>();
    return parsed
        .map<CabinAreaDTO>((json) => CabinAreaDTO.fromJson(json))
        .toList();
  }

  CabinAreaDTO parseCabinAreaDTO(String responseBody) {
    final Map parsed = jsonDecode(responseBody);
    return CabinAreaDTO.fromJson(parsed);
  }
}
