import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/CabinDTO.dart';

class CabinService {
  Future<List<CabinDTO>> fetchMyCabins() async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final body = jsonEncode(globals.myUserDTO.toJson());
    final response = await http.get(
        globals.baseUrl +
            "/cabin/cabinsbyuser/" +
            globals.myUserDTO.id.toString(),
        headers: headers);
    if (response.statusCode == 200) {
      print("sucess");
      return parseCabinDTOs(response.body);
    } else {
      print("cabins not found");
      return null;
    }
  }

  Future<CabinDTO> updateCabin(CabinDTO cabinDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final body = jsonEncode(cabinDTO.toJson());
    final response = await http.put(globals.baseUrl + "/cabin/update",
        headers: headers, body: body);
    if (response.statusCode == 200) {
      print("sucessful");
      return parseCabinDTO(response.body);
    } else {
      print("cabins not found");
      return null;
    }
  }

  Future<bool> createCabin(CabinDTO cabinDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final body = jsonEncode(cabinDTO.toJson());
    final response = await http.post(globals.baseUrl + "/cabin/create",
        headers: headers, body: body);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("failed");
      return false;
    }
  }

  Future<bool> deleteCabin(CabinDTO cabinDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response = await http.delete(
        globals.baseUrl + "/cabin/delete/" + cabinDTO.id.toString(),
        headers: headers);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("cabin not found");
      return false;
    }
  }

  List<CabinDTO> parseCabinDTOs(String responseBody) {
    final parsed = jsonDecode(responseBody).cast<Map<String, dynamic>>();
    return parsed.map<CabinDTO>((json) => CabinDTO.fromJson(json)).toList();
  }

  CabinDTO parseCabinDTO(String responseBody) {
    final Map parsed = jsonDecode(responseBody);
    return CabinDTO.fromJson(parsed);
  }
}
