import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/MyUserDTO.dart';
import 'package:snow_plow/models/RoleDTO.dart';

class MyUserService {
  Future<MyUserDTO> fetchMyUser() async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response =
        await http.get(globals.baseUrl + "/user/myuser", headers: headers);
    if (response.statusCode == 200) {
      MyUserDTO myUserDTO = parseMyUserDTO(response.body);
      print("success");
      return myUserDTO;
    } else {
      print("user not found");
      return null;
    }
  }

  Future<bool> updateMyUser(MyUserDTO myUserDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final body = jsonEncode(myUserDTO.toJson());
    final response = await http.put(globals.baseUrl + "/user/update",
        headers: headers, body: body);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("user not found");
      return false;
    }
  }

  Future<bool> createMyUser(MyUserDTO myUserDTO) async {
    Map<String, String> headers = {
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final body = jsonEncode(myUserDTO.toJson());
    final response = await http.post(globals.baseUrl + "/user/create",
        headers: headers, body: body);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("not able to create");
      return false;
    }
  }

  Future<bool> deleteMyUser(MyUserDTO myUserDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response = await http.delete(
        globals.baseUrl + "/user/delete/" + myUserDTO.id.toString(),
        headers: headers);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("user not found");
      return false;
    }
  }

  Future<List<RoleDTO>> fetcRoles() async {
    final response = await http.get(globals.baseUrl + "/test/roles");
    if (response.statusCode == 200) {
      return parseRoleDTOs(response.body);
    } else {
      print("couldnt fetch");
      return null;
    }
  }

  MyUserDTO parseMyUserDTO(String responseBody) {
    final Map parsed = jsonDecode(responseBody);
    return MyUserDTO.fromJson(parsed);
  }

  List<RoleDTO> parseRoleDTOs(String responseBody) {
    final parsed = jsonDecode(responseBody).cast<Map<String, dynamic>>();

    return parsed.map<RoleDTO>((json) => RoleDTO.fromJson(json)).toList();
  }

  void logMyUser() async {
    Future<List<RoleDTO>> roles = fetcRoles();
    roles.then((roles) {
      for (RoleDTO roleDTO in roles) {
        print(roleDTO.role);
        print(roleDTO.description);
      }
    });
  }

  Future<bool> validateToken() async {
    if (globals.jsonWebToken != null) {
      final response =
          await http.get(globals.baseUrl + "/validatejwt", headers: {
        HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
        HttpHeaders.acceptHeader: "application/json"
      });
      if (response.statusCode == 200) {
        print(response.body);
      } else {
        print("couldnt fetch");
      }
    }
    return false;
  }
}
