import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/PlowerCabinAreaDTO.dart';

class PlowerCabinAreaService {
  Future<bool> updatePlowerCabinArea(
      PlowerCabinAreaDTO plowerCabinAreaDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final body = jsonEncode(plowerCabinAreaDTO.toJson());
    final response = await http.put(globals.baseUrl + "/plowercabinarea/update",
        headers: headers, body: body);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("plowerCabinAreas not found");
      return false;
    }
  }

  Future<bool> createPlowerCabinArea(
      PlowerCabinAreaDTO plowerCabinAreaDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final body = jsonEncode(plowerCabinAreaDTO.toJson());
    final response = await http.post(
        globals.baseUrl + "/plowercabinarea/create",
        headers: headers,
        body: body);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("failed");
      return false;
    }
  }

  Future<bool> deletePlowerCabinArea(
      PlowerCabinAreaDTO plowerCabinAreaDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response = await http.delete(
        globals.baseUrl +
            "/plowercabinarea/delete/" +
            plowerCabinAreaDTO.id.toString(),
        headers: headers);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("plowerCabinArea not found");
      return false;
    }
  }

  List<PlowerCabinAreaDTO> parsePlowerCabinAreaDTOs(String responseBody) {
    final parsed = jsonDecode(responseBody).cast<Map<String, dynamic>>();
    return parsed
        .map<PlowerCabinAreaDTO>((json) => PlowerCabinAreaDTO.fromJson(json))
        .toList();
  }

  PlowerCabinAreaDTO parsePlowerCabinAreaDTO(String responseBody) {
    final Map parsed = jsonDecode(responseBody);
    return PlowerCabinAreaDTO.fromJson(parsed);
  }
}
