import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/PlowerRequestDTO.dart';

class PlowerRequestService {
  Future<List<PlowerRequestDTO>> fetchPlowerRequests() async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response = await http.get(
        globals.baseUrl + "/plowerrequest/plowerrequests",
        headers: headers);
    if (response.statusCode == 200) {
      print("sucess");
      print(parsePlowerRequestDTOs(response.body));
      return parsePlowerRequestDTOs(response.body);
    } else {
      print("plower request not found");
      return null;
    }
  }

  Future<List<PlowerRequestDTO>> fetchPlowerRequestsByUserId() async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response = await http.get(
        globals.baseUrl +
            "/plowerrequest/myuser/" +
            globals.myUserDTO.id.toString(),
        headers: headers);
    if (response.statusCode == 200) {
      print("sucess");
      return parsePlowerRequestDTOs(response.body);
    } else {
      print("plower request not found");
      return null;
    }
  }

  Future<bool> updatePlowerRequest(PlowerRequestDTO plowerRequestDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final body = jsonEncode(plowerRequestDTO.toJson());
    final response = await http.put(globals.baseUrl + "/plowerrequest/update",
        headers: headers, body: body);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("plower request not found");
      return false;
    }
  }

  Future<bool> createPlowerRequest(PlowerRequestDTO plowerRequestDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final body = jsonEncode(plowerRequestDTO.toJson());
    print(body);
    final response = await http.post(globals.baseUrl + "/plowerrequest/create",
        headers: headers, body: body);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("failed");
      return false;
    }
  }

  Future<bool> deletePlowerRequest(PlowerRequestDTO plowerRequestDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response = await http.post(
        globals.baseUrl +
            "/plowerrequest/delete/" +
            plowerRequestDTO.id.toString(),
        headers: headers);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("plowerrequest not found");
      return false;
    }
  }

  List<PlowerRequestDTO> parsePlowerRequestDTOs(String responseBody) {
    final parsed = jsonDecode(responseBody).cast<Map<String, dynamic>>();
    return parsed
        .map<PlowerRequestDTO>((json) => PlowerRequestDTO.fromJson(json))
        .toList();
  }

  PlowerRequestDTO parsePlowerRequestDTO(String responseBody) {
    final Map parsed = jsonDecode(responseBody);
    return PlowerRequestDTO.fromJson(parsed);
  }
}
