import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/models/CabinAreaDTO.dart';
import 'package:snow_plow/models/CabinDTO.dart';
import 'package:snow_plow/models/PlowingRequestDTO.dart';

class PlowingRequestService {
  Future<List<PlowingRequestDTO>> fetchPlowingRequests() async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response = await http.get(
        globals.baseUrl + "/plowingrequest/plowingrequests/",
        headers: headers);
    if (response.statusCode == 200) {
      print("sucess");
      return parsePlowingRequestDTOs(response.body);
    } else {
      print("plowingrequest not found");
      return null;
    }
  }

  Future<bool> updatePlowingRequest(PlowingRequestDTO plowingRequestDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final body = jsonEncode(plowingRequestDTO.toJson());
    final response = await http.put(globals.baseUrl + "/cabin/update",
        headers: headers, body: body);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("plowingrequest not found");
      return false;
    }
  }

  Future<bool> createPlowingRequest(PlowingRequestDTO plowingRequestDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final body = jsonEncode(plowingRequestDTO.toJson());
    final response = await http.post(globals.baseUrl + "/plowingrequest/create",
        headers: headers, body: body);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("failed");
      return false;
    }
  }

  Future<bool> deletePlowingRequest(PlowingRequestDTO plowingRequestDTO) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response = await http.delete(
        globals.baseUrl +
            "/plowingrequest/delete/" +
            plowingRequestDTO.id.toString(),
        headers: headers);
    if (response.statusCode == 200) {
      print("sucessful");
      return true;
    } else {
      print("plowingrequest not found");
      return false;
    }
  }

  Future<List<PlowingRequestDTO>> getPlowingRequestByCabinId(
      CabinDTO cabin) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response = await http.get(
        globals.baseUrl + "/plowingrequest/cabin/" + cabin.id.toString(),
        headers: headers);
    if (response.statusCode == 200) {
      print("sucessful");
      return parsePlowingRequestDTOs(response.body);
    } else {
      print("plowingrequest not found");
      return null;
    }
  }

  Future<List<PlowingRequestDTO>> getPlowingRequestByCabinAreaId(
      CabinAreaDTO cabinArea) async {
    Map<String, String> headers = {
      HttpHeaders.authorizationHeader: "Bearer " + globals.jsonWebToken.token,
      HttpHeaders.acceptHeader: "application/json",
      HttpHeaders.contentTypeHeader: "application/json"
    };
    final response = await http.get(
        globals.baseUrl +
            "/plowingrequest/cabinarea/" +
            cabinArea.id.toString(),
        headers: headers);
    if (response.statusCode == 200) {
      print("sucessful");
      return parsePlowingRequestDTOs(response.body);
    } else {
      print("plowingrequest not found");
      return null;
    }
  }

  List<PlowingRequestDTO> parsePlowingRequestDTOs(String responseBody) {
    final parsed = jsonDecode(responseBody).cast<Map<String, dynamic>>();
    return parsed
        .map<PlowingRequestDTO>((json) => PlowingRequestDTO.fromJson(json))
        .toList();
  }

  PlowingRequestDTO parsePlowingRequestDTO(String responseBody) {
    final Map parsed = jsonDecode(responseBody);
    return PlowingRequestDTO.fromJson(parsed);
  }
}
