
enum PhoneValidationResult {
  VALID,
  INVALID,
  TOO_SHORT,
  TOO_LONG,
}

enum EmailValidationResult  {
  VALID,
  INVALID,
  MISSING,
}

enum ConfirmationCodeResult {
  VALID,
  INVALID,
  TOO_SHORT,
  TOO_LONG,
}

enum InputFieldResult {
  VALID,
  MISSING,
  NOT_A_NUMBER,
}

PhoneValidationResult validatePhoneNumber(String phoneNumber)  {
  PhoneValidationResult result = PhoneValidationResult.INVALID;
  RegExp nonNumber = new RegExp("[^0-9]");
  RegExp validPhoneFormat = new RegExp("^[0-9]{6,12}\$");
  
    //If input is an actual phone number
    if(validPhoneFormat.hasMatch(phoneNumber)) {
      result = PhoneValidationResult.VALID;
    }
    //Check if input contains non-numerical characters
    else if(nonNumber.hasMatch(phoneNumber)) {
      result = PhoneValidationResult.INVALID;
    }
    //If input is too short/missing
    else if(phoneNumber.length < 6) {
      result = PhoneValidationResult.TOO_SHORT;
    }
    //If input is too long
    else if(phoneNumber.length > 12) {
      result = PhoneValidationResult.TOO_LONG;
    }
    return result;
}

EmailValidationResult validateEmail(String email) {
  EmailValidationResult result = EmailValidationResult.INVALID;
  RegExp validEmailFormat = RegExp(r"^[a-zA-Z0-9.a-zA-Z0-9.!#$%&'*+-/=?^_`{|}~]+@[a-zA-Z0-9]+\.[a-zA-Z]+");

  if(validEmailFormat.hasMatch(email))  {
    result = EmailValidationResult.VALID;
  }
  else if(email.length <= 0) {
    result = EmailValidationResult.MISSING;
  }
  else {
    result = EmailValidationResult.INVALID;
  }
  return result;
}

ConfirmationCodeResult validateConfirmationCode(String code)  {
  ConfirmationCodeResult result = ConfirmationCodeResult.INVALID;
  RegExp nonNumber = new RegExp("[^0-9]");
  RegExp validCodeFormat = new RegExp("^[0-9]{6}\$");

  if(validCodeFormat.hasMatch(code)) {
    result = ConfirmationCodeResult.VALID;
  }
  else if(nonNumber.hasMatch(code)) {
    result = ConfirmationCodeResult.INVALID;
  }
  //If input is too short/missing
  else if(code.length < 6) {
    result = ConfirmationCodeResult.TOO_SHORT;
  }
  //If input is too long
  else if(code.length > 6) {
    result = ConfirmationCodeResult.TOO_LONG;
  }
  return result;
}

InputFieldResult validateIfNotEmpty(String inputText) {
  InputFieldResult result = InputFieldResult.MISSING;
  if(inputText.length > 0)  {
    result = InputFieldResult.VALID;
  }
  return result;
}

InputFieldResult validateNumericalInput(String input) {
  InputFieldResult result = InputFieldResult.MISSING;
  RegExp nonNumber = new RegExp("[^0-9]");
  if(input.length > 0)  {
    if(nonNumber.hasMatch(input)) {
      result = InputFieldResult.NOT_A_NUMBER;
    }
    else if(!nonNumber.hasMatch(input)) {
      result = InputFieldResult.VALID;
    }
  }
  return result;
}

