import 'package:flutter/material.dart';
import 'package:snow_plow/Plower/CabinAreas.dart';
import 'package:snow_plow/admin/PlowerRequests.dart';
import 'package:snow_plow/globals.dart' as globals;
import 'package:snow_plow/login/login.dart';
import 'package:snow_plow/map/map_view.dart';
import 'package:snow_plow/models/RoleDTO.dart';
import 'package:snow_plow/profile/profile.dart';
import 'package:snow_plow/screens/MyCabinsScreen.dart';

class MainDrawer extends StatelessWidget {
  bool checkIfUserIsPlower() {
    if (globals.myUserDTO != null) {
      for (RoleDTO role in globals.myUserDTO.roleDTOs) {
        if (role.role == "plower") {
          return true;
        }
      }
    }
    return false;
  }

  bool checkIfUserIsAdmin() {
    if (globals.myUserDTO != null) {
      for (RoleDTO role in globals.myUserDTO.roleDTOs) {
        if (role.role == "admin") {
          return true;
        }
      }
    }
    return false;
  }

  Widget buildListTile(String title, IconData icon) {
    return ListTile(
      leading: Icon(
        icon,
        size: 26,
      ),
      title: Text(
        title,
        style: TextStyle(
          fontFamily: "",
          fontSize: 24,
          fontWeight: FontWeight.bold,
        ),
      ),
    );
  }

  @override
  Widget build(BuildContext context) {
    void _onLogoutPressed() {
      globals.myUserDTO = null;
      globals.jsonWebToken = null;
      Navigator.of(context).pushNamed(LoginPage.routeName);
    }

    return Drawer(
      child: Column(
        children: <Widget>[
          AppBar(title: Text("Meny"), automaticallyImplyLeading: false),
          Divider(),
          ListTile(
            leading: Icon(Icons.person, size: 26),
            title: Text("Profil"),
            onTap: () => {
              Navigator.of(context).pushReplacementNamed(ProfilePage.routeName)
            },
          ),
          Divider(),
          ListTile(
            leading: Icon(Icons.home, size: 26),
            title: Text("Hytter"),
            onTap: () => {
              Navigator.of(context)
                  .pushReplacementNamed(MyCabinsScreen.routeName)
            },
          ),
          Divider(),
          ListTile(
            leading: Icon(Icons.map, size: 26),
            title: Text("Kart"),
            onTap: () =>
                {Navigator.of(context).pushNamed(PlowerMapView.routeName)},
          ),
          Divider(),
          checkIfUserIsPlower()
              ? ListTile(
                  leading: Icon(
                    Icons.check,
                    size: 26,
                  ),
                  title: Text("Ploge forespursler"),
                  onTap: () => {
                    Navigator.of(context)
                        .pushNamed(MyCabinAreasScreen.routeName)
                  },
                )
              : Container(),
          Divider(),
          checkIfUserIsAdmin()
              ? ListTile(
                  leading: Icon(
                    Icons.accessibility,
                    size: 26,
                  ),
                  title: Text("Ploger forespursler"),
                  onTap: () => {
                    Navigator.of(context)
                        .pushNamed(PlowerRequestsScreen.routeName)
                  },
                )
              : Container(),
          Divider(),
          ListTile(
              leading: Icon(Icons.cloud_off, size: 26),
              title: Text("Logg av"),
              onTap: _onLogoutPressed),
        ],
      ),
    );
  }
}
